#ifndef __FRONTEND_LIST_H__
#define __FRONTEND_LIST_H__

struct fe_driver {
	char description[128];
	char name[16];
	char exe[16];
	int cores; /* ASM cores: 0=None,1=Cyclone,2=DrZ80,3=Cyclone+DrZ80,4=DrZ80(snd),5=Cyclone+DrZ80(snd) */
	int available;
};

#define NUMGAMES 2270

struct fe_driver fe_drivers[NUMGAMES] = {

{ "'88 Games"                                                                                             ,"88games"      , "mame", 3, 0 } ,												
{ "'99 The Last War (alternate)"                                                                          ,"99lstwra"     , "mame", 3, 0 } ,												
{ "'99 The Last War"                                                                                      ,"99lstwar"     , "mame", 3, 0 } ,												
{ "005"                                                                                                   ,"005"          , "mame", 1, 0 } ,												
{ "10 Yard Fight (Vs. version 11/05/84)"                                                                  ,"vsyard"       , "mame", 3, 0 } ,												
{ "10 Yard Fight (Vs. version, set 2)"                                                                    ,"vsyard2"      , "mame", 3, 0 } ,												
{ "10 Yard Fight"                                                                                         ,"yard"         , "mame", 3, 0 } ,												
{ "1941 - Counter Attack (Japan)"                                                                         ,"1941j"        , "mame", 3, 0 } ,												
{ "1941 - Counter Attack (World)"                                                                         ,"1941"         , "mame", 3, 0 } ,												
{ "1942 (set 1)"                                                                                          ,"1942"         , "mame", 5, 0 } ,												
{ "1942 (set 2)"                                                                                          ,"1942a"        , "mame", 5, 0 } ,												
{ "1942 (set 3)"                                                                                          ,"1942b"        , "mame", 5, 0 } ,												
{ "1943 - The Battle of Midway (Japan)"                                                                   ,"1943j"        , "mame", 3, 0 } ,												
{ "1943 - The Battle of Midway (US)"                                                                      ,"1943"         , "mame", 3, 0 } ,												
{ "1943 Kai"                                                                                              ,"1943kai"      , "mame", 3, 0 } ,												
{ "2 On 2 Open Ice Challenge (rev 1.21)"                                                                  ,"openice"      , "mame", 3, 0 } ,												
{ "2020 Super Baseball (set 1)"                                                                           ,"2020bb"       , "neomame", 3, 0 } ,												
{ "2020 Super Baseball (set 2)"                                                                           ,"2020bbh"      , "neomame", 3, 0 } ,												
{ "3 Count Bout / Fire Suplex"                                                                            ,"3countb"      , "neomame", 3, 0 } ,												
{ "4 Player Bowling"                                                                                      ,"bowler"       , "mame", 3, 0 } ,												
{ "4-D Warriors"                                                                                          ,"4dwarrio"     , "mame", 1, 0 } ,												
{ "600"                                                                                                   ,"600"          , "mame", 3, 0 } ,												
{ "64th. Street - A Detective Story (Japan)"                                                              ,"64streej"     , "mame", 3, 0 } ,												
{ "64th. Street - A Detective Story (World)"                                                              ,"64street"     , "mame", 3, 0 } ,												
{ "720 Degrees (set 1)"                                                                                   ,"720"          , "mame", 3, 0 } ,												
{ "720 Degrees (set 2)"                                                                                   ,"720b"         , "mame", 3, 0 } ,												
{ "800 Fathoms"                                                                                           ,"800fath"      , "mame", 3, 0 } ,												
{ "APB - All Points Bulletin (set 1)"                                                                     ,"apb"          , "mame", 3, 0 } ,												
{ "APB - All Points Bulletin (set 2)"                                                                     ,"apb2"         , "mame", 3, 0 } ,												
{ "ASO - Armored Scrum Object"                                                                            ,"aso"          , "mame", 3, 0 } ,												
{ "Act-Fancer Cybernetick Hyper Weapon (Japan revision 1)"                                                ,"actfancj"     , "mame", 3, 0 } ,												
{ "Act-Fancer Cybernetick Hyper Weapon (World revision 1)"                                                ,"actfanc1"     , "mame", 3, 0 } ,												
{ "Act-Fancer Cybernetick Hyper Weapon (World revision 2)"                                                ,"actfancr"     , "mame", 3, 0 } ,												
{ "Adventure Quiz 2 Hatena Hatena no Dai-Bouken (Japan)"                                                  ,"hatena"       , "mame", 1, 0 } ,												
{ "Aero Fighters (Turbo Force hardware set 1)"                                                            ,"aerofgtb"     , "mame", 1, 0 } ,												
{ "Aero Fighters (Turbo Force hardware set 2)"                                                            ,"aerofgtc"     , "mame", 1, 0 } ,												
{ "Aero Fighters 2 / Sonic Wings 2"                                                                       ,"sonicwi2"     , "neomame", 1, 0 } ,												
{ "Aero Fighters 3 / Sonic Wings 3"                                                                       ,"sonicwi3"     , "neomame", 1, 0 } ,												
{ "Aero Fighters"                                                                                         ,"aerofgt"      , "mame", 1, 0 } ,												
{ "Aeroboto"                                                                                              ,"aeroboto"     , "mame", 3, 0 } ,												
{ "Aggressors of Dark Kombat / Tsuukai GANGAN Koushinkyoku"                                               ,"aodk"         , "neomame", 3, 0 } ,												
{ "Ah Eikou no Koshien (Japan)"                                                                           ,"koshien"      , "mame", 3, 0 } ,												
{ "Air Buster (Japan)"                                                                                    ,"airbustr"     , "mame", 3, 0 } ,												
{ "Air Duel (Japan)"                                                                                      ,"airduel"      , "mame", 1, 0 } ,												
{ "Air Wolf"                                                                                              ,"airwolf"      , "mame", 3, 0 } ,												
{ "Ajax (Japan)"                                                                                          ,"ajaxj"        , "mame", 3, 0 } ,												
{ "Ajax"                                                                                                  ,"ajax"         , "mame", 3, 0 } ,												
{ "Akuma-Jou Dracula (Japan)"                                                                             ,"hcastlej"     , "mame", 3, 0 } ,												
{ "Alcon"                                                                                                 ,"alcon"        , "mame", 3, 0 } ,												
{ "Ales no Tsubasa (Japan)"                                                                               ,"lwingsjp"     , "mame", 5, 0 } ,												
{ "Alex Kidd (set 1)"                                                                                     ,"alexkidd"     , "mame", 3, 0 } ,												
{ "Alex Kidd (set 2)"                                                                                     ,"alexkida"     , "mame", 3, 0 } ,												
{ "Ali Baba and 40 Thieves"                                                                               ,"alibaba"      , "mame", 3, 0 } ,												
{ "Alien Invasion Part II"                                                                                ,"alieninv"     , "mame", 3, 0 } ,												
{ "Alien Storm (2 Player)"                                                                                ,"astorm2p"     , "mame", 1, 0 } ,												
{ "Alien Storm (bootleg)"                                                                                 ,"astormbl"     , "mame", 1, 0 } ,												
{ "Alien Storm"                                                                                           ,"astorm"       , "mame", 1, 0 } ,												
{ "Alien Syndrome (Japan)"                                                                                ,"aliensyj"     , "mame", 1, 0 } ,												
{ "Alien Syndrome (set 1)"                                                                                ,"aliensyn"     , "mame", 1, 0 } ,												
{ "Alien Syndrome (set 2)"                                                                                ,"aliensya"     , "mame", 1, 0 } ,												
{ "Alien Syndrome (set 3)"                                                                                ,"aliensyb"     , "mame", 1, 0 } ,												
{ "Aliens (Japan)"                                                                                        ,"aliensj"      , "mame", 3, 0 } ,												
{ "Aliens (US)"                                                                                           ,"aliensu"      , "mame", 3, 0 } ,												
{ "Aliens (World set 1)"                                                                                  ,"aliens"       , "mame", 3, 0 } ,												
{ "Aliens (World set 2)"                                                                                  ,"aliens2"      , "mame", 3, 0 } ,												
{ "All American Football (rev B)"                                                                         ,"aafbb"        , "mame", 3, 0 } ,												
{ "All American Football (rev D, 2 Players)"                                                              ,"aafbd2p"      , "mame", 3, 0 } ,												
{ "All American Football (rev E)"                                                                         ,"aafb"         , "mame", 3, 0 } ,												
{ "Alley Master"                                                                                          ,"alleymas"     , "mame", 1, 0 } ,												
{ "Alpha Mission II / ASO II - Last Guardian"                                                             ,"alpham2"      , "neomame", 3, 0 } ,												
{ "Alpine Ski (set 1)"                                                                                    ,"alpine"       , "mame", 3, 0 } ,												
{ "Alpine Ski (set 2)"                                                                                    ,"alpinea"      , "mame", 3, 0 } ,												
{ "Altered Beast (Version 1)"                                                                             ,"altbeast"     , "mame", 1, 0 } ,												
{ "Altered Beast (Version 2)"                                                                             ,"altbeas2"     , "mame", 1, 0 } ,												
{ "Amazing Maze"                                                                                          ,"maze"         , "mame", 3, 0 } ,												
{ "Ambush"                                                                                                ,"ambush"       , "mame", 3, 0 } ,												
{ "American Horseshoes (US)"                                                                              ,"horshoes"     , "mame", 3, 0 } ,												
{ "Amidar (Olympia)"                                                                                      ,"amidaro"      , "mame", 3, 0 } ,												
{ "Amidar (Scramble hardware)"                                                                            ,"amidars"      , "mame", 3, 0 } ,												
{ "Amidar (Stern)"                                                                                        ,"amidaru"      , "mame", 3, 0 } ,												
{ "Amidar"                                                                                                ,"amidar"       , "mame", 3, 0 } ,												
{ "Amigo"                                                                                                 ,"amigo"        , "mame", 3, 0 } ,												
{ "Andro Dunos"                                                                                           ,"androdun"     , "neomame", 3, 0 } ,												
{ "Anteater"                                                                                              ,"anteater"     , "mame", 3, 0 } ,												
{ "Appoooh"                                                                                               ,"appoooh"      , "mame", 3, 0 } ,												
{ "Arabian (Atari)"                                                                                       ,"arabiana"     , "mame", 3, 0 } ,												
{ "Arabian"                                                                                               ,"arabian"      , "mame", 3, 0 } ,												
{ "Arbalester"                                                                                            ,"arbalest"     , "mame", 3, 0 } ,												
{ "Arcade Classics (prototype)"                                                                           ,"arcadecl"     , "mame", 3, 0 } ,												
{ "Arch Rivals (rev 2.0)"                                                                                 ,"archriv2"     , "mame", 3, 0 } ,												
{ "Arch Rivals (rev 4.0)"                                                                                 ,"archrivl"     , "mame", 3, 0 } ,												
{ "Area 88 (Japan)"                                                                                       ,"area88"       , "mame", 3, 0 } ,												
{ "Argus"                                                                                                 ,"argus"        , "mame", 1, 0 } ,												
{ "Argus no Senshi (Japan)"                                                                               ,"rygarj"       , "mame", 3, 0 } ,												
{ "Ark Area"                                                                                              ,"arkarea"      , "mame", 1, 0 } ,												
{ "Arkanoid (Game Corporation bootleg)"                                                                   ,"arkangc"      , "mame", 3, 0 } ,												
{ "Arkanoid (Japan)"                                                                                      ,"arknoidj"     , "mame", 3, 0 } ,												
{ "Arkanoid (Japanese bootleg Set 2)"                                                                     ,"arkbl2"       , "mame", 3, 0 } ,												
{ "Arkanoid (Tayto bootleg, Japanese)"                                                                    ,"arkatayt"     , "mame", 3, 0 } ,												
{ "Arkanoid (US)"                                                                                         ,"arknoidu"     , "mame", 3, 0 } ,												
{ "Arkanoid (World)"                                                                                      ,"arkanoid"     , "mame", 3, 0 } ,												
{ "Arkanoid - Revenge of DOH (Japan)"                                                                     ,"ark2jp"       , "mame", 3, 0 } ,												
{ "Arkanoid - Revenge of DOH (US)"                                                                        ,"ark2us"       , "mame", 3, 0 } ,												
{ "Arkanoid - Revenge of DOH (World)"                                                                     ,"arkanoi2"     , "mame", 3, 0 } ,												
{ "Arm Wrestling"                                                                                         ,"armwrest"     , "mame", 1, 0 } ,												
{ "Armed Formation"                                                                                       ,"armedf"       , "mame", 3, 0 } ,												
{ "Armor Attack"                                                                                          ,"armora"       , "mame", 3, 0 } ,												
{ "Armored Car (set 1)"                                                                                   ,"armorcar"     , "mame", 3, 0 } ,												
{ "Armored Car (set 2)"                                                                                   ,"armorca2"     , "mame", 3, 0 } ,												
{ "Art of Fighting / Ryuuko no Ken"                                                                       ,"aof"          , "neomame", 3, 0 } ,												
{ "Art of Fighting 2 / Ryuuko no Ken 2"                                                                   ,"aof2"         , "neomame", 3, 0 } ,												
{ "Art of Fighting 3 - The Path of the Warrior / Art of Fighting - Ryuuko no Ken Gaiden"                  ,"aof3"         , "neomame", 3, 0 } ,												
{ "Ashura Blaster (Japan)"                                                                                ,"ashura"       , "mame", 3, 0 } ,												
{ "Ashura Blaster (US)"                                                                                   ,"ashurau"      , "mame", 3, 0 } ,												
{ "Assault (Japan)"                                                                                       ,"assaultj"     , "mame", 3, 0 } ,												
{ "Assault Plus (Japan)"                                                                                  ,"assaultp"     , "mame", 3, 0 } ,												
{ "Assault"                                                                                               ,"assault"      , "mame", 3, 0 } ,												
{ "Asteroids (bootleg on Lunar Lander hardware)"                                                          ,"asteroib"     , "mame", 3, 0 } ,												
{ "Asteroids (rev 1)"                                                                                     ,"asteroi1"     , "mame", 3, 0 } ,												
{ "Asteroids (rev 2)"                                                                                     ,"asteroid"     , "mame", 3, 0 } ,												
{ "Asteroids Deluxe (rev 1)"                                                                              ,"astdelu1"     , "mame", 3, 0 } ,												
{ "Asteroids Deluxe (rev 2)"                                                                              ,"astdelux"     , "mame", 3, 0 } ,												
{ "Astro Blaster (version 1)"                                                                             ,"astrob1"      , "mame", 1, 0 } ,												
{ "Astro Blaster (version 2)"                                                                             ,"astrob2"      , "mame", 1, 0 } ,												
{ "Astro Blaster (version 3)"                                                                             ,"astrob"       , "mame", 1, 0 } ,												
{ "Astro Fighter (set 1)"                                                                                 ,"astrof"       , "mame", 3, 0 } ,												
{ "Astro Fighter (set 2)"                                                                                 ,"astrof2"      , "mame", 3, 0 } ,												
{ "Astro Fighter (set 3)"                                                                                 ,"astrof3"      , "mame", 3, 0 } ,												
{ "Astro Invader"                                                                                         ,"astinvad"     , "mame", 3, 0 } ,												
{ "Astyanax, The"                                                                                         ,"astyanax"     , "mame", 3, 0 } ,												
{ "Atari Baseball (set 1)"                                                                                ,"abaseb"       , "mame", 3, 0 } ,												
{ "Atari Baseball (set 2)"                                                                                ,"abaseb2"      , "mame", 3, 0 } ,												
{ "Atari Football (4 players)"                                                                            ,"atarifb4"     , "mame", 3, 0 } ,												
{ "Atari Football (revision 1)"                                                                           ,"atarifb1"     , "mame", 3, 0 } ,												
{ "Atari Football (revision 2)"                                                                           ,"atarifb"      , "mame", 3, 0 } ,												
{ "Atari Soccer"                                                                                          ,"soccer"       , "mame", 3, 0 } ,												
{ "Ataxx (Japan)"                                                                                         ,"ataxxj"       , "mame", 1, 0 } ,												
{ "Ataxx (set 1)"                                                                                         ,"ataxx"        , "mame", 1, 0 } ,												
{ "Ataxx (set 2)"                                                                                         ,"ataxxa"       , "mame", 1, 0 } ,												
{ "Athena"                                                                                                ,"athena"       , "mame", 3, 0 } ,												
{ "Atomic Point"                                                                                          ,"atomicp"      , "mame", 3, 0 } ,												
{ "Aurail (set 1)"                                                                                        ,"aurail"       , "mame", 1, 0 } ,												
{ "Aurail (set 2)"                                                                                        ,"auraila"      , "mame", 1, 0 } ,												
{ "Avalanche"                                                                                             ,"avalnche"     , "mame", 3, 0 } ,												
{ "Avengers (set 1)"                                                                                      ,"avengers"     , "mame", 3, 0 } ,												
{ "Avengers (set 2)"                                                                                      ,"avenger2"     , "mame", 3, 0 } ,												
{ "Avenging Spirit"                                                                                       ,"avspirit"     , "mame", 3, 0 } ,												
{ "Aztarac"                                                                                               ,"aztarac"      , "mame", 3, 0 } ,												
{ "Azurian Attack"                                                                                        ,"azurian"      , "mame", 3, 0 } ,												
{ "Bad Dudes vs. Dragonninja (US)"                                                                        ,"baddudes"     , "mame", 3, 0 } ,												
{ "Bad Lands"                                                                                             ,"badlands"     , "mame", 3, 0 } ,												
{ "Bagman (Stern set 1)"                                                                                  ,"bagmans"      , "mame", 3, 0 } ,												
{ "Bagman (Stern set 2)"                                                                                  ,"bagmans2"     , "mame", 3, 0 } ,												
{ "Bagman"                                                                                                ,"bagman"       , "mame", 3, 0 } ,												
{ "Bakatonosama Mahjong Manyuki"                                                                          ,"bakatono"     , "neomame", 3, 0 } ,												
{ "Balloon Bomber"                                                                                        ,"ballbomb"     , "mame", 3, 0 } ,												
{ "Baluba-louk no Densetsu"                                                                               ,"baluba"       , "mame", 1, 0 } ,												
{ "Bandido"                                                                                               ,"bandido"      , "mame", 3, 0 } ,												
{ "Bank Panic"                                                                                            ,"bankp"        , "mame", 3, 0 } ,												
{ "Baraduke"                                                                                              ,"baraduke"     , "mame", 3, 0 } ,												
{ "Barrier"                                                                                               ,"barrier"      , "mame", 3, 0 } ,												
{ "Baseball Stars 2"                                                                                      ,"bstars2"      , "neomame", 3, 0 } ,												
{ "Baseball Stars Professional"                                                                           ,"bstars"       , "neomame", 3, 0 } ,												
{ "Baseball The Season II"                                                                                ,"basebal2"     , "mame", 1, 0 } ,												
{ "Basketball"                                                                                            ,"bsktball"     , "mame", 3, 0 } ,												
{ "Batman"                                                                                                ,"batman"       , "mame", 3, 0 } ,												
{ "Batsugun"                                                                                              ,"batsugun"     , "mame", 1, 0 } ,												
{ "Batsugun Special Ver."                                                                                 ,"batugnsp"     , "mame", 3, 0 } ,												
{ "Battlantis (Japan)"                                                                                    ,"battlntj"     , "mame", 3, 0 } ,												
{ "Battlantis"                                                                                            ,"battlnts"     , "mame", 3, 0 } ,												
{ "Battle Chopper"                                                                                        ,"bchopper"     , "mame", 1, 0 } ,												
{ "Battle Field (Japan)"                                                                                  ,"btlfield"     , "mame", 3, 0 } ,												
{ "Battle Flip Shot"                                                                                      ,"flipshot"     , "neomame", 3, 0 } ,												
{ "Battle Lane Vol. 5 (set 1)"                                                                            ,"battlane"     , "mame", 3, 0 } ,												
{ "Battle Lane Vol. 5 (set 2)"                                                                            ,"battlan2"     , "mame", 3, 0 } ,												
{ "Battle Lane Vol. 5 (set 3)"                                                                            ,"battlan3"     , "mame", 3, 0 } ,												
{ "Battle Rangers (World)"                                                                                ,"battlera"     , "mame", 3, 0 } ,												
{ "Battle Zone (set 1)"                                                                                   ,"bzone"        , "mame", 3, 0 } ,												
{ "Battle Zone (set 2)"                                                                                   ,"bzone2"       , "mame", 3, 0 } ,												
{ "Battle of Atlantis (set 1)"                                                                            ,"atlantis"     , "mame", 3, 0 } ,												
{ "Battle of Atlantis (set 2)"                                                                            ,"atlants2"     , "mame", 3, 0 } ,												
{ "Battle-Road, The"                                                                                      ,"battroad"     , "mame", 3, 0 } ,												
{ "Bay Route (bootleg set 1)"                                                                             ,"bayrtbl1"     , "mame", 3, 0 } ,												
{ "Bay Route (bootleg set 2)"                                                                             ,"bayrtbl2"     , "mame", 3, 0 } ,												
{ "Bay Route (set 1)"                                                                                     ,"bayroute"     , "mame", 3, 0 } ,												
{ "Bay Route (set 2)"                                                                                     ,"bayrouta"     , "mame", 3, 0 } ,												
{ "Beastie Feastie"                                                                                       ,"beastf"       , "mame", 1, 0 } ,												
{ "Bells & Whistles"                                                                                      ,"blswhstl"     , "mame", 3, 0 } ,												
{ "Beraboh Man (Japan)"                                                                                   ,"berabohm"     , "mame", 3, 0 } ,												
{ "Berlin Wall, The (set 1)"                                                                              ,"berlwall"     , "mame", 3, 0 } ,												
{ "Berlin Wall, The (set 2)"                                                                              ,"berlwalt"     , "mame", 3, 0 } ,												
{ "Bermuda Triangle (Japan)"                                                                              ,"bermudaj"     , "mame", 3, 0 } ,												
{ "Bermuda Triangle (US early version)"                                                                   ,"bermudaa"     , "mame", 3, 0 } ,												
{ "Bermuda Triangle (US)"                                                                                 ,"bermudat"     , "mame", 3, 0 } ,												
{ "Berzerk (set 1)"                                                                                       ,"berzerk"      , "mame", 3, 0 } ,												
{ "Berzerk (set 2)"                                                                                       ,"berzerk1"     , "mame", 3, 0 } ,												
{ "Big Karnak"                                                                                            ,"bigkarnk"     , "mame", 3, 0 } ,												
{ "Big Pro Wrestling!, The"                                                                               ,"bigprowr"     , "mame", 3, 0 } ,												
{ "Big Striker"                                                                                           ,"bigstrik"     , "mame", 3, 0 } ,												
{ "Billiards, The"                                                                                        ,"billiard"     , "mame", 3, 0 } ,												
{ "Bio Attack"                                                                                            ,"bioatack"     , "mame", 3, 0 } ,												
{ "Biomechanical Toy (unprotected)"                                                                       ,"biomtoy"      , "mame", 3, 0 } ,												
{ "Bionic Commando (US set 1)"                                                                            ,"bionicc"      , "mame", 3, 0 } ,												
{ "Bionic Commando (US set 2)"                                                                            ,"bionicc2"     , "mame", 3, 0 } ,												
{ "Birdie King 2"                                                                                         ,"bking2"       , "mame", 3, 0 } ,												
{ "Black Dragon (bootleg)"                                                                                ,"blkdrgnb"     , "mame", 3, 0 } ,												
{ "Black Dragon"                                                                                          ,"blkdrgon"     , "mame", 3, 0 } ,												
{ "Black Hole"                                                                                            ,"blkhole"      , "mame", 3, 0 } ,												
{ "Black Tiger (bootleg)"                                                                                 ,"bktigerb"     , "mame", 3, 0 } ,												
{ "Black Tiger"                                                                                           ,"blktiger"     , "mame", 3, 0 } ,												
{ "Black Widow"                                                                                           ,"bwidow"       , "mame", 3, 0 } ,												
{ "Blade Master (World)"                                                                                  ,"bmaster"      , "mame", 3, 0 } ,												
{ "Blades of Steel (version E)"                                                                           ,"bladstle"     , "mame", 3, 0 } ,												
{ "Blades of Steel (version T)"                                                                           ,"bladestl"     , "mame", 3, 0 } ,												
{ "Blandia [Prototype]"                                                                                   ,"blandia"      , "mame", 3, 0 } ,												
{ "Blast Off (Japan)"                                                                                     ,"blastoff"     , "mame", 3, 0 } ,												
{ "Blasted"                                                                                               ,"blasted"      , "mame", 3, 0 } ,												
{ "Blaster"                                                                                               ,"blaster"      , "mame", 3, 0 } ,												
{ "Blasteroids (version 2)"                                                                               ,"blstroi2"     , "mame", 3, 0 } ,												
{ "Blasteroids (version 4)"                                                                               ,"blstroid"     , "mame", 3, 0 } ,												
{ "Blasteroids (with heads)"                                                                              ,"blsthead"     , "mame", 3, 0 } ,												
{ "Blasto"                                                                                                ,"blasto"       , "mame", 3, 0 } ,												
{ "Blazer (Japan)"                                                                                        ,"blazer"       , "mame", 3, 0 } ,												
{ "Blazing Star"                                                                                          ,"blazstar"     , "neomame", 3, 0 } ,												
{ "Block (Game Corporation bootleg)"                                                                      ,"arkbloc2"     , "mame", 3, 0 } ,												
{ "Block Block (Japan)"                                                                                   ,"blockj"       , "mame", 1, 0 } ,												
{ "Block Block (World)"                                                                                   ,"block"        , "mame", 1, 0 } ,												
{ "Block Block (bootleg)"                                                                                 ,"blockbl"      , "mame", 1, 0 } ,												
{ "Block Gal (bootleg)"                                                                                   ,"blckgalb"     , "mame", 3, 0 } ,												
{ "Block Gal"                                                                                             ,"blockgal"     , "mame", 3, 0 } ,												
{ "Block Hole"                                                                                            ,"blockhl"      , "mame", 3, 0 } ,												
{ "Block Out (set 1)"                                                                                     ,"blockout"     , "mame", 3, 0 } ,												
{ "Block Out (set 2)"                                                                                     ,"blckout2"     , "mame", 3, 0 } ,												
{ "Blockade"                                                                                              ,"blockade"     , "mame", 3, 0 } ,												
{ "Blocken (Japan)"                                                                                       ,"blocken"      , "mame", 3, 0 } ,												
{ "Blood Bros."                                                                                           ,"bloodbro"     , "mame", 1, 0 } ,												
{ "Bloody Wolf (US)"                                                                                      ,"bldwolf"      , "mame", 3, 0 } ,												
{ "Blue Print (Jaleco)"                                                                                   ,"blueprnj"     , "mame", 3, 0 } ,												
{ "Blue Print (Midway)"                                                                                   ,"blueprnt"     , "mame", 3, 0 } ,												
{ "Blue Shark"                                                                                            ,"blueshrk"     , "mame", 3, 0 } ,												
{ "Blue's Journey / Raguy"                                                                                ,"bjourney"     , "neomame", 3, 0 } ,												
{ "Bobble Bobble"                                                                                         ,"boblbobl"     , "mame", 3, 0 } ,												
{ "Body Slam"                                                                                             ,"bodyslam"     , "mame", 1, 0 } ,												
{ "Bogey Manor"                                                                                           ,"bogeyman"     , "mame", 3, 0 } ,												
{ "Bomb Bee"                                                                                              ,"bombbee"      , "mame", 3, 0 } ,												
{ "Bomb Jack (set 1)"                                                                                     ,"bombjack"     , "mame", 3, 0 } ,												
{ "Bomb Jack (set 2)"                                                                                     ,"bombjac2"     , "mame", 3, 0 } ,												
{ "Bombjack Twin"                                                                                         ,"bjtwin"       , "mame", 3, 0 } ,												
{ "Boot Camp"                                                                                             ,"bootcamp"     , "mame", 3, 0 } ,												
{ "Boot Hill"                                                                                             ,"boothill"     , "mame", 3, 0 } ,												
{ "Bosconian (Midway, new version)"                                                                       ,"boscomd"      , "mame", 3, 0 } ,												
{ "Bosconian (Midway, old version)"                                                                       ,"boscomdo"     , "mame", 3, 0 } ,												
{ "Bosconian (new version)"                                                                               ,"bosco"        , "mame", 3, 0 } ,												
{ "Bosconian (old version)"                                                                               ,"boscoo"       , "mame", 3, 0 } ,												
{ "Bosconian (older version)"                                                                             ,"boscoo2"      , "mame", 3, 0 } ,												
{ "Bottom of the Ninth (version N)"                                                                       ,"bottom9n"     , "mame", 3, 0 } ,												
{ "Bottom of the Ninth (version T)"                                                                       ,"bottom9"      , "mame", 3, 0 } ,												
{ "Boulder Dash / Boulder Dash Part 2 (World)"                                                            ,"bouldash"     , "mame", 3, 0 } ,												
{ "Bowl-O-Rama"                                                                                           ,"bowlrama"     , "mame", 3, 0 } ,												
{ "Boxing Bugs"                                                                                           ,"boxingb"      , "mame", 3, 0 } ,												
{ "Brain"                                                                                                 ,"brain"        , "mame", 3, 0 } ,												
{ "Break Thru (US)"                                                                                       ,"brkthru"      , "mame", 3, 0 } ,												
{ "Breakers Revenge"                                                                                      ,"breakrev"     , "neomame", 3, 0 } ,												
{ "Breakers"                                                                                              ,"breakers"     , "neomame", 3, 0 } ,												
{ "Breywood (Japan revision 2)"                                                                           ,"breywood"     , "mame", 3, 0 } ,												
{ "Brix"                                                                                                  ,"brix"         , "mame", 3, 0 } ,												
{ "Brute Force"                                                                                           ,"brutforc"     , "mame", 1, 0 } ,												
{ "Bubble Bobble (US with mode select)"                                                                   ,"bublbobr"     , "mame", 3, 0 } ,												
{ "Bubble Bobble (US)"                                                                                    ,"bubbobr1"     , "mame", 3, 0 } ,												
{ "Bubble Bobble"                                                                                         ,"bublbobl"     , "mame", 3, 0 } ,												
{ "Bubbles (Solid Red label)"                                                                             ,"bubblesr"     , "mame", 3, 0 } ,												
{ "Bubbles"                                                                                               ,"bubbles"      , "mame", 3, 0 } ,												
{ "Bump 'n' Jump"                                                                                         ,"bnj"          , "mame", 3, 0 } ,												
{ "Burger Time (Data East set 1)"                                                                         ,"btime"        , "mame", 3, 0 } ,												
{ "Burger Time (Data East set 2)"                                                                         ,"btime2"       , "mame", 3, 0 } ,												
{ "Burger Time (Midway)"                                                                                  ,"btimem"       , "mame", 3, 0 } ,												
{ "Burnin' Rubber"                                                                                        ,"brubber"      , "mame", 3, 0 } ,												
{ "Burning Fight (set 1)"                                                                                 ,"burningf"     , "neomame", 3, 0 } ,												
{ "Burning Fight (set 2)"                                                                                 ,"burningh"     , "neomame", 3, 0 } ,												
{ "Burning Force (Japan)"                                                                                 ,"burnforc"     , "mame", 3, 0 } ,												
{ "Buster Bros (US)"                                                                                      ,"bbros"        , "mame", 1, 0 } ,												
{ "Butasan (Japan)"                                                                                       ,"butasan"      , "mame", 1, 0 } ,												
{ "Cabal (US set 1)"                                                                                      ,"cabal"        , "mame", 3, 0 } ,												
{ "Cabal (US set 2)"                                                                                      ,"cabal2"       , "mame", 3, 0 } ,												
{ "Cabal (bootleg)"                                                                                       ,"cabalbl"      , "mame", 3, 0 } ,												
{ "Cachat (Japan)"                                                                                        ,"cachat"       , "mame", 3, 0 } ,												
{ "Cadillacs Kyouryuu-Shinseiki (Japan)"                                                                  ,"dinoj"        , "mame", 1, 0 } ,												
{ "Cadillacs and Dinosaurs (World)"                                                                       ,"dino"         , "mame", 1, 0 } ,												
{ "Caliber 50"                                                                                            ,"calibr50"     , "mame", 3, 0 } ,												
{ "Calipso"                                                                                               ,"calipso"      , "mame", 3, 0 } ,												
{ "Camel Try (Japan)"                                                                                     ,"cameltry"     , "mame", 3, 0 } ,												
{ "Camel Try (US)"                                                                                        ,"cameltru"     , "mame", 3, 0 } ,												
{ "Canyon Bomber (prototype)"                                                                             ,"canbprot"     , "mame", 3, 0 } ,												
{ "Canyon Bomber"                                                                                         ,"canyon"       , "mame", 3, 0 } ,												
{ "Capcom Baseball (Japan)"                                                                               ,"cbasebal"     , "mame", 1, 0 } ,												
{ "Capcom Bowling (set 1)"                                                                                ,"capbowl"      , "mame", 3, 0 } ,												
{ "Capcom Bowling (set 2)"                                                                                ,"capbowl2"     , "mame", 3, 0 } ,												
{ "Capcom World (Japan)"                                                                                  ,"cworld"       , "mame", 1, 0 } ,												
{ "Capcom World 2 (Japan)"                                                                                ,"cworld2j"     , "mame", 3, 0 } ,												
{ "Captain Commando (Japan)"                                                                              ,"captcomj"     , "mame", 3, 0 } ,												
{ "Captain Commando (US)"                                                                                 ,"captcomu"     , "mame", 3, 0 } ,												
{ "Captain Commando (World)"                                                                              ,"captcomm"     , "mame", 3, 0 } ,												
{ "Captain Silver (Japan)"                                                                                ,"csilver"      , "mame", 3, 0 } ,												
{ "Car Action"                                                                                            ,"caractn"      , "mame", 3, 0 } ,												
{ "Carnival (cocktail)"                                                                                   ,"carnvckt"     , "mame", 3, 0 } ,												
{ "Carnival (upright)"                                                                                    ,"carnival"     , "mame", 3, 0 } ,												
{ "Carrier Air Wing (World)"                                                                              ,"cawing"       , "mame", 3, 0 } ,												
{ "Caveman Ninja (US)"                                                                                    ,"cninjau"      , "mame", 3, 0 } ,												
{ "Caveman Ninja (World revision 0)"                                                                      ,"cninja0"      , "mame", 3, 0 } ,												
{ "Caveman Ninja (World revision 3)"                                                                      ,"cninja"       , "mame", 3, 0 } ,												
{ "Centipede (bootleg set 1)"                                                                             ,"centipdb"     , "mame", 3, 0 } ,												
{ "Centipede (bootleg set 2)"                                                                             ,"centipb2"     , "mame", 3, 0 } ,												
{ "Centipede (revision 2)"                                                                                ,"centipd2"     , "mame", 3, 0 } ,												
{ "Centipede (revision 3)"                                                                                ,"centiped"     , "mame", 3, 0 } ,												
{ "Cerberus"                                                                                              ,"cerberus"     , "mame", 1, 0 } ,												
{ "Challenger"                                                                                            ,"challeng"     , "mame", 3, 0 } ,												
{ "Champion Baseball (Japan)"                                                                             ,"champbbj"     , "mame", 3, 0 } ,												
{ "Champion Baseball II"                                                                                  ,"champbb2"     , "mame", 3, 0 } ,												
{ "Champion Baseball"                                                                                     ,"champbas"     , "mame", 3, 0 } ,												
{ "Champion Wrestler (Japan)"                                                                             ,"champwrj"     , "mame", 1, 0 } ,												
{ "Champion Wrestler (US)"                                                                                ,"champwru"     , "mame", 1, 0 } ,												
{ "Champion Wrestler (World)"                                                                             ,"champwr"      , "mame", 1, 0 } ,												
{ "Championship Sprint"                                                                                   ,"csprint"      , "mame", 3, 0 } ,												
{ "Changes"                                                                                               ,"changes"      , "mame", 3, 0 } ,												
{ "Checkman (Japan)"                                                                                      ,"checkmaj"     , "mame", 3, 0 } ,												
{ "Checkman"                                                                                              ,"checkman"     , "mame", 3, 0 } ,												
{ "Checkmate"                                                                                             ,"checkmat"     , "mame", 3, 0 } ,												
{ "Cheeky Mouse"                                                                                          ,"cheekyms"     , "mame", 3, 0 } ,												
{ "Chelnov - Atomic Runner (Japan)"                                                                       ,"chelnovj"     , "mame", 3, 0 } ,												
{ "Chelnov - Atomic Runner (US)"                                                                          ,"chelnov"      , "mame", 3, 0 } ,												
{ "Cheyenne (version 1.0)"                                                                                ,"cheyenne"     , "mame", 3, 0 } ,												
{ "Chibi Marukochan Deluxe Quiz"                                                                          ,"marukodq"     , "neomame", 3, 0 } ,												
{ "Chicken Shift"                                                                                         ,"cshift"       , "mame", 3, 0 } ,												
{ "Chiki Chiki Boys (Japan)"                                                                              ,"chikij"       , "mame", 3, 0 } ,												
{ "Chiller (version 3.0)"                                                                                 ,"chiller"      , "mame", 3, 0 } ,												
{ "Chimera Beast"                                                                                         ,"chimerab"     , "mame", 3, 0 } ,												
{ "Choplifter (alternate)"                                                                                ,"chplftb"      , "mame", 5, 0 } ,												
{ "Choplifter (bootleg)"                                                                                  ,"chplftbl"     , "mame", 5, 0 } ,												
{ "Choplifter"                                                                                            ,"chplft"       , "mame", 5, 0 } ,												
{ "Chopper I"                                                                                             ,"chopper"      , "mame", 3, 0 } ,												
{ "Chuka Taisen (Japan)"                                                                                  ,"chukatai"     , "mame", 3, 0 } ,												
{ "Circus Charlie (Centuri)"                                                                              ,"circuscc"     , "mame", 3, 0 } ,												
{ "Circus Charlie (Centuri, earlier)"                                                                     ,"circusce"     , "mame", 3, 0 } ,												
{ "Circus Charlie (no level select)"                                                                      ,"circusc2"     , "mame", 3, 0 } ,												
{ "Circus Charlie"                                                                                        ,"circusc"      , "mame", 3, 0 } ,												
{ "Circus"                                                                                                ,"circus"       , "mame", 3, 0 } ,												
{ "Cisco Heat"                                                                                            ,"cischeat"     , "mame", 3, 0 } ,												
{ "City Connection (set 1)"                                                                               ,"citycon"      , "mame", 3, 0 } ,												
{ "City Connection (set 2)"                                                                               ,"citycona"     , "mame", 3, 0 } ,												
{ "Clay Pigeon (version 2.0)"                                                                             ,"claypign"     , "mame", 3, 0 } ,												
{ "Cloak & Dagger"                                                                                        ,"cloak"        , "mame", 3, 0 } ,												
{ "Cloud 9 (prototype)"                                                                                   ,"cloud9"       , "mame", 3, 0 } ,												
{ "Clowns"                                                                                                ,"clowns"       , "mame", 3, 0 } ,												
{ "Cobra-Command (Japan)"                                                                                 ,"cobracmj"     , "mame", 3, 0 } ,												
{ "Cobra-Command (World revision 5)"                                                                      ,"cobracom"     , "mame", 3, 0 } ,												
{ "Colony 7 (set 1)"                                                                                      ,"colony7"      , "mame", 3, 0 } ,												
{ "Colony 7 (set 2)"                                                                                      ,"colony7a"     , "mame", 3, 0 } ,												
{ "Combat (version 3.0)"                                                                                  ,"combat"       , "mame", 3, 0 } ,												
{ "Combat School (Japan trackball)"                                                                       ,"combascj"     , "mame", 3, 0 } ,												
{ "Combat School (bootleg)"                                                                               ,"combascb"     , "mame", 3, 0 } ,												
{ "Combat School (joystick)"                                                                              ,"combasc"      , "mame", 3, 0 } ,												
{ "Combat School (trackball)"                                                                             ,"combasct"     , "mame", 3, 0 } ,												
{ "Combatribes, The (US)"                                                                                 ,"ctribe"       , "mame", 3, 0 } ,												
{ "Combatribes, The (bootleg)"                                                                            ,"ctribeb"      , "mame", 3, 0 } ,												
{ "Commando (Sega)"                                                                                       ,"commsega"     , "mame", 3, 0 } ,												
{ "Commando (US)"                                                                                         ,"commandu"     , "mame", 5, 0 } ,												
{ "Commando (World)"                                                                                      ,"commando"     , "mame", 5, 0 } ,												
{ "Comotion"                                                                                              ,"comotion"     , "mame", 3, 0 } ,												
{ "Congo Bongo"                                                                                           ,"congo"        , "mame", 3, 0 } ,												
{ "Contra (Japan bootleg)"                                                                                ,"contrajb"     , "mame", 3, 0 } ,												
{ "Contra (Japan)"                                                                                        ,"contraj"      , "mame", 3, 0 } ,												
{ "Contra (US bootleg)"                                                                                   ,"contrab"      , "mame", 3, 0 } ,												
{ "Contra (US)"                                                                                           ,"contra"       , "mame", 3, 0 } ,												
{ "Cook Race"                                                                                             ,"cookrace"     , "mame", 3, 0 } ,												
{ "Coors Light Bowling"                                                                                   ,"clbowl"       , "mame", 3, 0 } ,												
{ "Cop 01 (set 1)"                                                                                        ,"cop01"        , "mame", 5, 0 } ,												
{ "Cop 01 (set 2)"                                                                                        ,"cop01a"       , "mame", 5, 0 } ,												
{ "Cops'n Robbers"                                                                                        ,"copsnrob"     , "mame", 3, 0 } ,												
{ "Cosmic Alien (older)"                                                                                  ,"cosmica2"     , "mame", 3, 0 } ,												
{ "Cosmic Alien"                                                                                          ,"cosmica"      , "mame", 3, 0 } ,												
{ "Cosmic Avenger"                                                                                        ,"cavenger"     , "mame", 3, 0 } ,												
{ "Cosmic Chasm (set 1)"                                                                                  ,"cchasm"       , "mame", 1, 0 } ,												
{ "Cosmic Chasm (set 2)"                                                                                  ,"cchasm1"      , "mame", 1, 0 } ,												
{ "Cosmic Guerilla"                                                                                       ,"cosmicg"      , "mame", 3, 0 } ,												
{ "Cosmic Monsters"                                                                                       ,"cosmicmo"     , "mame", 3, 0 } ,												
{ "Cosmo Gang the Video (Japan)"                                                                          ,"cosmognj"     , "mame", 3, 0 } ,												
{ "Cosmo Gang the Video (US)"                                                                             ,"cosmogng"     , "mame", 3, 0 } ,												
{ "Cotocoto Cottong"                                                                                      ,"cottong"      , "mame", 3, 0 } ,												
{ "Crackshot (version 2.0)"                                                                               ,"cracksht"     , "mame", 3, 0 } ,												
{ "Crash"                                                                                                 ,"crash"        , "mame", 3, 0 } ,												
{ "Crater Raider"                                                                                         ,"crater"       , "mame", 5, 0 } ,												
{ "Crazy Balloon (set 1)"                                                                                 ,"crbaloon"     , "mame", 3, 0 } ,												
{ "Crazy Balloon (set 2)"                                                                                 ,"crbalon2"     , "mame", 3, 0 } ,												
{ "Crazy Blocks"                                                                                          ,"crazyblk"     , "mame", 3, 0 } ,												
{ "Crazy Climber (Japan)"                                                                                 ,"cclimbrj"     , "mame", 1, 0 } ,												
{ "Crazy Climber (US)"                                                                                    ,"cclimber"     , "mame", 1, 0 } ,												
{ "Crazy Climber (bootleg set 1)"                                                                         ,"ccboot"       , "mame", 1, 0 } ,												
{ "Crazy Climber (bootleg set 2)"                                                                         ,"ccboot2"      , "mame", 1, 0 } ,												
{ "Crazy Climber 2 (Japan)"                                                                               ,"cclimbr2"     , "mame", 3, 0 } ,												
{ "Crazy Cop (Japan)"                                                                                     ,"crazycop"     , "mame", 3, 0 } ,												
{ "Crazy Kong (Alca bootleg)"                                                                             ,"ckongalc"     , "mame", 3, 0 } ,												
{ "Crazy Kong (Jeutel bootleg)"                                                                           ,"ckongjeu"     , "mame", 3, 0 } ,												
{ "Crazy Kong (Orca bootleg)"                                                                             ,"ckongo"       , "mame", 3, 0 } ,												
{ "Crazy Kong (Scramble hardware)"                                                                        ,"ckongs"       , "mame", 3, 0 } ,												
{ "Crazy Kong (set 1)"                                                                                    ,"ckong"        , "mame", 3, 0 } ,												
{ "Crazy Kong (set 2)"                                                                                    ,"ckonga"       , "mame", 3, 0 } ,												
{ "Crime City (Japan)"                                                                                    ,"crimecj"      , "mame", 3, 0 } ,												
{ "Crime City (US)"                                                                                       ,"crimecu"      , "mame", 3, 0 } ,												
{ "Crime City (World)"                                                                                    ,"crimec"       , "mame", 3, 0 } ,												
{ "Crime Fighters (Japan 2 Players)"                                                                      ,"crimfgtj"     , "mame", 3, 0 } ,												
{ "Crime Fighters (US 4 players)"                                                                         ,"crimfght"     , "mame", 3, 0 } ,												
{ "Crime Fighters (World 2 Players)"                                                                      ,"crimfgt2"     , "mame", 3, 0 } ,												
{ "Crime Fighters 2 (Japan)"                                                                              ,"vendettj"     , "mame", 3, 0 } ,												
{ "Crossbow (version 2.0)"                                                                                ,"crossbow"     , "mame", 3, 0 } ,												
{ "Crossed Swords"                                                                                        ,"crsword"      , "neomame", 3, 0 } ,												
{ "Crude Buster (Japan)"                                                                                  ,"cbusterj"     , "mame", 3, 0 } ,												
{ "Crude Buster (World FU version)"                                                                       ,"cbusterw"     , "mame", 3, 0 } ,												
{ "Crude Buster (World FX version)"                                                                       ,"cbuster"      , "mame", 3, 0 } ,												
{ "Cruisin"                                                                                               ,"cruisin"      , "mame", 3, 0 } ,												
{ "Crush Roller (Kural - bootleg?)"                                                                       ,"crush3"       , "mame", 1, 0 } ,												
{ "Crush Roller (Kural Esco - bootleg?)"                                                                  ,"crush2"       , "mame", 1, 0 } ,												
{ "Crush Roller (Kural Samno)"                                                                            ,"crush"        , "mame", 1, 0 } ,												
{ "Crystal Castles (set 1)"                                                                               ,"ccastles"     , "mame", 3, 0 } ,												
{ "Crystal Castles (set 2)"                                                                               ,"ccastle2"     , "mame", 3, 0 } ,												
{ "Cuby Bop"                                                                                              ,"cubybop"      , "mame", 3, 0 } ,												
{ "Cuebrick"                                                                                              ,"cuebrick"     , "mame", 3, 0 } ,												
{ "Curve Ball"                                                                                            ,"curvebal"     , "mame", 3, 0 } ,												
{ "Cutie Q"                                                                                               ,"cutieq"       , "mame", 3, 0 } ,												
{ "Cybattler"                                                                                             ,"cybattlr"     , "mame", 3, 0 } ,												
{ "Cyber-Lip"                                                                                             ,"cyberlip"     , "neomame", 3, 0 } ,												
{ "Cyberball (Version 2)"                                                                                 ,"cyberba2"     , "mame", 3, 0 } ,												
{ "Cyberball (Version 4)"                                                                                 ,"cyberbal"     , "mame", 3, 0 } ,												
{ "Cyberball 2072 (2 player)"                                                                             ,"cyberb2p"     , "mame", 3, 0 } ,												
{ "D-Con"                                                                                                 ,"dcon"         , "mame", 1, 0 } ,												
{ "D-Day (Centuri)"                                                                                       ,"ddayc"        , "mame", 3, 0 } ,												
{ "D-Day"                                                                                                 ,"dday"         , "mame", 3, 0 } ,												
{ "Dai Makai-Mura (Japan)"                                                                                ,"ghoulsj"      , "mame", 3, 0 } ,												
{ "Dai Ressya Goutou (Japan)"                                                                             ,"dairesya"     , "mame", 3, 0 } ,												
{ "Daiku no Gensan (Japan)"                                                                               ,"dkgensan"     , "mame", 1, 0 } ,												
{ "DakkoChan Jansoh"                                                                                      ,"dakkochn"     , "mame", 3, 0 } ,												
{ "Dangar - Ufo Robo (12/1/1986)"                                                                         ,"dangar"       , "mame", 3, 0 } ,												
{ "Dangar - Ufo Robo (9/26/1986)"                                                                         ,"dangar2"      , "mame", 3, 0 } ,												
{ "Dangar - Ufo Robo (bootleg)"                                                                           ,"dangarb"      , "mame", 3, 0 } ,												
{ "Danger Zone"                                                                                           ,"dangerz"      , "mame", 3, 0 } ,												
{ "Dangerous Seed (Japan)"                                                                                ,"dangseed"     , "mame", 3, 0 } ,												
{ "Dangun Feveron (Japan)"                                                                                ,"dfeveron"     , "mame", 3, 0 } ,												
{ "Danny Sullivan's Indy Heat"                                                                            ,"indyheat"     , "mame", 3, 0 } ,												
{ "Dark Adventure"                                                                                        ,"darkadv"      , "mame", 3, 0 } ,												
{ "Dark Planet"                                                                                           ,"darkplnt"     , "mame", 3, 0 } ,												
{ "Dark Seal (Japan)"                                                                                     ,"darkseaj"     , "mame", 3, 0 } ,												
{ "Dark Seal (World revision 1)"                                                                          ,"darksea1"     , "mame", 3, 0 } ,												
{ "Dark Seal (World revision 3)"                                                                          ,"darkseal"     , "mame", 3, 0 } ,												
{ "Darwin 4078 (Japan)"                                                                                   ,"darwin"       , "mame", 3, 0 } ,												
{ "Datsugoku - Prisoners of War (Japan)"                                                                  ,"powj"         , "mame", 3, 0 } ,												
{ "Datsun 280 Zzzap"                                                                                      ,"280zzzap"     , "mame", 3, 0 } ,												
{ "Dead Connection (Japan)"                                                                               ,"deadconj"     , "mame", 3, 0 } ,												
{ "Dead Connection (World)"                                                                               ,"deadconx"     , "mame", 3, 0 } ,												
{ "Dead Eye"                                                                                              ,"deadeye"      , "mame", 3, 0 } ,												
{ "Defence Command"                                                                                       ,"defence"      , "mame", 3, 0 } ,												
{ "Defend the Terra Attack on the Red UFO (bootleg)"                                                      ,"redufo"       , "mame", 3, 0 } ,												
{ "Defender (Green label)"                                                                                ,"defendg"      , "mame", 3, 0 } ,												
{ "Defender (Red label)"                                                                                  ,"defender"     , "mame", 3, 0 } ,												
{ "Defender (White label)"                                                                                ,"defendw"      , "mame", 3, 0 } ,												
{ "Defense Command (set 1)"                                                                               ,"defcmnd"      , "mame", 3, 0 } ,												
{ "Demolition Derby (2-Player Mono Board Version)"                                                        ,"destderm"     , "mame", 1, 0 } ,												
{ "Demolition Derby"                                                                                      ,"destderb"     , "mame", 1, 0 } ,												
{ "Demon"                                                                                                 ,"demon"        , "mame", 3, 0 } ,												
{ "Demon's World / Horror Story"                                                                          ,"demonwld"     , "mame", 3, 0 } ,												
{ "Depthcharge"                                                                                           ,"depthch"      , "mame", 3, 0 } ,												
{ "Desert Gun"                                                                                            ,"desertgu"     , "mame", 3, 0 } ,												
{ "Destination Earth"                                                                                     ,"desterth"     , "mame", 3, 0 } ,												
{ "Detana!! Twin Bee (Japan)"                                                                             ,"detatwin"     , "mame", 3, 0 } ,												
{ "Devastators (version V)"                                                                               ,"devstor3"     , "mame", 3, 0 } ,												
{ "Devastators (version X)"                                                                               ,"devstor2"     , "mame", 3, 0 } ,												
{ "Devastators (version Z)"                                                                               ,"devstors"     , "mame", 3, 0 } ,												
{ "Devil Fish (Galaxian hardware, bootleg?)"                                                              ,"devilfsg"     , "mame", 3, 0 } ,												
{ "Devil Fish"                                                                                            ,"devilfsh"     , "mame", 3, 0 } ,												
{ "Devil World"                                                                                           ,"devilw"       , "mame", 3, 0 } ,												
{ "Devil Zone"                                                                                            ,"devzone"      , "mame", 3, 0 } ,												
{ "Diamond Run"                                                                                           ,"diamond"      , "mame", 3, 0 } ,												
{ "Dig Dug (Atari)"                                                                                       ,"digdugat"     , "mame", 3, 0 } ,												
{ "Dig Dug (set 1)"                                                                                       ,"digdug"       , "mame", 3, 0 } ,												
{ "Dig Dug (set 2)"                                                                                       ,"digdugb"      , "mame", 3, 0 } ,												
{ "Dig Dug II (set 1)"                                                                                    ,"digdug2"      , "mame", 3, 0 } ,												
{ "Dig Dug II (set 2)"                                                                                    ,"digdug2a"     , "mame", 3, 0 } ,												
{ "Digger"                                                                                                ,"digger"       , "mame", 3, 0 } ,												
{ "Dino Rex (Japan)"                                                                                      ,"dinorexj"     , "mame", 3, 0 } ,												
{ "Dino Rex (US)"                                                                                         ,"dinorexu"     , "mame", 3, 0 } ,												
{ "Dino Rex (World)"                                                                                      ,"dinorex"      , "mame", 3, 0 } ,												
{ "Disco No.1"                                                                                            ,"disco"        , "mame", 3, 0 } ,												
{ "Discs of Tron (Environmental)"                                                                         ,"dotrone"      , "mame", 5, 0 } ,												
{ "Discs of Tron (Upright)"                                                                               ,"dotron"       , "mame", 5, 0 } ,												
{ "Do! Run Run (Do's Castle hardware)"                                                                    ,"dorunruc"     , "mame", 1, 0 } ,												
{ "Do! Run Run (set 1)"                                                                                   ,"dorunrun"     , "mame", 1, 0 } ,												
{ "Do! Run Run (set 2)"                                                                                   ,"dorunru2"     , "mame", 1, 0 } ,												
{ "Dodonpachi (Japan)"                                                                                    ,"ddonpach"     , "mame", 3, 0 } ,												
{ "Dog Fight"                                                                                             ,"dogfight"     , "mame", 1, 0 } ,												
{ "Dog Patch"                                                                                             ,"dogpatch"     , "mame", 3, 0 } ,												
{ "Dogou Souken"                                                                                          ,"dogosoke"     , "mame", 3, 0 } ,												
{ "Dogyuun"                                                                                               ,"dogyuun"      , "mame", 3, 0 } ,												
{ "Dokaben (Japan)"                                                                                       ,"dokaben"      , "mame", 1, 0 } ,												
{ "Domino Man"                                                                                            ,"domino"       , "mame", 5, 0 } ,												
{ "Dominos"                                                                                               ,"dominos"      , "mame", 3, 0 } ,												
{ "Don Doko Don (Japan)"                                                                                  ,"dondokod"     , "mame", 3, 0 } ,												
{ "Donkey Kong (Japan set 1)"                                                                             ,"dkongjp"      , "mame", 1, 0 } ,												
{ "Donkey Kong (Japan set 2)"                                                                             ,"dkongjpo"     , "mame", 1, 0 } ,												
{ "Donkey Kong (US)"                                                                                      ,"dkong"        , "mame", 1, 0 } ,												
{ "Donkey Kong 3 (Japan)"                                                                                 ,"dkong3j"      , "mame", 1, 0 } ,												
{ "Donkey Kong 3 (US)"                                                                                    ,"dkong3"       , "mame", 1, 0 } ,												
{ "Donkey Kong Jr. (Original Japanese)"                                                                   ,"dkngjrjp"     , "mame", 1, 0 } ,												
{ "Donkey Kong Junior (Japan)"                                                                            ,"dkjrjp"       , "mame", 1, 0 } ,												
{ "Donkey Kong Junior (US)"                                                                               ,"dkongjr"      , "mame", 1, 0 } ,												
{ "Donkey Kong Junior (bootleg?)"                                                                         ,"dkjrbl"       , "mame", 1, 0 } ,												
{ "Dottori Kun (new version)"                                                                             ,"dotrikun"     , "mame", 1, 0 } ,												
{ "Dottori Kun (old version)"                                                                             ,"dotriku2"     , "mame", 1, 0 } ,												
{ "Double Dragon (Japan)"                                                                                 ,"ddragon"      , "mame", 3, 0 } ,												
{ "Double Dragon (Neo-Geo)"                                                                               ,"doubledr"     , "neomame", 3, 0 } ,												
{ "Double Dragon (US)"                                                                                    ,"ddragonu"     , "mame", 3, 0 } ,												
{ "Double Dragon (bootleg)"                                                                               ,"ddragonb"     , "mame", 3, 0 } ,												
{ "Double Dragon 3 - The Rosetta Stone (bootleg)"                                                         ,"ddrago3b"     , "mame", 3, 0 } ,												
{ "Double Dragon 3 - The Rosetta Stone"                                                                   ,"ddragon3"     , "mame", 3, 0 } ,												
{ "Double Dragon II - The Revenge"                                                                        ,"ddragon2"     , "mame", 3, 0 } ,												
{ "Double Dribble"                                                                                        ,"ddribble"     , "mame", 3, 0 } ,												
{ "Double Dynamites, The"                                                                                 ,"dbldyn"       , "mame", 3, 0 } ,												
{ "Double Play"                                                                                           ,"dplay"        , "mame", 3, 0 } ,												
{ "DownTown"                                                                                              ,"downtown"     , "mame", 3, 0 } ,												
{ "Dr. Toppel's Tankentai (Japan)"                                                                        ,"drtoppel"     , "mame", 3, 0 } ,												
{ "Dragon Breed"                                                                                          ,"dbreed"       , "mame", 1, 0 } ,												
{ "Dragon Buster"                                                                                         ,"drgnbstr"     , "mame", 3, 0 } ,												
{ "Dragon Saber (Japan)"                                                                                  ,"dsaberj"      , "mame", 3, 0 } ,												
{ "Dragon Saber"                                                                                          ,"dsaber"       , "mame", 3, 0 } ,												
{ "Dragon Spirit (new version)"                                                                           ,"dspirit"      , "mame", 3, 0 } ,												
{ "Dragon Spirit (old version)"                                                                           ,"dspirito"     , "mame", 3, 0 } ,												
{ "Dragon Unit / Castle of Dragon"                                                                        ,"drgnunit"     , "mame", 3, 0 } ,												
{ "Dragonninja (Japan)"                                                                                   ,"drgninja"     , "mame", 3, 0 } ,												
{ "Dream Shopper"                                                                                         ,"dremshpr"     , "mame", 3, 0 } ,												
{ "Dream Soccer '94"                                                                                      ,"dsoccr94"     , "mame", 3, 0 } ,												
{ "Drift Out (Japan)"                                                                                     ,"driftout"     , "mame", 1, 0 } ,												
{ "Drive Out"                                                                                             ,"driveout"     , "mame", 1, 0 } ,												
{ "Dump Matsumoto (Japan)"                                                                                ,"dumpmtmt"     , "mame", 1, 0 } ,												
{ "Dyger (set 1)"                                                                                         ,"dyger"        , "mame", 3, 0 } ,												
{ "Dyger (set 2)"                                                                                         ,"dygera"       , "mame", 3, 0 } ,												
{ "Dynamite Duke"                                                                                         ,"dynduke"      , "mame", 3, 0 } ,												
{ "Dynamite Dux (bootleg)"                                                                                ,"dduxbl"       , "mame", 3, 0 } ,												
{ "E-Swat (bootleg)"                                                                                      ,"eswatbl"      , "mame", 1, 0 } ,												
{ "E-Swat"                                                                                                ,"eswat"        , "mame", 1, 0 } ,												
{ "ESP Ra.De. (Japan)"                                                                                    ,"esprade"      , "mame", 3, 0 } ,												
{ "Eagle (set 1)"                                                                                         ,"eagle"        , "mame", 3, 0 } ,												
{ "Eagle (set 2)"                                                                                         ,"eagle2"       , "mame", 3, 0 } ,												
{ "Earth Defense Force"                                                                                   ,"edf"          , "mame", 3, 0 } ,												
{ "Eggs"                                                                                                  ,"eggs"         , "mame", 3, 0 } ,												
{ "Eight Man"                                                                                             ,"eightman"     , "neomame", 3, 0 } ,												
{ "Electric Yo-Yo, The (set 1)"                                                                           ,"elecyoyo"     , "mame", 3, 0 } ,												
{ "Electric Yo-Yo, The (set 2)"                                                                           ,"elecyoy2"     , "mame", 3, 0 } ,												
{ "Elevator Action (bootleg)"                                                                             ,"elevatob"     , "mame", 5, 0 } ,												
{ "Elevator Action"                                                                                       ,"elevator"     , "mame", 5, 0 } ,												
{ "Eliminator (2 Players, set 1)"                                                                         ,"elim2"        , "mame", 1, 0 } ,												
{ "Eliminator (2 Players, set 2)"                                                                         ,"elim2a"       , "mame", 1, 0 } ,												
{ "Eliminator (4 Players)"                                                                                ,"elim4"        , "mame", 1, 0 } ,												
{ "Empire City: 1931 (Japan)"                                                                             ,"empcityj"     , "mame", 5, 0 } ,												
{ "Empire City: 1931 (bootleg?)"                                                                          ,"empcity"      , "mame", 5, 0 } ,												
{ "Empire Strikes Back, The"                                                                              ,"esb"          , "mame", 3, 0 } ,												
{ "End, The (Stern)"                                                                                      ,"theends"      , "mame", 3, 0 } ,												
{ "End, The"                                                                                              ,"theend"       , "mame", 3, 0 } ,												
{ "Enduro Racer (bootleg set 1)"                                                                          ,"endurobl"     , "mame", 3, 0 } ,												
{ "Enduro Racer (bootleg set 2)"                                                                          ,"endurob2"     , "mame", 3, 0 } ,												
{ "Enduro Racer"                                                                                          ,"enduror"      , "mame", 3, 0 } ,												
{ "Escape from the Planet of the Robot Monsters (set 1)"                                                  ,"eprom"        , "mame", 0, 0 } ,												
{ "Escape from the Planet of the Robot Monsters (set 2)"                                                  ,"eprom2"       , "mame", 0, 0 } ,												
{ "Espial (Europe)"                                                                                       ,"espiale"      , "mame", 3, 0 } ,												
{ "Espial (US?)"                                                                                          ,"espial"       , "mame", 3, 0 } ,												
{ "Euro Champ '92 (World)"                                                                                ,"euroch92"     , "mame", 3, 0 } ,												
{ "Euro League"                                                                                           ,"wc90b"        , "mame", 3, 0 } ,												
{ "Exciting Hour"                                                                                         ,"excthour"     , "mame", 3, 0 } ,												
{ "Exciting Soccer (alternate music)"                                                                     ,"exctscca"     , "mame", 3, 0 } ,												
{ "Exciting Soccer (bootleg)"                                                                             ,"exctsccb"     , "mame", 3, 0 } ,												
{ "Exciting Soccer II"                                                                                    ,"exctscc2"     , "mame", 3, 0 } ,												
{ "Exciting Soccer"                                                                                       ,"exctsccr"     , "mame", 3, 0 } ,												
{ "Exed Exes"                                                                                             ,"exedexes"     , "mame", 1, 0 } ,												
{ "Exerion (Taito)"                                                                                       ,"exeriont"     , "mame", 3, 0 } ,												
{ "Exerion (bootleg)"                                                                                     ,"exerionb"     , "mame", 3, 0 } ,												
{ "Exerion"                                                                                               ,"exerion"      , "mame", 3, 0 } ,												
{ "Exerizer (Japan) (bootleg)"                                                                            ,"exerizrb"     , "mame", 3, 0 } ,												
{ "Exodus (bootleg?)"                                                                                     ,"exodus"       , "mame", 3, 0 } ,												
{ "Express Raider (US)"                                                                                   ,"exprraid"     , "mame", 3, 0 } ,												
{ "Extermination (US)"                                                                                    ,"extrmatn"     , "mame", 3, 0 } ,												
{ "Exterminator"                                                                                          ,"exterm"       , "mame", 3, 0 } ,												
{ "Extra Bases"                                                                                           ,"ebases"       , "mame", 1, 0 } ,												
{ "Extra Innings"                                                                                         ,"einnings"     , "mame", 3, 0 } ,												
{ "Eyes (Digitrex Techstar)"                                                                              ,"eyes"         , "mame", 3, 0 } ,												
{ "Eyes (Techstar Inc.)"                                                                                  ,"eyes2"        , "mame", 3, 0 } ,												
{ "F-1 Dream (bootleg)"                                                                                   ,"f1dreamb"     , "mame", 3, 0 } ,												
{ "F-1 Dream"                                                                                             ,"f1dream"      , "mame", 3, 0 } ,												
{ "F1 Grand Prix Star"                                                                                    ,"f1gpstar"     , "mame", 3, 0 } ,												
{ "Face Off (Japan)"                                                                                      ,"faceoff"      , "mame", 3, 0 } ,												
{ "Fairyland Story, The"                                                                                  ,"flstory"      , "mame", 3, 0 } ,												
{ "Fairyland Story, The (Japan)"                                                                          ,"flstoryj"      , "mame", 3, 0 } ,												
{ "Fantasy (Japan)"                                                                                       ,"fantasyj"     , "mame", 3, 0 } ,												
{ "Fantasy (US)"                                                                                          ,"fantasy"      , "mame", 3, 0 } ,												
{ "Fantasy Zone (Japan New Ver.)"                                                                         ,"fantzone"     , "mame", 3, 0 } ,												
{ "Fantasy Zone (Old Ver.)"                                                                               ,"fantzono"     , "mame", 3, 0 } ,												
{ "Fantazia"                                                                                              ,"fantazia"     , "mame", 3, 0 } ,												
{ "Far West"                                                                                              ,"farwest"      , "mame", 3, 0 } ,												
{ "Fast Freddie"                                                                                          ,"fastfred"     , "mame", 3, 0 } ,												
{ "Fast Lane"                                                                                             ,"fastlane"     , "mame", 3, 0 } ,												
{ "Faster, Harder, More Challenging Q*bert (prototype)"                                                   ,"sqbert"       , "mame", 3, 0 } ,												
{ "Fatal Fury - King of Fighters / Garou Densetsu - shukumei no tatakai"                                  ,"fatfury1"     , "neomame", 3, 0 } ,												
{ "Fatal Fury 2 / Garou Densetsu 2 - arata-naru tatakai"                                                  ,"fatfury2"     , "neomame", 3, 0 } ,												
{ "Fatal Fury 3 - Road to the Final Victory / Garou Densetsu 3 - haruka-naru tatakai"                     ,"fatfury3"     , "neomame", 3, 0 } ,												
{ "Fatal Fury Special / Garou Densetsu Special"                                                           ,"fatfursp"     , "neomame", 3, 0 } ,												
{ "Fax"                                                                                                   ,"fax"          , "mame", 3, 0 } ,												
{ "Fight Fever / Crystal Legacy"                                                                          ,"fightfev"     , "neomame", 3, 0 } ,												
{ "Fighting Fantasy (Japan)"                                                                              ,"ffantasy"     , "mame", 3, 0 } ,												
{ "Fighting Golf"                                                                                         ,"fitegolf"     , "mame", 3, 0 } ,												
{ "Fighting Hawk (Japan)"                                                                                 ,"fhawk"        , "mame", 3, 0 } ,												
{ "Fighting Soccer"                                                                                       ,"ftsoccer"     , "mame", 5, 0 } ,												
{ "Final Blow (Japan)"                                                                                    ,"finalbj"      , "mame", 3, 0 } ,												
{ "Final Blow (World)"                                                                                    ,"finalb"       , "mame", 3, 0 } ,												
{ "Final Fight (Japan)"                                                                                   ,"ffightj"      , "mame", 3, 0 } ,												
{ "Final Fight (US)"                                                                                      ,"ffightu"      , "mame", 3, 0 } ,												
{ "Final Fight (World)"                                                                                   ,"ffight"       , "mame", 3, 0 } ,												
{ "Final Round"                                                                                           ,"fround"       , "mame", 3, 0 } ,												
{ "Final Star Force (US)"                                                                                 ,"fstarfrc"     , "mame", 3, 0 } ,												
{ "Finalizer - Super Transformation (bootleg)"                                                            ,"finalizb"     , "mame", 3, 0 } ,												
{ "Finalizer - Super Transformation"                                                                      ,"finalizr"     , "mame", 3, 0 } ,												
{ "Finest Hour (Japan)"                                                                                   ,"finehour"     , "mame", 3, 0 } ,												
{ "Fire One"                                                                                              ,"fireone"      , "mame", 3, 0 } ,												
{ "Fire Shark"                                                                                            ,"fireshrk"     , "mame", 3, 0 } ,												
{ "Fire Trap (Japan bootleg)"                                                                             ,"firetpbl"     , "mame", 3, 0 } ,												
{ "Fire Trap"                                                                                             ,"firetrap"     , "mame", 3, 0 } ,												
{ "Fire Truck"                                                                                            ,"firetrk"      , "mame", 3, 0 } ,												
{ "Fitter"                                                                                                ,"fitter"       , "mame", 3, 0 } ,												
{ "Flak Attack (Japan)"                                                                                   ,"flkatck"      , "mame", 3, 0 } ,												
{ "Flash Gal"                                                                                             ,"flashgal"     , "mame", 3, 0 } ,												
{ "Flash Point (bootleg)"                                                                                 ,"fpointbl"     , "mame", 3, 0 } ,												
{ "Flash Point"                                                                                           ,"fpoint"       , "mame", 3, 0 } ,												
{ "Flicky (set 1)"                                                                                        ,"flicky"       , "mame", 5, 0 } ,												
{ "Flicky (set 2)"                                                                                        ,"flicky2"      , "mame", 5, 0 } ,												
{ "Fly-Boy (bootleg)"                                                                                     ,"flyboyb"      , "mame", 3, 0 } ,												
{ "Fly-Boy"                                                                                               ,"flyboy"       , "mame", 3, 0 } ,												
{ "Flying Shark (World)"                                                                                  ,"fshark"       , "mame", 3, 0 } ,												
{ "Flying Shark (bootleg)"                                                                                ,"fsharkbt"     , "mame", 3, 0 } ,												
{ "Food Fight"                                                                                            ,"foodf"        , "mame", 3, 0 } ,												
{ "Football Champ (World)"                                                                                ,"footchmp"     , "mame", 3, 0 } ,												
{ "Football Frenzy"                                                                                       ,"fbfrenzy"     , "neomame", 3, 0 } ,												
{ "Forgotten Worlds (US)"                                                                                 ,"forgottn"     , "mame", 3, 0 } ,												
{ "Formation Z"                                                                                           ,"formatz"      , "mame", 3, 0 } ,												
{ "Freeze"                                                                                                ,"freeze"       , "mame", 3, 0 } ,												
{ "Frenzy"                                                                                                ,"frenzy"       , "mame", 3, 0 } ,												
{ "Frisky Tom"                                                                                            ,"friskyt"      , "mame", 3, 0 } ,												
{ "Frog"                                                                                                  ,"froggers"     , "mame", 3, 0 } ,												
{ "Frogger (Sega set 1)"                                                                                  ,"frogseg1"     , "mame", 3, 0 } ,												
{ "Frogger (Sega set 2)"                                                                                  ,"frogseg2"     , "mame", 3, 0 } ,												
{ "Frogger (modified Moon Cresta hardware)"                                                               ,"froggrmc"     , "mame", 3, 0 } ,												
{ "Frogger"                                                                                               ,"frogger"      , "mame", 3, 0 } ,												
{ "Frogs"                                                                                                 ,"frogs"        , "mame", 3, 0 } ,												
{ "Front Line"                                                                                            ,"frontlin"     , "mame", 3, 0 } ,												
{ "Funky Bee"                                                                                             ,"funkybee"     , "mame", 3, 0 } ,												
{ "Funky Fish"                                                                                            ,"fnkyfish"     , "mame", 3, 0 } ,												
{ "Funny Mouse (bootleg?)"                                                                                ,"suprmou2"     , "mame", 3, 0 } ,												
{ "Future Spy"                                                                                            ,"futspy"       , "mame", 1, 0 } ,												
{ "Galactic Warriors"                                                                                     ,"gwarrior"     , "mame", 3, 0 } ,												
{ "Galaga '84"                                                                                            ,"galaga84"     , "mame", 3, 0 } ,												
{ "Galaga '88 (Japan)"                                                                                    ,"galag88j"     , "mame", 3, 0 } ,												
{ "Galaga '88 (set 1)"                                                                                    ,"galaga88"     , "mame", 3, 0 } ,												
{ "Galaga '88 (set 2)"                                                                                    ,"galag88b"     , "mame", 3, 0 } ,												
{ "Galaga (Midway)"                                                                                       ,"galagamw"     , "mame", 3, 0 } ,												
{ "Galaga (Namco)"                                                                                        ,"galaga"       , "mame", 3, 0 } ,												
{ "Galaga (bootleg)"                                                                                      ,"galagab2"     , "mame", 3, 0 } ,												
{ "Galaga (fast shoot)"                                                                                   ,"galagads"     , "mame", 3, 0 } ,												
{ "Galaga 3 (set 1)"                                                                                      ,"galaga3"      , "mame", 3, 0 } ,												
{ "Galaga 3 (set 2)"                                                                                      ,"galaga3a"     , "mame", 3, 0 } ,												
{ "Galaxian (Midway)"                                                                                     ,"galmidw"      , "mame", 3, 0 } ,												
{ "Galaxian (Namco)"                                                                                      ,"galaxian"     , "mame", 3, 0 } ,												
{ "Galaxian (bootleg)"                                                                                    ,"galaxb"       , "mame", 3, 0 } ,												
{ "Galaxian Part 4"                                                                                       ,"galap4"       , "mame", 3, 0 } ,												
{ "Galaxian Part X"                                                                                       ,"galapx"       , "mame", 3, 0 } ,												
{ "Galaxian Turbo"                                                                                        ,"galturbo"     , "mame", 3, 0 } ,												
{ "Galaxy Fight - Universal Warriors"                                                                     ,"galaxyfg"     , "neomame", 3, 0 } ,												
{ "Galaxy Rescue"                                                                                         ,"grescue"      , "mame", 3, 0 } ,												
{ "Galaxy Wars"                                                                                           ,"galxwars"     , "mame", 3, 0 } ,												
{ "Galivan - Cosmo Police (12/11/1985)"                                                                   ,"galivan2"     , "mame", 3, 0 } ,												
{ "Galivan - Cosmo Police (12/16/1985)"                                                                   ,"galivan"      , "mame", 3, 0 } ,												
{ "Gallag"                                                                                                ,"gallag"       , "mame", 3, 0 } ,												
{ "Gallop - Armed police Unit (Japan)"                                                                    ,"gallop"       , "mame", 3, 0 } ,												
{ "Gals Panic"                                                                                            ,"galpanic"     , "mame", 3, 0 } ,												
{ "Ganbare Ginkun"                                                                                        ,"ginkun"       , "mame", 3, 0 } ,												
{ "Gang Busters"                                                                                          ,"gbusters"     , "mame", 3, 0 } ,												
{ "Gang Wars (US)"                                                                                        ,"gangwars"     , "mame", 3, 0 } ,												
{ "Gang Wars (bootleg)"                                                                                   ,"gangwarb"     , "mame", 3, 0 } ,												
{ "Gaplus (set 1)"                                                                                        ,"gaplus"       , "mame", 3, 0 } ,												
{ "Gaplus (set 2)"                                                                                        ,"gaplusa"      , "mame", 3, 0 } ,												
{ "Gardia (bootleg)"                                                                                      ,"gardiab"      , "mame", 1, 0 } ,												
{ "Gardia"                                                                                                ,"gardia"       , "mame", 1, 0 } ,												
{ "Garuka (Japan)"                                                                                        ,"garuka"       , "mame", 3, 0 } ,												
{ "Garyo Retsuden (Japan)"                                                                                ,"garyoret"     , "mame", 3, 0 } ,												
{ "Gate of Doom (US revision 1)"                                                                          ,"gatedom1"     , "mame", 3, 0 } ,												
{ "Gate of Doom (US revision 4)"                                                                          ,"gatedoom"     , "mame", 3, 0 } ,												
{ "Gauntlet (2 Players)"                                                                                  ,"gaunt2p"      , "mame", 3, 0 } ,												
{ "Gauntlet (Intermediate Release 1)"                                                                     ,"gauntir1"     , "mame", 3, 0 } ,												
{ "Gauntlet (Intermediate Release 2)"                                                                     ,"gauntir2"     , "mame", 3, 0 } ,												
{ "Gauntlet II"                                                                                           ,"gaunt2"       , "mame", 3, 0 } ,												
{ "Gauntlet"                                                                                              ,"gauntlet"     , "mame", 3, 0 } ,												
{ "Gee Bee (Gremlin)"                                                                                     ,"geebeeg"      , "mame", 3, 0 } ,												
{ "Gee Bee"                                                                                               ,"geebee"       , "mame", 3, 0 } ,												
{ "Gemini Wing"                                                                                           ,"gemini"       , "mame", 3, 0 } ,												
{ "Genpei ToumaDen"                                                                                       ,"genpeitd"     , "mame", 3, 0 } ,												
{ "Genshi-Tou 1930's"                                                                                     ,"gensitou"     , "mame", 3, 0 } ,												
{ "Get Star (Japan)"                                                                                      ,"getstarj"     , "mame", 3, 0 } ,												
{ "Get Star (bootleg)"                                                                                    ,"getstarb"     , "mame", 3, 0 } ,												
{ "Ghost Pilots"                                                                                          ,"gpilots"      , "neomame", 3, 0 } ,												
{ "Ghosts'n Goblins (US)"                                                                                 ,"gngt"         , "mame", 3, 0 } ,												
{ "Ghosts'n Goblins (World? set 1)"                                                                       ,"gng"          , "mame", 3, 0 } ,												
{ "Ghosts'n Goblins (World? set 2)"                                                                       ,"gnga"         , "mame", 3, 0 } ,												
{ "Ghouls'n Ghosts (US)"                                                                                  ,"ghoulsu"      , "mame", 3, 0 } ,												
{ "Ghouls'n Ghosts (World)"                                                                               ,"ghouls"       , "mame", 3, 0 } ,												
{ "Ghox"                                                                                                  ,"ghox"         , "mame", 3, 0 } ,												
{ "Gimme A Break"                                                                                         ,"gimeabrk"     , "mame", 3, 0 } ,												
{ "Ginga NinkyouDen"                                                                                      ,"ginganin"     , "mame", 3, 0 } ,												
{ "Gingateikoku No Gyakushu"                                                                              ,"gteikoku"     , "mame", 3, 0 } ,												
{ "Gladiator (US)"                                                                                        ,"gladiatr"     , "mame", 3, 0 } ,												
{ "Glob, The"                                                                                             ,"theglob"      , "mame", 1, 0 } ,												
{ "Go Go Mr. Yamaguchi / Yuke Yuke Yamaguchi-kun"                                                         ,"yamagchi"     , "mame", 3, 0 } ,												
{ "Goal! Goal! Goal!"                                                                                     ,"goalx3"       , "neomame", 3, 0 } ,												
{ "Goalie Ghost"                                                                                          ,"gghost"       , "mame", 3, 0 } ,												
{ "Goindol"                                                                                               ,"goindol"      , "mame", 3, 0 } ,												
{ "Gold Medalist"                                                                                         ,"goldmedl"     , "mame", 3, 0 } ,												
{ "Golden Axe (Version 1)"                                                                                ,"goldnaxe"     , "mame", 1, 0 } ,												
{ "Golden Axe (Version 1, Japan)"                                                                         ,"goldnaxj"     , "mame", 1, 0 } ,												
{ "Golden Axe (Version 2 317-0110)"                                                                       ,"goldnaxb"     , "mame", 1, 0 } ,												
{ "Golden Axe (Version 2 317-0122)"                                                                       ,"goldnaxc"     , "mame", 1, 0 } ,												
{ "Golden Axe (Version 2)"                                                                                ,"goldnaxa"     , "mame", 1, 0 } ,												
{ "Golden Axe (bootleg)"                                                                                  ,"goldnabl"     , "mame", 1, 0 } ,												
{ "Gondomania (US)"                                                                                       ,"gondo"        , "mame", 3, 0 } ,												
{ "Gorf (Program 1)"                                                                                      ,"gorfpgm1"     , "mame", 1, 0 } ,												
{ "Gorf"                                                                                                  ,"gorf"         , "mame", 1, 0 } ,												
{ "Got-Ya (12/24/1981, prototype?)"                                                                       ,"gotya"        , "mame", 3, 0 } ,												
{ "Gradius II - Gofer no Yabou (Japan set 1)"                                                             ,"gradius2"     , "mame", 3, 0 } ,												
{ "Gradius II - Gofer no Yabou (Japan set 2)"                                                             ,"grdius2a"     , "mame", 3, 0 } ,												
{ "Gradius II - Gofer no Yabou (Japan set 3)"                                                             ,"grdius2b"     , "mame", 3, 0 } ,												
{ "Gradius III (Asia)"                                                                                    ,"grdius3a"     , "mame", 3, 0 } ,												
{ "Gradius III (Japan)"                                                                                   ,"gradius3"     , "mame", 3, 0 } ,												
{ "Gradius"                                                                                               ,"gradius"      , "mame", 3, 0 } ,												
{ "Gravitar (version 2)"                                                                                  ,"gravitr2"     , "mame", 3, 0 } ,												
{ "Gravitar (version 3)"                                                                                  ,"gravitar"     , "mame", 3, 0 } ,												
{ "Great 1000 Miles Rally (Evolution Model)"                                                              ,"gtmre"        , "mame", 3, 0 } ,												
{ "Great 1000 Miles Rally"                                                                                ,"gtmr"         , "mame", 3, 0 } ,												
{ "Great Swordsman"                                                                                       ,"gsword"       , "mame", 3, 0 } ,												
{ "Green Beret (bootleg)"                                                                                 ,"gberetb"      , "mame", 3, 0 } ,												
{ "Green Beret"                                                                                           ,"gberet"       , "mame", 3, 0 } ,												
{ "Gridiron Fight"                                                                                        ,"gridiron"     , "mame", 3, 0 } ,												
{ "Grind Stormer (Korea)"                                                                                 ,"grindstm"     , "mame", 3, 0 } ,												
{ "Grobda (New version)"                                                                                  ,"grobda"       , "mame", 3, 0 } ,												
{ "Grobda (Old version set 1)"                                                                            ,"grobda2"      , "mame", 3, 0 } ,												
{ "Grobda (Old version set 2)"                                                                            ,"grobda3"      , "mame", 3, 0 } ,												
{ "Growl (US)"                                                                                            ,"growlu"       , "mame", 3, 0 } ,												
{ "Growl (World)"                                                                                         ,"growl"        , "mame", 3, 0 } ,												
{ "Gryzor"                                                                                                ,"gryzor"       , "mame", 3, 0 } ,												
{ "Guardian"                                                                                              ,"getstar"      , "mame", 3, 0 } ,												
{ "Guerrilla War (US)"                                                                                    ,"gwar"         , "mame", 3, 0 } ,												
{ "Guerrilla War (Version 1)"                                                                             ,"gwara"        , "mame", 3, 0 } ,												
{ "Guerrilla War (bootleg)"                                                                               ,"gwarb"        , "mame", 3, 0 } ,												
{ "Guevara (Japan)"                                                                                       ,"gwarj"        , "mame", 3, 0 } ,												
{ "Guided Missile"                                                                                        ,"gmissile"     , "mame", 3, 0 } ,												
{ "Gun & Frontier (World)"                                                                                ,"gunfront"     , "mame", 3, 0 } ,												
{ "Gun Bird (Japan)"                                                                                      ,"gunbird"      , "mame", 3, 0 } ,												
{ "Gun Dealer (set 1)"                                                                                    ,"gundealr"     , "mame", 1, 0 } ,												
{ "Gun Dealer (set 2)"                                                                                    ,"gundeala"     , "mame", 1, 0 } ,												
{ "Gun Fight"                                                                                             ,"gunfight"     , "mame", 3, 0 } ,												
{ "Gun Frontier (Japan)"                                                                                  ,"gunfronj"     , "mame", 3, 0 } ,												
{ "Gun Hohki (Japan)"                                                                                     ,"gunhohki"     , "mame", 3, 0 } ,												
{ "Gun.Smoke (Japan)"                                                                                     ,"gunsmokj"     , "mame", 3, 0 } ,												
{ "Gun.Smoke (US set 1)"                                                                                  ,"gunsmrom"     , "mame", 3, 0 } ,												
{ "Gun.Smoke (US set 2)"                                                                                  ,"gunsmoka"     , "mame", 3, 0 } ,												
{ "Gun.Smoke (World)"                                                                                     ,"gunsmoke"     , "mame", 3, 0 } ,												
{ "Gunforce - Battle Fire Engulfed Terror Island (US)"                                                    ,"gunforcu"     , "mame", 3, 0 } ,												
{ "Gunforce - Battle Fire Engulfed Terror Island (World)"                                                 ,"gunforce"     , "mame", 3, 0 } ,												
{ "Gururin"                                                                                               ,"gururin"      , "neomame", 3, 0 } ,												
{ "Guttang Gottong"                                                                                       ,"gutangtn"     , "mame", 3, 0 } ,												
{ "Guzzler"                                                                                               ,"guzzler"      , "mame", 3, 0 } ,												
{ "Gypsy Juggler"                                                                                         ,"gypsyjug"     , "mame", 3, 0 } ,												
{ "Gyrodine"                                                                                              ,"gyrodine"     , "mame", 3, 0 } ,												
{ "Gyruss (Centuri)"                                                                                      ,"gyrussce"     , "mame", 3, 0 } ,												
{ "Gyruss (Konami)"                                                                                       ,"gyruss"       , "mame", 3, 0 } ,												
{ "HAL21 (Japan)"                                                                                         ,"hal21j"       , "mame", 3, 0 } ,												
{ "HAL21"                                                                                                 ,"hal21"        , "mame", 3, 0 } ,												
{ "Hachoo!"                                                                                               ,"hachoo"       , "mame", 3, 0 } ,												
{ "Hammerin' Harry (US)"                                                                                  ,"hharryu"      , "mame", 1, 0 } ,												
{ "Hammerin' Harry (World)"                                                                               ,"hharry"       , "mame", 1, 0 } ,												
{ "Hana Awase (Flower Matching)"                                                                          ,"hanaawas"     , "mame", 3, 0 } ,												
{ "Hang-On"                                                                                               ,"hangon"       , "mame", 3, 0 } ,												
{ "Hangly-Man (set 1)"                                                                                    ,"hangly"       , "mame", 3, 0 } ,												
{ "Hangly-Man (set 2)"                                                                                    ,"hangly2"      , "mame", 3, 0 } ,												
{ "Hard Hat"                                                                                              ,"hardhat"      , "mame", 3, 0 } ,												
{ "Hard Head"                                                                                             ,"hardhead"     , "mame", 3, 0 } ,												
{ "Hard Head (Bootleg)"                                                                                   ,"hardhedb"      , "mame", 3, 0 } ,												
{ "Hard Puncher (Japan)"                                                                                  ,"hpuncher"     , "mame", 3, 0 } ,												
{ "Hat Trick Hero (Japan)"                                                                                ,"hthero"       , "mame", 3, 0 } ,												
{ "Hat Trick"                                                                                             ,"hattrick"     , "mame", 3, 0 } ,												
{ "Hatris (Japan)"                                                                                        ,"hatris"       , "mame", 1, 0 } ,												
{ "Haunted Castle (set 1)"                                                                                ,"hcastle"      , "mame", 3, 0 } ,												
{ "Haunted Castle (set 2)"                                                                                ,"hcastlea"     , "mame", 3, 0 } ,												
{ "Head On (1 player)"                                                                                    ,"headonb"      , "mame", 3, 0 } ,												
{ "Head On (2 players)"                                                                                   ,"headon"       , "mame", 3, 0 } ,												
{ "Head On 2"                                                                                             ,"headon2"      , "mame", 3, 0 } ,												
{ "Heavy Barrel (US)"                                                                                     ,"hbarrel"      , "mame", 3, 0 } ,												
{ "Heavy Barrel (World)"                                                                                  ,"hbarrelw"     , "mame", 3, 0 } ,												
{ "Heavy Metal"                                                                                           ,"hvymetal"     , "mame", 5, 0 } ,												
{ "Heavyweight Champ"                                                                                     ,"hwchamp"      , "mame", 1, 0 } ,												
{ "Hebereke no Popoon (Japan)"                                                                            ,"heberpop"     , "mame", 3, 0 } ,												
{ "Heiankyo Alien"                                                                                        ,"heiankyo"     , "mame", 3, 0 } ,												
{ "HeliFire (revision A)"                                                                                 ,"helifira"     , "mame", 3, 0 } ,												
{ "HeliFire (revision B)"                                                                                 ,"helifire"     , "mame", 3, 0 } ,												
{ "Hellfire"                                                                                              ,"hellfire"     , "mame", 3, 0 } ,												
{ "Herbie at the Olympics (DK conversion)"                                                                ,"herbiedk"     , "mame", 3, 0 } ,												
{ "Hexa"                                                                                                  ,"hexa"         , "mame", 3, 0 } ,												
{ "High Impact Football (rev LA3 12/27/90)"                                                               ,"hiimpact"     , "mame", 3, 0 } ,												
{ "High Way Race"                                                                                         ,"hwrace"       , "mame", 3, 0 } ,												
{ "Hippodrome (US)"                                                                                       ,"hippodrm"     , "mame", 3, 0 } ,												
{ "Hishou Zame (Japan)"                                                                                   ,"hishouza"     , "mame", 3, 0 } ,												
{ "Hit 'n Miss (version 2.0)"                                                                             ,"hitnmis2"     , "mame", 3, 0 } ,												
{ "Hit 'n Miss (version 3.0)"                                                                             ,"hitnmiss"     , "mame", 3, 0 } ,												
{ "Hit the Ice (US)"                                                                                      ,"hitice"       , "mame", 3, 0 } ,												
{ "Hoccer (set 1)"                                                                                        ,"hoccer"       , "mame", 3, 0 } ,												
{ "Hoccer (set 2)"                                                                                        ,"hoccer2"      , "mame", 3, 0 } ,												
{ "Homo"                                                                                                  ,"homo"         , "mame", 3, 0 } ,												
{ "Hook (US)"                                                                                             ,"hooku"        , "mame", 3, 0 } ,												
{ "Hook (World)"                                                                                          ,"hook"         , "mame", 3, 0 } ,												
{ "Hopper Robo"                                                                                           ,"hopprobo"     , "mame", 3, 0 } ,												
{ "Hopping Mappy"                                                                                         ,"hopmappy"     , "mame", 3, 0 } ,												
{ "Hot Chase"                                                                                             ,"hotchase"     , "mame", 3, 0 } ,												
{ "Hot Shocker"                                                                                           ,"hotshock"     , "mame", 3, 0 } ,												
{ "Hunchback (Donkey Kong conversion)"                                                                    ,"hunchbkd"     , "mame", 3, 0 } ,												
{ "Hunchback (Scramble hardware)"                                                                         ,"hunchbks"     , "mame", 3, 0 } ,												
{ "Hustle"                                                                                                ,"hustle"       , "mame", 3, 0 } ,												
{ "Hustler, The (Japan version J)"                                                                        ,"thehustj"     , "mame", 3, 0 } ,												
{ "Hustler, The (Japan version M)"                                                                        ,"thehustl"     , "mame", 3, 0 } ,												
{ "Hydra (prototype)"                                                                                     ,"hydrap"       , "mame", 3, 0 } ,												
{ "Hydra"                                                                                                 ,"hydra"        , "mame", 3, 0 } ,												
{ "Hyper Olympic (bootleg)"                                                                               ,"hyprolyb"     , "mame", 3, 0 } ,												
{ "Hyper Olympic"                                                                                         ,"hyprolym"     , "mame", 3, 0 } ,												
{ "Hyper Olympics '84"                                                                                    ,"hpolym84"     , "mame", 3, 0 } ,												
{ "Hyper Sports Special (Japan)"                                                                          ,"hypsptsp"     , "mame", 3, 0 } ,												
{ "Hyper Sports"                                                                                          ,"hyperspt"     , "mame", 3, 0 } ,												
{ "I'm Sorry (Japan)"                                                                                     ,"imsorryj"     , "mame", 5, 0 } ,												
{ "I'm Sorry (US)"                                                                                        ,"imsorry"      , "mame", 5, 0 } ,												
{ "I, Robot"                                                                                              ,"irobot"       , "mame", 3, 0 } ,												
{ "Iga Ninjyutsuden (Japan)"                                                                              ,"iganinju"     , "mame", 0, 0 } ,												
{ "Ikari III - The Rescue"                                                                                ,"ikari3"       , "mame", 3, 0 } ,												
{ "Ikari Warriors (Japan bootleg)"                                                                        ,"ikarijpb"     , "mame", 3, 0 } ,												
{ "Ikari Warriors (Japan)"                                                                                ,"ikarijp"      , "mame", 3, 0 } ,												
{ "Ikari Warriors (US)"                                                                                   ,"ikari"        , "mame", 3, 0 } ,												
{ "Image Fight (Japan)"                                                                                   ,"imgfight"     , "mame", 1, 0 } ,												
{ "In The Hunt (US)"                                                                                      ,"inthuntu"     , "mame", 3, 0 } ,												
{ "In The Hunt (World)"                                                                                   ,"inthunt"      , "mame", 3, 0 } ,												
{ "Indiana Jones and the Temple of Doom (set 1)"                                                          ,"indytemp"     , "mame", 0, 0 } ,												
{ "Indiana Jones and the Temple of Doom (set 2)"                                                          ,"indytem2"     , "mame", 0, 0 } ,												
{ "Indiana Jones and the Temple of Doom (set 3)"                                                          ,"indytem3"     , "mame", 0, 0 } ,												
{ "Indiana Jones and the Temple of Doom (set 4)"                                                          ,"indytem4"     , "mame", 0, 0 } ,												
{ "Inferno"                                                                                               ,"inferno"      , "mame", 3, 0 } ,												
{ "Insector (prototype)"                                                                                  ,"insector"     , "mame", 3, 0 } ,												
{ "Insector X (World)"                                                                                    ,"insectx"      , "mame", 1, 0 } ,												
{ "Intrepid (set 1)"                                                                                      ,"intrepid"     , "mame", 3, 0 } ,												
{ "Intrepid (set 2)"                                                                                      ,"intrepi2"     , "mame", 3, 0 } ,												
{ "Invader's Revenge (Dutchford)"                                                                         ,"invrvnga"     , "mame", 3, 0 } ,												
{ "Invader's Revenge"                                                                                     ,"invrvnge"     , "mame", 3, 0 } ,												
{ "Invinco / Deep Scan"                                                                                   ,"invds"        , "mame", 3, 0 } ,												
{ "Invinco / Head On 2"                                                                                   ,"invho2"       , "mame", 3, 0 } ,												
{ "Invinco"                                                                                               ,"invinco"      , "mame", 3, 0 } ,												
{ "Irem Skins Game, The (US set 1)"                                                                       ,"skingame"     , "mame", 3, 0 } ,												
{ "Irem Skins Game, The (US set 2)"                                                                       ,"skingam2"     , "mame", 3, 0 } ,												
{ "Iron Horse"                                                                                            ,"ironhors"     , "mame", 3, 0 } ,												
{ "Ironman Stewart's Super Off-Road Track Pack"                                                           ,"offroadt"     , "mame", 3, 0 } ,												
{ "Ironman Stewart's Super Off-Road"                                                                      ,"offroad"      , "mame", 3, 0 } ,												
{ "Irritating Maze / Ultra Denryu Iraira Bou, The"                                                        ,"irrmaze"      , "neomame", 3, 0 } ,												
{ "Jack Rabbit (set 1)"                                                                                   ,"jackrabt"     , "mame", 3, 0 } ,												
{ "Jack Rabbit (set 2)"                                                                                   ,"jackrab2"     , "mame", 3, 0 } ,												
{ "Jack Rabbit (special)"                                                                                 ,"jackrabs"     , "mame", 3, 0 } ,												
{ "Jack the Giantkiller (set 1)"                                                                          ,"jack"         , "mame", 3, 0 } ,												
{ "Jack the Giantkiller (set 2)"                                                                          ,"jack2"        , "mame", 3, 0 } ,												
{ "Jack the Giantkiller (set 3)"                                                                          ,"jack3"        , "mame", 3, 0 } ,												
{ "Jackal (World)"                                                                                        ,"jackal"       , "mame", 3, 0 } ,												
{ "Jackson"                                                                                               ,"zaxxonb"      , "mame", 1, 0 } ,												
{ "Jail Break"                                                                                            ,"jailbrek"     , "mame", 3, 0 } ,												
{ "Jatre Specter"                                                                                         ,"jspecter"     , "mame", 3, 0 } ,												
{ "Joe & Mac (Japan)"                                                                                     ,"joemac"       , "mame", 3, 0 } ,												
{ "John Elway's Team Quarterback (set 2)"                                                                 ,"teamqb2"      , "mame", 3, 0 } ,												
{ "John Elway's Team Quarterback"                                                                         ,"teamqb"       , "mame", 3, 0 } ,												
{ "Journey"                                                                                               ,"journey"      , "mame", 1, 0 } ,												
{ "Joust (Solid Red label)"                                                                               ,"joustr"       , "mame", 3, 0 } ,												
{ "Joust (White/Green label)"                                                                             ,"joust"        , "mame", 3, 0 } ,												
{ "Joust (White/Red label)"                                                                               ,"joustwr"      , "mame", 3, 0 } ,												
{ "Joust 2 - Survival of the Fittest (set 1)"                                                             ,"joust2"       , "mame", 3, 0 } ,												
{ "Joyful Road (US)"                                                                                      ,"joyfulr"      , "mame", 3, 0 } ,												
{ "Jr. Pac-Man"                                                                                           ,"jrpacman"     , "mame", 3, 0 } ,												
{ "Jump Bug (bootleg)"                                                                                    ,"jumpbugb"     , "mame", 3, 0 } ,												
{ "Jump Bug"                                                                                              ,"jumpbug"      , "mame", 3, 0 } ,												
{ "Jump Coaster"                                                                                          ,"jumpcoas"     , "mame", 3, 0 } ,												
{ "Jump Shot"                                                                                             ,"jumpshot"     , "mame", 1, 0 } ,												
{ "Jumping Jack"                                                                                          ,"jjack"        , "mame", 1, 0 } ,												
{ "Jumping"                                                                                               ,"jumping"      , "mame", 3, 0 } ,												
{ "Jungle Hunt (US)"                                                                                      ,"jungleh"      , "mame", 3, 0 } ,												
{ "Jungle King (Japan)"                                                                                   ,"junglek"      , "mame", 3, 0 } ,												
{ "Jungle King (Japan, earlier)"                                                                          ,"junglkj2"     , "mame", 3, 0 } ,												
{ "Jungler (Stern)"                                                                                       ,"junglers"     , "mame", 3, 0 } ,												
{ "Jungler"                                                                                               ,"jungler"      , "mame", 3, 0 } ,												
{ "Juno First (Gottlieb)"                                                                                 ,"junofstg"     , "mame", 3, 0 } ,												
{ "Juno First"                                                                                            ,"junofrst"     , "mame", 3, 0 } ,												
{ "Jyanshin Densetsu - Quest of Jongmaster"                                                               ,"janshin"      , "neomame", 3, 0 } ,												
{ "Jyuohki (Japan)"                                                                                       ,"jyuohki"      , "mame", 1, 0 } ,												
{ "Kabuki Klash - Far East of Eden / Tengai Makyou Shinden - Far East of Eden"                            ,"kabukikl"     , "neomame", 3, 0 } ,												
{ "Kageki (Japan)"                                                                                        ,"kagekij"      , "mame", 3, 0 } ,												
{ "Kageki (US)"                                                                                           ,"kageki"       , "mame", 3, 0 } ,												
{ "Kaiketsu Yanchamaru (Japan)"                                                                           ,"yanchamr"     , "mame", 3, 0 } ,												
{ "Kaitei Daisensou (Japan)"                                                                              ,"kaiteids"     , "mame", 3, 0 } ,												
{ "Kaitei Takara Sagashi (Namco)"                                                                         ,"kaitein"      , "mame", 3, 0 } ,												
{ "Kaitei Takara Sagashi"                                                                                 ,"kaitei"       , "mame", 3, 0 } ,												
{ "Kamikaze"                                                                                              ,"kamikaze"     , "mame", 3, 0 } ,												
{ "Kangaroo (Atari)"                                                                                      ,"kangaroa"     , "mame", 3, 0 } ,												
{ "Kangaroo (bootleg)"                                                                                    ,"kangarob"     , "mame", 3, 0 } ,												
{ "Kangaroo"                                                                                              ,"kangaroo"     , "mame", 3, 0 } ,												
{ "Kaos"                                                                                                  ,"kaos"         , "mame", 3, 0 } ,												
{ "Karate Blazers (US)"                                                                                   ,"karatblu"     , "mame", 1, 0 } ,												
{ "Karate Blazers (World?)"                                                                               ,"karatblz"     , "mame", 1, 0 } ,												
{ "Karate Champ (US VS version)"                                                                          ,"kchampvs"     , "mame", 3, 0 } ,												
{ "Karate Champ (US)"                                                                                     ,"kchamp"       , "mame", 3, 0 } ,												
{ "Karate Dou (Japan)"                                                                                    ,"karatedo"     , "mame", 3, 0 } ,												
{ "Karian Cross"                                                                                          ,"karianx"      , "mame", 3, 0 } ,												
{ "Karnov (Japan)"                                                                                        ,"karnovj"      , "mame", 3, 0 } ,												
{ "Karnov (US)"                                                                                           ,"karnov"       , "mame", 3, 0 } ,												
{ "Karnov's Revenge / Fighter's History Dynamite"                                                         ,"karnovr"      , "neomame", 3, 0 } ,												
{ "KiKi KaiKai"                                                                                           ,"kikikai"      , "mame", 1, 0 } ,												
{ "Kick (cocktail)"                                                                                       ,"kicka"        , "mame", 5, 0 } ,												
{ "Kick (upright)"                                                                                        ,"kick"         , "mame", 5, 0 } ,												
{ "Kick Off (Japan)"                                                                                      ,"kickoff"      , "mame", 3, 0 } ,												
{ "Kick Rider"                                                                                            ,"kickridr"     , "mame", 1, 0 } ,												
{ "Kick Start Wheelie King"                                                                               ,"kikstart"     , "mame", 1, 0 } ,												
{ "Kick and Run"                                                                                          ,"kicknrun"     , "mame", 1, 0 } ,												
{ "Kicker"                                                                                                ,"kicker"       , "mame", 3, 0 } ,												
{ "Kid Niki - Radical Ninja (US)"                                                                         ,"kidniki"      , "mame", 3, 0 } ,												
{ "Killer Comet"                                                                                          ,"killcom"      , "mame", 3, 0 } ,												
{ "King & Balloon (Japan)"                                                                                ,"kingbalj"     , "mame", 3, 0 } ,												
{ "King & Balloon (US)"                                                                                   ,"kingball"     , "mame", 3, 0 } ,												
{ "King of Boxer (English)"                                                                               ,"kingofb"      , "mame", 3, 0 } ,												
{ "King of Dragons, The (Japan)"                                                                          ,"kodj"         , "mame", 3, 0 } ,												
{ "King of Dragons, The (World)"                                                                          ,"kod"          , "mame", 3, 0 } ,												
{ "King of Dragons, The (bootleg)"                                                                        ,"kodb"         , "mame", 3, 0 } ,												
{ "King of Fighters '94, The"                                                                             ,"kof94"        , "neomame", 3, 0 } ,												
{ "King of Fighters '95, The"                                                                             ,"kof95"        , "neomame", 3, 0 } ,												
{ "King of Fighters '96, The"                                                                             ,"kof96"        , "neomame", 3, 0 } ,												
{ "King of Fighters '97, The"                                                                             ,"kof97"        , "neomame", 3, 0 } ,												
{ "King of Fighters '98 - The Slugfest / King of Fighters '98 - dream match never ends, The"              ,"kof98"        , "neomame", 3, 0 } ,												
{ "King of the Monsters 2 - The Next Thing"                                                               ,"kotm2"        , "neomame", 3, 0 } ,												
{ "King of the Monsters"                                                                                  ,"kotm"         , "neomame", 3, 0 } ,												
{ "Kizuna Encounter - Super Tag Battle / Fu'un Super Tag Battle"                                          ,"kizuna"       , "neomame", 3, 0 } ,												
{ "Klax (Japan)"                                                                                          ,"klaxj"        , "mame", 3, 0 } ,												
{ "Klax (set 1)"                                                                                          ,"klax"         , "mame", 3, 0 } ,												
{ "Klax (set 2)"                                                                                          ,"klax2"        , "mame", 3, 0 } ,												
{ "Klax (set 3)"                                                                                          ,"klax3"        , "mame", 3, 0 } ,												
{ "Knights of the Round (Japan)"                                                                          ,"knightsj"     , "mame", 3, 0 } ,												
{ "Knights of the Round (World)"                                                                          ,"knights"      , "mame", 3, 0 } ,												
{ "Knock Out !!"                                                                                          ,"knockout"     , "mame", 3, 0 } ,												
{ "Knuckle Bash"                                                                                          ,"kbash"        , "mame", 3, 0 } ,												
{ "Knuckle Joe (set 1)"                                                                                   ,"kncljoe"      , "mame", 3, 0 } ,                                                                                            
{ "Knuckle Joe (set 2)"                                                                                   ,"kncljoea"     , "mame", 3, 0 } ,                                                                                            
{ "Kodure Ookami (Japan)"                                                                                 ,"kodure"       , "mame", 3, 0 } ,												
{ "Koi no Hotrock (Japan)"                                                                                ,"rockragj"     , "mame", 3, 0 } ,												
{ "Konami '88"                                                                                            ,"konami88"     , "mame", 3, 0 } ,												
{ "Konami GT"                                                                                             ,"konamigt"     , "mame", 3, 0 } ,												
{ "Konami RF2 - Red Fighter"                                                                              ,"rf2"          , "mame", 3, 0 } ,												
{ "Koukuu Kihei Monogatari - The Legend of Air Cavalry"                                                   ,"legofair"     , "mame", 3, 0 } ,												
{ "Kozmik Kroozr"                                                                                         ,"kroozr"       , "mame", 1, 0 } ,												
{ "Kram (set 1)"                                                                                          ,"kram"         , "mame", 3, 0 } ,												
{ "Kram (set 2)"                                                                                          ,"kram2"        , "mame", 3, 0 } ,												
{ "Krull"                                                                                                 ,"krull"        , "mame", 3, 0 } ,												
{ "Kuhga - Operation Code 'Vapor Trail' (Japan revision 3)"                                               ,"kuhga"        , "mame", 3, 0 } ,												
{ "Kung Fu Master (Data East)"                                                                            ,"kungfud"      , "mame", 3, 0 } ,												
{ "Kung Fu Master (bootleg set 1)"                                                                        ,"kungfub"      , "mame", 3, 0 } ,												
{ "Kung Fu Master (bootleg set 2)"                                                                        ,"kungfub2"     , "mame", 3, 0 } ,												
{ "Kung Fu Master"                                                                                        ,"kungfum"      , "mame", 3, 0 } ,												
{ "Kuri Kinton (World)"                                                                                   ,"kurikint"     , "mame", 3, 0 } ,												
{ "Kuri Kinton (prototype?)"                                                                              ,"kurikina"     , "mame", 3, 0 } ,												
{ "Kyohkoh-Toppa (Japan)"                                                                                 ,"brkthruj"     , "mame", 3, 0 } ,												
{ "Kyros"                                                                                                 ,"kyros"        , "mame", 3, 0 } ,												
{ "Kyukyoku Tiger (Japan)"                                                                                ,"ktiger"       , "mame", 3, 0 } ,												
{ "Kyuukai Douchuuki (Japan new version)"                                                                 ,"kyukaidk"     , "mame", 3, 0 } ,												
{ "Kyuukai Douchuuki (Japan old version)"                                                                 ,"kyukaido"     , "mame", 3, 0 } ,												
{ "Labyrinth Runner (Japan)"                                                                              ,"labyrunr"     , "mame", 3, 0 } ,												
{ "Lady Bug (bootleg)"                                                                                    ,"ladybugb"     , "mame", 3, 0 } ,												
{ "Lady Bug"                                                                                              ,"ladybug"      , "mame", 3, 0 } ,												
{ "Laguna Racer"                                                                                          ,"lagunar"      , "mame", 3, 0 } ,												
{ "Land Sea Air Squad / Riku Kai Kuu Saizensen"                                                           ,"lsasquad"     , "mame", 3, 0 } ,												
{ "Laser"                                                                                                 ,"laser"        , "mame", 3, 0 } ,												
{ "Lasso"                                                                                                 ,"lasso"        , "mame", 3, 0 } ,												
{ "Last Blade / Bakumatsu Roman - Gekkano Kenshi, The"                                                    ,"lastblad"     , "neomame", 3, 0 } ,												
{ "Last Blade 2 / Bakumatsu Roman - Dai Ni Maku Gekkano Kenshi, The"                                      ,"lastbld2"     , "neomame", 3, 0 } ,												
{ "Last Duel (US set 1)"                                                                                  ,"lastduel"     , "mame", 3, 0 } ,												
{ "Last Duel (US set 2)"                                                                                  ,"lstduela"     , "mame", 3, 0 } ,												
{ "Last Duel (bootleg)"                                                                                   ,"lstduelb"     , "mame", 3, 0 } ,												
{ "Last Mission (US revision 5)"                                                                          ,"lastmss2"     , "mame", 3, 0 } ,												
{ "Last Mission (US revision 6)"                                                                          ,"lastmiss"     , "mame", 3, 0 } ,												
{ "Last Resort"                                                                                           ,"lresort"      , "neomame", 3, 0 } ,												
{ "Lazer Command"                                                                                         ,"lazercmd"     , "mame", 3, 0 } ,												
{ "Le Bagnard"                                                                                            ,"bagnard"      , "mame", 3, 0 } ,												
{ "League Bowling"                                                                                        ,"lbowling"     , "neomame", 3, 0 } ,												
{ "Led Storm (US)"                                                                                        ,"ledstorm"     , "mame", 3, 0 } ,												
{ "Legend of Hero Tonma"                                                                                  ,"loht"         , "mame", 1, 0 } ,												
{ "Legend of Kage, The (bootleg set 1)"                                                                   ,"lkageb"       , "mame", 3, 0 } ,												
{ "Legend of Kage, The (bootleg set 2)"                                                                   ,"lkageb2"      , "mame", 3, 0 } ,												
{ "Legend of Kage, The (bootleg set 3)"                                                                   ,"lkageb3"      , "mame", 3, 0 } ,												
{ "Legend of Kage, The"                                                                                   ,"lkage"        , "mame", 3, 0 } ,												
{ "Legend of Makai (World)"                                                                               ,"lomakai"      , "mame", 3, 0 } ,												
{ "Legend of Success Joe / Ashitano Joe Densetsu"                                                         ,"legendos"     , "neomame", 3, 0 } ,												
{ "Legend of the Valkyrie (Japan)"                                                                        ,"valkyrie"     , "mame", 3, 0 } ,												
{ "Legendary Wings (US set 1)"                                                                            ,"lwings"       , "mame", 5, 0 } ,												
{ "Legendary Wings (US set 2)"                                                                            ,"lwings2"      , "mame", 5, 0 } ,												
{ "Leprechaun"                                                                                            ,"leprechn"     , "mame", 3, 0 } ,												
{ "Lethal Thunder (World)"                                                                                ,"lethalth"     , "mame", 3, 0 } ,												
{ "Levers"                                                                                                ,"levers"       , "mame", 3, 0 } ,												
{ "Liberator (set 1)"                                                                                     ,"liberatr"     , "mame", 3, 0 } ,												
{ "Lifeforce (Japan)"                                                                                     ,"lifefrcj"     , "mame", 3, 0 } ,												
{ "Lifeforce (US)"                                                                                        ,"lifefrce"     , "mame", 3, 0 } ,												
{ "Lightning Fighters (US)"                                                                               ,"lgtnfght"     , "mame", 3, 0 } ,												
{ "Liquid Kids (US)"                                                                                      ,"liquidku"     , "mame", 3, 0 } ,												
{ "Liquid Kids (World)"                                                                                   ,"liquidk"      , "mame", 3, 0 } ,												
{ "Lizard Wizard"                                                                                         ,"lizwiz"       , "mame", 3, 0 } ,												
{ "Lock'n'Chase"                                                                                          ,"lnc"          , "mame", 3, 0 } ,												
{ "Loco-Motion"                                                                                           ,"locomotn"     , "mame", 3, 0 } ,												
{ "Lode Runner (set 1)"                                                                                   ,"ldrun"        , "mame", 3, 0 } ,												
{ "Lode Runner (set 2)"                                                                                   ,"ldruna"       , "mame", 3, 0 } ,												
{ "Lode Runner II - The Bungeling Strikes Back"                                                           ,"ldrun2"       , "mame", 3, 0 } ,												
{ "Lode Runner III - Majin No Fukkatsu"                                                                   ,"ldrun3"       , "mame", 3, 0 } ,												
{ "Lode Runner IV - Teikoku Karano Dasshutsu"                                                             ,"ldrun4"       , "mame", 3, 0 } ,												
{ "Logic Pro"                                                                                             ,"logicpro"       , "mame", 3, 0 } ,												
{ "Logic Pro 2 (Japan)"                                                                                   ,"logicpr2"       , "mame", 3, 0 } ,												
{ "Looper"                                                                                                ,"looper"       , "mame", 3, 0 } ,												
{ "Lord of King, The (Japan)"                                                                             ,"lordofk"      , "mame", 3, 0 } ,												
{ "Lost Tomb (easy)"                                                                                      ,"losttomb"     , "mame", 3, 0 } ,												
{ "Lost Tomb (hard)"                                                                                      ,"losttmbh"     , "mame", 3, 0 } ,												
{ "Lost Worlds (Japan)"                                                                                   ,"lostwrld"     , "mame", 3, 0 } ,												
{ "Lot Lot"                                                                                               ,"lotlot"       , "mame", 3, 0 } ,												
{ "Lunar Lander (rev 1)"                                                                                  ,"llander1"     , "mame", 3, 0 } ,												
{ "Lunar Lander (rev 2)"                                                                                  ,"llander"      , "mame", 3, 0 } ,												
{ "Lunar Rescue"                                                                                          ,"lrescue"      , "mame", 3, 0 } ,												
{ "Lupin III"                                                                                             ,"lupin3"       , "mame", 3, 0 } ,												
{ "M-4"                                                                                                   ,"m4"           , "mame", 3, 0 } ,												
{ "M.A.C.H. 3"                                                                                            ,"mach3"        , "mame", 3, 0 } ,												
{ "M79 Ambush"                                                                                            ,"m79amb"       , "mame", 3, 0 } ,												
{ "MX5000"                                                                                                ,"mx5000"       , "mame", 3, 0 } ,												
{ "Macho Mouse"                                                                                           ,"machomou"     , "mame", 3, 0 } ,												
{ "Mad Crasher"                                                                                           ,"madcrash"     , "mame", 3, 0 } ,												
{ "Mad Gear (Japan)"                                                                                      ,"madgearj"     , "mame", 3, 0 } ,												
{ "Mad Gear (US)"                                                                                         ,"madgear"      , "mame", 3, 0 } ,												
{ "Mad Motor"                                                                                             ,"madmotor"     , "mame", 3, 0 } ,												
{ "Mad Planets"                                                                                           ,"mplanets"     , "mame", 3, 0 } ,												
{ "Magic Brush"                                                                                           ,"mbrush"       , "mame", 3, 0 } ,												
{ "Magic Sword (Japan)"                                                                                   ,"mswordj"      , "mame", 3, 0 } ,												
{ "Magic Sword - Heroic Fantasy (US)"                                                                     ,"mswordu"      , "mame", 3, 0 } ,												
{ "Magic Sword - Heroic Fantasy (World)"                                                                  ,"msword"       , "mame", 3, 0 } ,												
{ "Magical Drop II"                                                                                       ,"magdrop2"     , "neomame", 3, 0 } ,												
{ "Magical Drop III"                                                                                      ,"magdrop3"     , "neomame", 3, 0 } ,												
{ "Magical Spot II"                                                                                       ,"magspot2"     , "mame", 3, 0 } ,												
{ "Magician Lord (set 1)"                                                                                 ,"maglord"      , "neomame", 3, 0 } ,												
{ "Magician Lord (set 2)"                                                                                 ,"maglordh"     , "neomame", 3, 0 } ,												
{ "Magix"                                                                                                 ,"magix"        , "mame", 3, 0 } ,												
{ "Mahjong Gakuen 2 Gakuen-chou no Fukushuu"                                                              ,"mgakuen2"     , "mame", 1, 0 } ,												
{ "Mahjong Gakuen"                                                                                        ,"mgakuen"      , "mame", 3, 0 } ,												
{ "Mahjong Kyoretsuden"                                                                                   ,"mahretsu"     , "neomame", 3, 0 } ,												
{ "Mahjong Quest (Japan)"                                                                                 ,"mjnquest"     , "mame", 3, 0 } ,												
{ "Mahjong Quest (No Nudity)"                                                                             ,"mjnquesb"     , "mame", 3, 0 } ,												
{ "Mahou Daisakusen (Japan)"                                                                              ,"mahoudai"     , "mame", 3, 0 } ,												
{ "Main Event, The (version F)"                                                                           ,"mainevt2"     , "mame", 3, 0 } ,												
{ "Main Event, The (version Y)"                                                                           ,"mainevt"      , "mame", 3, 0 } ,												
{ "Majestic Twelve - The Space Invaders Part IV (Japan)"                                                  ,"majest12"     , "mame", 3, 0 } ,												
{ "Major Havoc (Return to Vax)"                                                                           ,"mhavocrv"     , "mame", 3, 0 } ,												
{ "Major Havoc (prototype)"                                                                               ,"mhavocp"      , "mame", 3, 0 } ,												
{ "Major Havoc (rev 2)"                                                                                   ,"mhavoc2"      , "mame", 3, 0 } ,												
{ "Major Havoc (rev 3)"                                                                                   ,"mhavoc"       , "mame", 3, 0 } ,												
{ "Major League"                                                                                          ,"mjleague"     , "mame", 1, 0 } ,												
{ "Major Title (Japan)"                                                                                   ,"majtitle"     , "mame", 1, 0 } ,												
{ "Major Title 2 (World)"                                                                                 ,"majtitl2"     , "mame", 3, 0 } ,												
{ "Majuu no Ohkoku"                                                                                       ,"majuu"        , "mame", 3, 0 } ,												
{ "Makai Densetsu (Japan)"                                                                                ,"makaiden"     , "mame", 3, 0 } ,												
{ "Makai-Mura (Revision C)"                                                                               ,"makaimuc"     , "mame", 3, 0 } ,												
{ "Makai-Mura (Revision G)"                                                                               ,"makaimug"     , "mame", 3, 0 } ,												
{ "Makai-Mura"                                                                                            ,"makaimur"     , "mame", 3, 0 } ,												
{ "Make Trax"                                                                                             ,"maketrax"     , "mame", 1, 0 } ,												
{ "Makyou Senshi (Japan)"                                                                                 ,"makyosen"     , "mame", 3, 0 } ,												
{ "Mania Challenge (set 1)"                                                                               ,"maniach"      , "mame", 3, 0 } ,												
{ "Mania Challenge (set 2)"                                                                               ,"maniach2"     , "mame", 3, 0 } ,												
{ "Mappy (Japan)"                                                                                         ,"mappyjp"      , "mame", 3, 0 } ,												
{ "Mappy (US)"                                                                                            ,"mappy"        , "mame", 3, 0 } ,												
{ "Marble Madness (set 1)"                                                                                ,"marble"       , "mame", 3, 0 } ,												
{ "Marble Madness (set 2)"                                                                                ,"marble2"      , "mame", 3, 0 } ,												
{ "Marble Madness (set 3)"                                                                                ,"marblea"      , "mame", 3, 0 } ,												
{ "Marchen Maze (Japan)"                                                                                  ,"mmaze"        , "mame", 3, 0 } ,												
{ "Marine Boy"                                                                                            ,"marineb"      , "mame", 3, 0 } ,												
{ "Mariner"                                                                                               ,"mariner"      , "mame", 3, 0 } ,												
{ "Mario Bros. (Japan)"                                                                                   ,"mariojp"      , "mame", 3, 0 } ,												
{ "Mario Bros. (US)"                                                                                      ,"mario"        , "mame", 3, 0 } ,												
{ "Mars"                                                                                                  ,"mars"         , "mame", 3, 0 } ,												
{ "Marvel Land (Japan)"                                                                                   ,"marvlanj"     , "mame", 3, 0 } ,												
{ "Marvel Land (US)"                                                                                      ,"marvland"     , "mame", 3, 0 } ,												
{ "Marvin's Maze"                                                                                         ,"marvins"      , "mame", 3, 0 } ,												
{ "Masao"                                                                                                 ,"masao"        , "mame", 3, 0 } ,												
{ "Master of Weapon (World)"                                                                              ,"masterw"      , "mame", 3, 0 } ,												
{ "Mat Mania"                                                                                             ,"matmania"     , "mame", 3, 0 } ,												
{ "Max RPM"                                                                                               ,"maxrpm"       , "mame", 1, 0 } ,												
{ "Mayday (set 1)"                                                                                        ,"mayday"       , "mame", 3, 0 } ,												
{ "Mayday (set 2)"                                                                                        ,"maydaya"      , "mame", 3, 0 } ,												
{ "Mayhem 2002"                                                                                           ,"mayhem"       , "mame", 3, 0 } ,												
{ "Meadows Lanes"                                                                                         ,"medlanes"     , "mame", 3, 0 } ,												
{ "Mega Force"                                                                                            ,"megaforc"     , "mame", 1, 0 } ,												
{ "Mega Man - The Power Battle (Asia)"                                                                    ,"megaman"      , "mame", 3, 0 } ,												
{ "Mega Twins (World)"                                                                                    ,"mtwins"       , "mame", 3, 0 } ,												
{ "Mega Zone (Kosuka)"                                                                                    ,"megaznik"     , "mame", 3, 0 } ,												
{ "Mega Zone"                                                                                             ,"megazone"     , "mame", 3, 0 } ,												
{ "MegaTack"                                                                                              ,"megatack"     , "mame", 3, 0 } ,												
{ "Meikyu Jima (Japan)"                                                                                   ,"kikcubic"     , "mame", 1, 0 } ,												
{ "Meikyuu Hunter G (Japan)"                                                                              ,"meikyuh"      , "mame", 3, 0 } ,												
{ "Mercs (US)"                                                                                            ,"mercsu"       , "mame", 3, 0 } ,												
{ "Mercs (World)"                                                                                         ,"mercs"        , "mame", 3, 0 } ,												
{ "Mermaid"                                                                                               ,"mermaid"      , "mame", 3, 0 } ,												
{ "Meta Fox"                                                                                              ,"metafox"      , "mame", 3, 0 } ,												
{ "Metal Slug - Super Vehicle-001"                                                                        ,"mslug"        , "neomame", 3, 0 } ,												
{ "Metal Slug 2 - Super Vehicle-001/II"                                                                   ,"mslug2"       , "neomame", 3, 0 } ,												
{ "Meteoroids"                                                                                            ,"meteor"       , "mame", 3, 0 } ,												
{ "Metro-Cross"                                                                                           ,"metrocrs"     , "mame", 3, 0 } ,												
{ "Mexico 86"                                                                                             ,"mexico86"     , "mame", 1, 0 } ,												
{ "Midnight Resistance (Japan)"                                                                           ,"midresj"      , "mame", 3, 0 } ,												
{ "Midnight Resistance (US)"                                                                              ,"midresu"      , "mame", 3, 0 } ,												
{ "Midnight Resistance (World)"                                                                           ,"midres"       , "mame", 3, 0 } ,												
{ "Mikie (High School Graffiti)"                                                                          ,"mikiehs"      , "mame", 3, 0 } ,												
{ "Mikie"                                                                                                 ,"mikie"        , "mame", 3, 0 } ,												
{ "Millipede"                                                                                             ,"milliped"     , "mame", 3, 0 } ,												
{ "Minefield"                                                                                             ,"minefld"      , "mame", 3, 0 } ,												
{ "Mini Golf (set 1)"                                                                                     ,"minigolf"     , "mame", 3, 0 } ,												
{ "Mini Golf (set 2)"                                                                                     ,"minigol2"     , "mame", 3, 0 } ,												
{ "Minivader"                                                                                             ,"minivadr"     , "mame", 3, 0 } ,												
{ "Minky Monkey"                                                                                          ,"mmonkey"      , "mame", 3, 0 } ,												
{ "Minnasanno Okagesamadesu"                                                                              ,"minasan"      , "neomame", 3, 0 } ,												
{ "Mirai Ninja (Japan)"                                                                                   ,"mirninja"     , "mame", 3, 0 } ,												
{ "Missile Command (set 1)"                                                                               ,"missile"      , "mame", 3, 0 } ,												
{ "Missile Command (set 2)"                                                                               ,"missile2"     , "mame", 3, 0 } ,												
{ "Missing in Action (Japan)"                                                                             ,"miaj"         , "mame", 3, 0 } ,												
{ "Missing in Action (version S)"                                                                         ,"mia2"         , "mame", 3, 0 } ,												
{ "Missing in Action (version T)"                                                                         ,"mia"          , "mame", 3, 0 } ,												
{ "Mister Viking (Japan)"                                                                                 ,"mrvikinj"     , "mame", 5, 0 } ,												
{ "Mister Viking"                                                                                         ,"mrviking"     , "mame", 5, 0 } ,												
{ "Mizubaku Daibouken (Japan)"                                                                            ,"mizubaku"     , "mame", 3, 0 } ,												
{ "Moguchan"                                                                                              ,"moguchan"     , "mame", 1, 0 } ,												
{ "Mole Attack"                                                                                           ,"mole"         , "mame", 3, 0 } ,												
{ "Momoko 120%"                                                                                           ,"momoko"       , "mame", 3, 0 } ,												
{ "Money Money"                                                                                           ,"monymony"     , "mame", 3, 0 } ,												
{ "Money Puzzle Exchanger / Money Idol Exchanger"                                                         ,"miexchng"     , "neomame", 3, 0 } ,												
{ "Monkey Donkey"                                                                                         ,"monkeyd"      , "mame", 3, 0 } ,												
{ "Monster Bash"                                                                                          ,"monsterb"     , "mame", 1, 0 } ,												
{ "Moon Alien Part 2 (older version)"                                                                     ,"moonal2b"     , "mame", 3, 0 } ,												
{ "Moon Alien Part 2"                                                                                     ,"moonal2"      , "mame", 3, 0 } ,												
{ "Moon Base"                                                                                             ,"moonbase"     , "mame", 3, 0 } ,												
{ "Moon Cresta (Gremlin)"                                                                                 ,"mooncrsg"     , "mame", 3, 0 } ,												
{ "Moon Cresta (Nichibutsu)"                                                                              ,"mooncrst"     , "mame", 3, 0 } ,												
{ "Moon Cresta (bootleg on Galaxian hardware)"                                                            ,"mooncrgx"     , "mame", 3, 0 } ,												
{ "Moon Cresta (bootleg set 1)"                                                                           ,"mooncrsb"     , "mame", 3, 0 } ,												
{ "Moon Cresta (bootleg set 2)"                                                                           ,"mooncrs2"     , "mame", 3, 0 } ,												
{ "Moon Patrol (Williams)"                                                                                ,"mpatrolw"     , "mame", 3, 0 } ,												
{ "Moon Patrol"                                                                                           ,"mpatrol"      , "mame", 3, 0 } ,												
{ "Moon Quasar"                                                                                           ,"moonqsr"      , "mame", 1, 0 } ,												
{ "Moon Ranger"                                                                                           ,"mranger"      , "mame", 3, 0 } ,												
{ "Moon Walker (Set 1)"                                                                                   ,"moonwalk"     , "mame", 1, 0 } ,												
{ "Moon Walker (Set 2)"                                                                                   ,"moonwlka"     , "mame", 1, 0 } ,												
{ "Moon Walker (bootleg)"                                                                                 ,"moonwlkb"     , "mame", 1, 0 } ,												
{ "Moon War II (set 1)"                                                                                   ,"moonwar2"     , "mame", 3, 0 } ,												
{ "Moon War II (set 2)"                                                                                   ,"monwar2a"     , "mame", 3, 0 } ,												
{ "Mortal Kombat (rev 1.0 08/08/92)"                                                                      ,"mkla1"        , "mame", 3, 0 } ,												
{ "Mortal Kombat (rev 2.0 08/18/92)"                                                                      ,"mkla2"        , "mame", 3, 0 } ,												
{ "Mortal Kombat (rev 3.0 08/31/92)"                                                                      ,"mkla3"        , "mame", 3, 0 } ,												
{ "Mortal Kombat (rev 4.0 09/28/92)"                                                                      ,"mkla4"        , "mame", 3, 0 } ,												
{ "Mortal Kombat (rev 5.0 T-Unit 03/19/93)"                                                               ,"mk"           , "mame", 3, 0 } ,												
{ "Mortal Kombat 3 (rev 1.0)"                                                                             ,"mk3r10"       , "mame", 3, 0 } ,												
{ "Mortal Kombat 3 (rev 2.0)"                                                                             ,"mk3r20"       , "mame", 3, 0 } ,												
{ "Mortal Kombat 3 (rev 2.1)"                                                                             ,"mk3"          , "mame", 3, 0 } ,												
{ "Mortal Kombat II (rev L1.4)"                                                                           ,"mk2r14"       , "mame", 3, 0 } ,												
{ "Mortal Kombat II (rev L3.1)"                                                                           ,"mk2"          , "mame", 3, 0 } ,												
{ "Mortal Kombat II (rev L3.2 (European))"                                                                ,"mk2r32"       , "mame", 3, 0 } ,												
{ "MotoRace USA"                                                                                          ,"motorace"     , "mame", 3, 0 } ,												
{ "Motos"                                                                                                 ,"motos"        , "mame", 3, 0 } ,												
{ "Mouse Trap (version 3)"                                                                                ,"mtrap3"       , "mame", 3, 0 } ,												
{ "Mouse Trap (version 4)"                                                                                ,"mtrap4"       , "mame", 3, 0 } ,												
{ "Mouse Trap (version 5)"                                                                                ,"mtrap"        , "mame", 3, 0 } ,												
{ "Mr. Do vs. Unicorns"                                                                                   ,"douni"        , "mame", 1, 0 } ,												
{ "Mr. Do! (Taito)"                                                                                       ,"mrdot"        , "mame", 3, 0 } ,												
{ "Mr. Do! (Universal)"                                                                                   ,"mrdo"         , "mame", 3, 0 } ,												
{ "Mr. Do! (Yukidaruma)"                                                                                  ,"mrdoy"        , "mame", 3, 0 } ,												
{ "Mr. Do! (bugfixed)"                                                                                    ,"mrdofix"      , "mame", 3, 0 } ,												
{ "Mr. Do's Castle (set 1)"                                                                               ,"docastle"     , "mame", 1, 0 } ,												
{ "Mr. Do's Castle (set 2)"                                                                               ,"docastl2"     , "mame", 1, 0 } ,												
{ "Mr. Do's Wild Ride"                                                                                    ,"dowild"       , "mame", 1, 0 } ,												
{ "Mr. Du!"                                                                                               ,"mrdu"         , "mame", 3, 0 } ,												
{ "Mr. Goemon (Japan)"                                                                                    ,"mrgoemon"     , "mame", 3, 0 } ,												
{ "Mr. HELI no Dai-Bouken"                                                                                ,"mrheli"       , "mame", 1, 0 } ,												
{ "Mr. Jong (Japan)"                                                                                      ,"mrjong"       , "mame", 3, 0 } ,												
{ "Mr. Lo!"                                                                                               ,"mrlo"         , "mame", 3, 0 } ,												
{ "Mr. TNT"                                                                                               ,"mrtnt"        , "mame", 3, 0 } ,												
{ "Ms. Pac-Man Plus"                                                                                      ,"mspacatk"     , "mame", 3, 0 } ,												
{ "Ms. Pac-Man"                                                                                           ,"mspacman"     , "mame", 3, 0 } ,												
{ "Munch Mobile (Japan)"                                                                                  ,"mnchmobl"     , "mame", 3, 0 } ,												
{ "Muscle Bomber - The Body Explosion (Japan)"                                                            ,"mbomberj"     , "mame", 1, 0 } ,												
{ "Muscle Bomber Duo - Heat Up Warriors (Japan)"                                                          ,"mbombrdj"     , "mame", 1, 0 } ,												
{ "Muscle Bomber Duo - Ultimate Team Battle (World)"                                                      ,"mbombrd"      , "mame", 1, 0 } ,												
{ "Mutant Night"                                                                                          ,"mnight"       , "mame", 1, 0 } ,												
{ "Mutation Nation"                                                                                       ,"mutnat"       , "neomame", 3, 0 } ,												
{ "My Hero (Korea)"                                                                                       ,"myherok"      , "mame", 3, 0 } ,												
{ "My Hero (US)"                                                                                          ,"myhero"       , "mame", 3, 0 } ,												
{ "Mysterious Stones"                                                                                     ,"mystston"     , "mame", 3, 0 } ,												
{ "Mystic Marathon"                                                                                       ,"mysticm"      , "mame", 3, 0 } ,												
{ "Mystic Riders (World)"                                                                                 ,"mysticri"     , "mame", 3, 0 } ,												
{ "NAM-1975"                                                                                              ,"nam1975"      , "neomame", 3, 0 } ,												
{ "NBA Jam (rev 2.00 02/10/93)"                                                                           ,"nbajamr2"     , "mame", 3, 0 } ,												
{ "NBA Jam (rev 3.01 04/07/93)"                                                                           ,"nbajam"       , "mame", 3, 0 } ,												
{ "NBA Jam TE (rev 1.0 01/17/94)"                                                                         ,"nbajamt1"     , "mame", 3, 0 } ,												
{ "NBA Jam TE (rev 2.0 01/28/94)"                                                                         ,"nbajamt2"     , "mame", 3, 0 } ,												
{ "NBA Jam TE (rev 3.0 03/04/94)"                                                                         ,"nbajamt3"     , "mame", 3, 0 } ,												
{ "NBA Jam TE (rev 4.0 03/23/94)"                                                                         ,"nbajamte"     , "mame", 3, 0 } ,												
{ "NBA Maximum Hangtime (rev 1.0)"                                                                        ,"nbamaxht"     , "mame", 3, 0 } ,												
{ "Name That Tune"                                                                                        ,"nametune"     , "mame", 3, 0 } ,												
{ "Narc (rev 3.20)"                                                                                       ,"narc3"        , "mame", 3, 0 } ,												
{ "Narc (rev 7.00)"                                                                                       ,"narc"         , "mame", 3, 0 } ,												
{ "Nastar (World)"                                                                                        ,"nastar"       , "mame", 3, 0 } ,												
{ "Nastar Warrior (US)"                                                                                   ,"nastarw"      , "mame", 3, 0 } ,												
{ "Naughty Boy (Cinematronics)"                                                                           ,"naughtyc"     , "mame", 3, 0 } ,												
{ "Naughty Boy (bootleg)"                                                                                 ,"naughtya"     , "mame", 3, 0 } ,												
{ "Naughty Boy"                                                                                           ,"naughtyb"     , "mame", 3, 0 } ,												
{ "Navalone"                                                                                              ,"navalone"     , "mame", 3, 0 } ,												
{ "Nebulous Bee"                                                                                          ,"nebulbee"     , "mame", 3, 0 } ,												
{ "Nekketsu Kouha Kunio-kun (Japan bootleg)"                                                              ,"kuniokub"     , "mame", 3, 0 } ,												
{ "Nekketsu Kouha Kunio-kun (Japan)"                                                                      ,"kuniokun"     , "mame", 3, 0 } ,												
{ "Nemesis (World?)"                                                                                      ,"nemesuk"      , "mame", 3, 0 } ,												
{ "Nemesis (hacked?)"                                                                                     ,"nemesis"      , "mame", 3, 0 } ,												
{ "Nemo (Japan)"                                                                                          ,"nemoj"        , "mame", 3, 0 } ,												
{ "Nemo (World)"                                                                                          ,"nemo"         , "mame", 3, 0 } ,												
{ "Neo Bomberman"                                                                                         ,"neobombe"     , "neomame", 3, 0 } ,												
{ "Neo Drift Out - New Technology"                                                                        ,"neodrift"     , "neomame", 3, 0 } ,												
{ "Neo Mr. Do!"                                                                                           ,"neomrdo"      , "neomame", 3, 0 } ,												
{ "Neo Turf Masters / Big Tournament Golf"                                                                ,"turfmast"     , "neomame", 3, 0 } ,												
{ "Neo-Geo Cup '98 - The Road to the Victory"                                                             ,"neocup98"     , "neomame", 3, 0 } ,												
{ "New Puck-X"                                                                                            ,"puckman"      , "mame", 3, 0 } ,												
{ "New Rally X"                                                                                           ,"nrallyx"      , "mame", 1, 0 } ,												
{ "New Sinbad 7"                                                                                          ,"newsin7"      , "mame", 3, 0 } ,												
{ "NewZealand Story 2, The (World)"                                                                       ,"tnzs2"        , "mame", 1, 0 } ,												
{ "NewZealand Story, The (Japan)"                                                                         ,"tnzs"         , "mame", 1, 0 } ,												
{ "NewZealand Story, The (World, bootleg)"                                                                ,"tnzsb"        , "mame", 1, 0 } ,												
{ "Nibbler (set 1)"                                                                                       ,"nibbler"      , "mame", 3, 0 } ,												
{ "Nibbler (set 2)"                                                                                       ,"nibblera"     , "mame", 3, 0 } ,												
{ "Night Driver"                                                                                          ,"nitedrvr"     , "mame", 3, 0 } ,												
{ "Night Stocker"                                                                                         ,"nstocker"     , "mame", 3, 0 } ,												
{ "Ninja Combat"                                                                                          ,"ncombat"      , "neomame", 3, 0 } ,												
{ "Ninja Commando"                                                                                        ,"ncommand"     , "neomame", 3, 0 } ,												
{ "Ninja Emaki (US)"                                                                                      ,"ninjemak"     , "mame", 3, 0 } ,												
{ "Ninja Gaiden (World)"                                                                                  ,"gaiden"       , "mame", 3, 0 } ,												
{ "Ninja Kid II (set 1)"                                                                                  ,"ninjakd2"     , "mame", 1, 0 } ,												
{ "Ninja Kid II (set 2)"                                                                                  ,"ninjak2a"     , "mame", 1, 0 } ,												
{ "Ninja Kid II (set 3)"                                                                                  ,"ninjak2b"     , "mame", 1, 0 } ,												
{ "Ninja Kids (Japan)"                                                                                    ,"ninjakj"      , "mame", 3, 0 } ,												
{ "Ninja Kids (World)"                                                                                    ,"ninjak"       , "mame", 3, 0 } ,												
{ "Ninja Master's - haoh-ninpo-cho"                                                                       ,"ninjamas"     , "neomame", 3, 0 } ,												
{ "Ninja Princess (bootleg?)"                                                                             ,"nprincsb"     , "mame", 5, 0 } ,												
{ "Ninja Princess (not encrypted)"                                                                        ,"nprincsu"     , "mame", 5, 0 } ,												
{ "Ninja Princess"                                                                                        ,"nprinces"     , "mame", 5, 0 } ,												
{ "Ninja Ryukenden (Japan)"                                                                               ,"ryukendn"     , "mame", 3, 0 } ,												
{ "Ninja Spirit"                                                                                          ,"nspirit"      , "mame", 1, 0 } ,												
{ "No Man's Land (Gottlieb)"                                                                              ,"nomnlndg"     , "mame", 3, 0 } ,												
{ "No Man's Land"                                                                                         ,"nomnlnd"      , "mame", 3, 0 } ,												
{ "Nova 2001 (Japan)"                                                                                     ,"nova2001"     , "mame", 3, 0 } ,												
{ "Nova 2001 (US)"                                                                                        ,"nov2001u"     , "mame", 3, 0 } ,												
{ "Nunchackun"                                                                                            ,"nunchaku"     , "mame", 3, 0 } ,												
{ "Off the Wall (2-player cocktail)"                                                                      ,"offtwalc"     , "mame", 3, 0 } ,												
{ "Off the Wall (2/3-player upright)"                                                                     ,"offtwall"     , "mame", 3, 0 } ,												
{ "Off the Wall (Sente)"                                                                                  ,"otwalls"      , "mame", 3, 0 } ,												
{ "Oh My God! (Japan)"                                                                                    ,"ohmygod"      , "mame", 3, 0 } ,												
{ "Ohgon no Siro (Japan)"                                                                                 ,"ogonsiro"     , "mame", 3, 0 } ,												
{ "Oli-Boo-Chu"                                                                                           ,"olibochu"     , "mame", 1, 0 } ,												
{ "Omega Race"                                                                                            ,"omegrace"     , "mame", 3, 0 } ,												
{ "Operation Ragnagard / Shin-Oh-Ken"                                                                     ,"ragnagrd"     , "neomame", 3, 0 } ,												
{ "Orbitron"                                                                                              ,"orbitron"     , "mame", 3, 0 } ,												
{ "Ordyne (Japan)"                                                                                        ,"ordyne"       , "mame", 3, 0 } ,												
{ "Out Run (set 1)"                                                                                       ,"outrun"       , "mame", 1, 0 } ,												
{ "Out Run (set 2)"                                                                                       ,"outruna"      , "mame", 1, 0 } ,												
{ "Out Run (set 3)"                                                                                       ,"outrunb"      , "mame", 1, 0 } ,												
{ "Out Zone (bootleg)"                                                                                    ,"outzonep"     , "mame", 3, 0 } ,												
{ "Out Zone"                                                                                              ,"outzone"      , "mame", 3, 0 } ,												
{ "Over Top"                                                                                              ,"overtop"      , "neomame", 3, 0 } ,												
{ "Ozma Wars"                                                                                             ,"ozmawars"     , "mame", 3, 0 } ,												
{ "P-47 - The Freedom Fighter (Japan)"                                                                    ,"p47j"         , "mame", 3, 0 } ,												
{ "P-47 - The Phantom Fighter (World)"                                                                    ,"p47"          , "mame", 3, 0 } ,												
{ "P.O.W. - Prisoners of War (US)"                                                                        ,"pow"          , "mame", 3, 0 } ,												
{ "Pac & Pal (older)"                                                                                     ,"pacnpal2"     , "mame", 3, 0 } ,												
{ "Pac & Pal"                                                                                             ,"pacnpal"      , "mame", 3, 0 } ,												
{ "Pac-Gal"                                                                                               ,"pacgal"       , "mame", 3, 0 } ,												
{ "Pac-Land (Midway)"                                                                                     ,"paclandm"     , "mame", 3, 0 } ,												
{ "Pac-Land (set 1)"                                                                                      ,"pacland"      , "mame", 3, 0 } ,												
{ "Pac-Land (set 2)"                                                                                      ,"pacland2"     , "mame", 3, 0 } ,												
{ "Pac-Land (set 3)"                                                                                      ,"pacland3"     , "mame", 3, 0 } ,												
{ "Pac-Man & Chomp Chomp"                                                                                 ,"pacnchmp"     , "mame", 3, 0 } ,												
{ "Pac-Man (Hearts)"                                                                                      ,"pacheart"     , "mame", 3, 0 } ,												
{ "Pac-Man (Midway)"                                                                                      ,"pacmanm"      , "mame", 3, 0 } ,												
{ "Pac-Man (Midway, harder)"                                                                              ,"pacmod"       , "mame", 3, 0 } ,												
{ "Pac-Man (bootleg on Galaxian hardware)"                                                                ,"pacmanbl"     , "mame", 3, 0 } ,												
{ "Pac-Man Plus"                                                                                          ,"pacplus"      , "mame", 3, 0 } ,												
{ "Pac-Mania (Japan)"                                                                                     ,"pacmanij"     , "mame", 3, 0 } ,												
{ "Pac-Mania"                                                                                             ,"pacmania"     , "mame", 3, 0 } ,												
{ "Paint Roller"                                                                                          ,"paintrlr"     , "mame", 1, 0 } ,												
{ "Palamedes (Japan)"                                                                                     ,"palamed"      , "mame", 3, 0 } ,												
{ "Pandora's Palace"                                                                                      ,"pandoras"     , "mame", 3, 0 } ,												
{ "Pang (World)"                                                                                          ,"pang"         , "mame", 1, 0 } ,												
{ "Pang (bootleg)"                                                                                        ,"pangb"        , "mame", 1, 0 } ,												
{ "Pang! 3 (Euro)"                                                                                        ,"pang3"        , "mame", 3, 0 } ,												
{ "Pang! 3 (Japan)"                                                                                       ,"pang3j"       , "mame", 3, 0 } ,												
{ "Panic Bomber"                                                                                          ,"panicbom"     , "neomame", 3, 0 } ,												
{ "Paperboy"                                                                                              ,"paperboy"     , "mame", 3, 0 } ,												
{ "Parodius DA! (Japan)"                                                                                  ,"parodius"     , "mame", 3, 0 } ,												
{ "Passing Shot (2 Players) (bootleg)"                                                                    ,"passshtb"     , "mame", 1, 0 } ,												
{ "Passing Shot (2 Players)"                                                                              ,"passsht"      , "mame", 1, 0 } ,												
{ "Passing Shot (4 Players) (bootleg)"                                                                    ,"passht4b"     , "mame", 1, 0 } ,												
{ "Peek-a-Boo!"                                                                                           ,"peekaboo"     , "mame", 3, 0 } ,												
{ "Pengo (set 1)"                                                                                         ,"pengo"        , "mame", 1, 0 } ,												
{ "Pengo (set 2 not encrypted)"                                                                           ,"pengo2u"      , "mame", 3, 0 } ,												
{ "Pengo (set 2)"                                                                                         ,"pengo2"       , "mame", 1, 0 } ,												
{ "Penguin-Kun Wars (Japan)"                                                                              ,"pkunwarj"     , "mame", 3, 0 } ,												
{ "Penguin-Kun Wars (US)"                                                                                 ,"pkunwar"      , "mame", 3, 0 } ,												
{ "Penta"                                                                                                 ,"penta"        , "mame", 1, 0 } ,												
{ "Pepper II"                                                                                             ,"pepper2"      , "mame", 3, 0 } ,												
{ "Percussor, The"                                                                                        ,"percuss"      , "mame", 1, 0 } ,												
{ "Perfect Soldiers (Japan)"                                                                              ,"psoldier"     , "mame", 3, 0 } ,												
{ "Peter Pack-Rat"                                                                                        ,"peterpak"     , "mame", 3, 0 } ,												
{ "Phantasm (Japan)"                                                                                      ,"phantasm"     , "mame", 3, 0 } ,												
{ "Phantom II"                                                                                            ,"phantom2"     , "mame", 3, 0 } ,												
{ "Phelios (Japan)"                                                                                       ,"phelios"      , "mame", 3, 0 } ,												
{ "Phoenix (Amstar)"                                                                                      ,"phoenix"      , "mame", 3, 0 } ,												
{ "Phoenix (Centuri)"                                                                                     ,"phoenixa"     , "mame", 3, 0 } ,												
{ "Phoenix (IRECSA, G.G.I Corp)"                                                                          ,"phoenixc"     , "mame", 3, 0 } ,												
{ "Phoenix (T.P.N.)"                                                                                      ,"phoenix3"     , "mame", 3, 0 } ,												
{ "Phoenix (Taito)"                                                                                       ,"phoenixt"     , "mame", 3, 0 } ,												
{ "Phozon"                                                                                                ,"phozon"       , "mame", 3, 0 } ,												
{ "Pickin'"                                                                                               ,"pickin"       , "mame", 3, 0 } ,												
{ "Pig Newton (version A)"                                                                                ,"pignewta"     , "mame", 1, 0 } ,												
{ "Pig Newton (version C)"                                                                                ,"pignewt"      , "mame", 1, 0 } ,												
{ "Pigout (alternate)"                                                                                    ,"pigouta"      , "mame", 3, 0 } ,												
{ "Pigout"                                                                                                ,"pigout"       , "mame", 3, 0 } ,												
{ "Pigskin 621AD"                                                                                         ,"pigskin"      , "mame", 3, 0 } ,												
{ "Pinball Action (set 1)"                                                                                ,"pbaction"     , "mame", 3, 0 } ,												
{ "Pinball Action (set 2)"                                                                                ,"pbactio2"     , "mame", 3, 0 } ,												
{ "Pinbo (Strike)"                                                                                        ,"pinbos"       , "mame", 3, 0 } ,												
{ "Pinbo"                                                                                                 ,"pinbo"        , "mame", 3, 0 } ,												
{ "Ping Pong"                                                                                             ,"pingpong"     , "mame", 3, 0 } ,												
{ "Pioneer Balloon"                                                                                       ,"pballoon"     , "mame", 3, 0 } ,												
{ "Pipe Dream (Japan)"                                                                                    ,"pipedrm"      , "mame", 3, 0 } ,												
{ "Pipi & Bibis / Whoopee (Japan)"                                                                        ,"pipibibs"     , "mame", 3, 0 } ,												
{ "Pipi & Bibis / Whoopee (Japan) [bootleg ?]"                                                            ,"pipibibi"     , "mame", 3, 0 } ,												
{ "Piranha"                                                                                               ,"piranha"      , "mame", 3, 0 } ,												
{ "Pirate Ship HigeMaru"                                                                                  ,"higemaru"     , "mame", 1, 0 } ,												
{ "Pisces"                                                                                                ,"pisces"       , "mame", 3, 0 } ,												
{ "Pistol Daimyo no Bouken (Japan)"                                                                       ,"pistoldm"     , "mame", 3, 0 } ,												
{ "Pit Fighter (version 3)"                                                                               ,"pitfigh3"     , "mame", 3, 0 } ,												
{ "Pit Fighter (version 4)"                                                                               ,"pitfight"     , "mame", 3, 0 } ,												
{ "Pit, The"                                                                                              ,"thepit"       , "mame", 3, 0 } ,												
{ "Pitfall II (not encrypted)"                                                                            ,"pitfallu"     , "mame", 3, 0 } ,												
{ "Pitfall II"                                                                                            ,"pitfall2"     , "mame", 5, 0 } ,												
{ "Play Girls"                                                                                            ,"plgirls"      , "mame", 3, 0 } ,												
{ "Play Girls 2"                                                                                          ,"plgirls2"     , "mame", 3, 0 } ,												
{ "Pleasure Goal / Futsal - 5 on 5 Mini Soccer"                                                           ,"pgoal"        , "neomame", 3, 0 } ,												
{ "Pleiads (Centuri)"                                                                                     ,"pleiadce"     , "mame", 3, 0 } ,												
{ "Pleiads (Tehkan)"                                                                                      ,"pleiads"      , "mame", 3, 0 } ,												
{ "Pleiads (bootleg)"                                                                                     ,"pleiadbl"     , "mame", 3, 0 } ,												
{ "Plotting (World)"                                                                                      ,"plotting"     , "mame", 3, 0 } ,												
{ "Plump Pop (Japan)"                                                                                     ,"plumppop"     , "mame", 3, 0 } ,												
{ "Plus Alpha"                                                                                            ,"plusalph"     , "mame", 3, 0 } ,												
{ "Pnickies (Japan)"                                                                                      ,"pnickj"       , "mame", 3, 0 } ,												
{ "Pocket Gal (Japan)"                                                                                    ,"pcktgal"      , "mame", 3, 0 } ,												
{ "Pocket Gal (bootleg)"                                                                                  ,"pcktgalb"     , "mame", 3, 0 } ,												
{ "Pocket Gal 2 (World?)"                                                                                 ,"pcktgal2"     , "mame", 3, 0 } ,												
{ "Poker Ladies"                                                                                          ,"pkladies"     , "mame", 1, 0 } ,												
{ "Polaris (set 1)"                                                                                       ,"polaris"      , "mame", 3, 0 } ,												
{ "Polaris (set 2)"                                                                                       ,"polarisa"     , "mame", 3, 0 } ,												
{ "Pole Position (Atari version 1)"                                                                       ,"polepos1"     , "mame", 3, 0 } ,												
{ "Pole Position (Atari version 2)"                                                                       ,"poleposa"     , "mame", 3, 0 } ,												
{ "Pole Position II (Atari bootleg 1)"                                                                    ,"poleps2b"     , "mame", 3, 0 } ,												
{ "Pole Position II (Atari bootleg 2)"                                                                    ,"poleps2c"     , "mame", 3, 0 } ,												
{ "Pole Position II (Atari)"                                                                              ,"poleps2a"     , "mame", 3, 0 } ,												
{ "Pole Position II"                                                                                      ,"polepos2"     , "mame", 3, 0 } ,												
{ "Pole Position"                                                                                         ,"polepos"      , "mame", 3, 0 } ,												
{ "Poly-Play"                                                                                             ,"polyplay"     , "mame", 3, 0 } ,												
{ "Pomping World (Japan)"                                                                                 ,"pompingw"     , "mame", 1, 0 } ,												
{ "Ponpoko (Venture Line)"                                                                                ,"ponpokov"     , "mame", 3, 0 } ,												
{ "Ponpoko"                                                                                               ,"ponpoko"      , "mame", 3, 0 } ,												
{ "Pootan"                                                                                                ,"pootan"       , "mame", 3, 0 } ,												
{ "Pooyan (Stern)"                                                                                        ,"pooyans"      , "mame", 3, 0 } ,												
{ "Pooyan"                                                                                                ,"pooyan"       , "mame", 3, 0 } ,												
{ "Pop 'n Bounce / Gapporin"                                                                              ,"popbounc"     , "neomame", 1, 0 } ,												
{ "Pop Flamer (set 1)"                                                                                    ,"popflame"     , "mame", 3, 0 } ,												
{ "Pop Flamer (set 2)"                                                                                    ,"popflama"     , "mame", 3, 0 } ,												
{ "Popeye (bootleg)"                                                                                      ,"popeyebl"     , "mame", 3, 0 } ,												
{ "Popeye (set 1)"                                                                                        ,"popeye"       , "mame", 3, 0 } ,												
{ "Popeye (set 2)"                                                                                        ,"popeye2"      , "mame", 3, 0 } ,												
{ "Port Man"                                                                                              ,"portman"      , "mame", 3, 0 } ,												
{ "Pot of Gold"                                                                                           ,"potogold"     , "mame", 3, 0 } ,												
{ "Pound for Pound (US)"                                                                                  ,"poundfou"     , "mame", 1, 0 } ,												
{ "Pound for Pound (World)"                                                                               ,"poundfor"     , "mame", 1, 0 } ,												
{ "Power Drive"                                                                                           ,"powerdrv"     , "mame", 1, 0 } ,												
{ "Power Instinct (USA) [bootleg]"                                                                        ,"powerins"     , "mame", 3, 0 } ,												
{ "Power Spikes (Korea)"                                                                                  ,"pspikes"      , "mame", 1, 0 } ,												
{ "Power Spikes II"                                                                                       ,"pspikes2"     , "neomame", 1, 0 } ,												
{ "Power Surge"                                                                                           ,"psurge"       , "mame", 3, 0 } ,												
{ "Prehistoric Isle in 1930 (US)"                                                                         ,"prehislu"     , "mame", 3, 0 } ,												
{ "Prehistoric Isle in 1930 (World)"                                                                      ,"prehisle"     , "mame", 3, 0 } ,												
{ "Psychic 5"                                                                                             ,"psychic5"     , "mame", 5, 0 } ,												
{ "Psycho Soldier (Japan)"                                                                                ,"psychosj"     , "mame", 3, 0 } ,												
{ "Psycho Soldier (US)"                                                                                   ,"psychos"      , "mame", 3, 0 } ,												
{ "Psycho-Nics Oscar (Japan revision 0)"                                                                  ,"oscarj0"      , "mame", 3, 0 } ,												
{ "Psycho-Nics Oscar (Japan revision 1)"                                                                  ,"oscarj1"      , "mame", 3, 0 } ,												
{ "Psycho-Nics Oscar (Japan revision 2)"                                                                  ,"oscarj"       , "mame", 3, 0 } ,												
{ "Psycho-Nics Oscar (US)"                                                                                ,"oscar"        , "mame", 3, 0 } ,												
{ "PuLiRuLa (Japan)"                                                                                      ,"pulirulj"     , "mame", 3, 0 } ,												
{ "PuLiRuLa (World)"                                                                                      ,"pulirula"     , "mame", 3, 0 } ,												
{ "PuckMan (Japan set 1)"                                                                                 ,"pacman"       , "mame", 3, 0 } ,												
{ "PuckMan (Japan set 2)"                                                                                 ,"pacmanjp"     , "mame", 3, 0 } ,												
{ "PuckMan (harder?)"                                                                                     ,"npacmod"      , "mame", 3, 0 } ,												
{ "Pulsar"                                                                                                ,"pulsar"       , "mame", 3, 0 } ,												
{ "Pulstar"                                                                                               ,"pulstar"      , "neomame", 3, 0 } ,												
{ "Punch-Out!!"                                                                                           ,"punchout"     , "mame", 1, 0 } ,												
{ "Punisher, The (Japan)"                                                                                 ,"punishrj"     , "mame", 1, 0 } ,												
{ "Punisher, The (US)"                                                                                    ,"punishru"     , "mame", 1, 0 } ,												
{ "Punisher, The (World)"                                                                                 ,"punisher"     , "mame", 1, 0 } ,												
{ "Punk Shot (2 Players)"                                                                                 ,"punksht2"     , "mame", 3, 0 } ,												
{ "Punk Shot (4 Players)"                                                                                 ,"punkshot"     , "mame", 3, 0 } ,												
{ "Puzzle Bobble (Japan, B-System)"                                                                       ,"puzbobb"      , "mame", 3, 0 } ,												
{ "Puzzle Bobble / Bust-A-Move (Neo-Geo)"                                                                 ,"pbobble"      , "neomame", 3, 0 } ,												
{ "Puzzle Club (Japan prototype)"                                                                         ,"puzlclub"     , "mame", 3, 0 } ,												
{ "Puzzle De Pon R"                                                                                       ,"puzzldpr"     , "neomame", 3, 0 } ,												
{ "Puzzle De Pon"                                                                                         ,"puzzledp"     , "neomame", 3, 0 } ,												
{ "Puzzled / Joy Joy Kid"                                                                                 ,"joyjoy"       , "neomame", 3, 0 } ,												
{ "Puzznic (Japan)"                                                                                       ,"puzznic"      , "mame", 3, 0 } ,												
{ "Pyros (US)"                                                                                            ,"pyros"        , "mame", 3, 0 } ,												
{ "Q*bert (Japan)"                                                                                        ,"qbertjp"      , "mame", 3, 0 } ,												
{ "Q*bert (US)"                                                                                           ,"qbert"        , "mame", 3, 0 } ,												
{ "Q*bert's Qubes"                                                                                        ,"qbertqub"     , "mame", 3, 0 } ,												
{ "Qix (set 1)"                                                                                           ,"qix"          , "mame", 3, 0 } ,												
{ "Qix (set 2)"                                                                                           ,"qixa"         , "mame", 3, 0 } ,												
{ "Qix (set 3)"                                                                                           ,"qixb"         , "mame", 3, 0 } ,												
{ "Qix II (Tournament)"                                                                                   ,"qix2"         , "mame", 3, 0 } ,												
{ "Quantum (prototype)"                                                                                   ,"quantump"     , "mame", 3, 0 } ,												
{ "Quantum (rev 1)"                                                                                       ,"quantum1"     , "mame", 3, 0 } ,												
{ "Quantum (rev 2)"                                                                                       ,"quantum"      , "mame", 3, 0 } ,												
{ "Quarterback (set 2)"                                                                                   ,"quartrba"     , "mame", 3, 0 } ,												
{ "Quarterback"                                                                                           ,"quarterb"     , "mame", 3, 0 } ,												
{ "Quartet (Japan)"                                                                                       ,"quartetj"     , "mame", 3, 0 } ,												
{ "Quartet II"                                                                                            ,"quartet2"     , "mame", 3, 0 } ,												
{ "Quartet"                                                                                               ,"quartet"      , "mame", 3, 0 } ,												
{ "Quarth (Japan)"                                                                                        ,"quarth"       , "mame", 3, 0 } ,												
{ "Quester (Japan)"                                                                                       ,"quester"      , "mame", 3, 0 } ,												
{ "Quiz & Dragons (Japan)"                                                                                ,"qadj"         , "mame", 3, 0 } ,												
{ "Quiz & Dragons (US)"                                                                                   ,"qad"          , "mame", 3, 0 } ,												
{ "Quiz Chikyu Bouei Gun (Japan)"                                                                         ,"qzchikyu"     , "mame", 3, 0 } ,												
{ "Quiz Crayon Shinchan (Japan)"                                                                          ,"qcrayon"      , "mame", 3, 0 } ,												
{ "Quiz Crayon Shinchan Orato Asobo (Japan)"                                                              ,"qcrayon2"     , "mame", 3, 0 } ,												
{ "Quiz Daisousa Sen - The Last Count Down"                                                               ,"quizdais"     , "neomame", 3, 0 } ,												
{ "Quiz HQ (Japan)"                                                                                       ,"quizhq"       , "mame", 3, 0 } ,												
{ "Quiz Jinsei Gekijoh (Japan)"                                                                           ,"qjinsei"      , "mame", 3, 0 } ,												
{ "Quiz King of Fighters"                                                                                 ,"quizkof"      , "neomame", 3, 0 } ,												
{ "Quiz Meintantei Neo Geo - Quiz Daisousa Sen Part 2"                                                    ,"quizdai2"     , "neomame", 3, 0 } ,												
{ "Quiz Quest - Hime to Yuusha no Monogatari (Japan)"                                                     ,"qzquest"      , "mame", 3, 0 } ,												
{ "Quiz Sangokushi (Japan)"                                                                               ,"qsangoku"     , "mame", 1, 0 } ,												
{ "Quiz Sekai wa SHOW by shobai (Japan)"                                                                  ,"qzshowby"     , "mame", 3, 0 } ,												
{ "Quiz Tonosama no Yabou (Japan)"                                                                        ,"qtono1"       , "mame", 1, 0 } ,												
{ "Quiz Tonosama no Yabou 2 Zenkoku-ban (Japan)"                                                          ,"qtono2"       , "mame", 3, 0 } ,												
{ "Quiz Torimonochou (Japan)"                                                                             ,"qtorimon"     , "mame", 3, 0 } ,												
{ "Qwak (prototype)"                                                                                      ,"qwakprot"     , "mame", 3, 0 } ,												
{ "R-Type (Japan prototype)"                                                                              ,"rtypepj"      , "mame", 1, 0 } ,												
{ "R-Type (Japan)"                                                                                        ,"rtype"        , "mame", 1, 0 } ,												
{ "R-Type (US)"                                                                                           ,"rtypeu"       , "mame", 1, 0 } ,												
{ "R-Type II (Japan)"                                                                                     ,"rtype2j"      , "mame", 1, 0 } ,												
{ "R-Type II"                                                                                             ,"rtype2"       , "mame", 1, 0 } ,												
{ "R-Type Leo (Japan)"                                                                                    ,"rtypeleo"     , "mame", 3, 0 } ,												
{ "Rabbit Punch (US)"                                                                                     ,"rpunch"       , "mame", 3, 0 } ,												
{ "Rabio Lepus (Japan)"                                                                                   ,"rabiolep"     , "mame", 3, 0 } ,												
{ "Rack 'em Up"                                                                                           ,"rackemup"     , "mame", 3, 0 } ,												
{ "Rad Action"                                                                                            ,"rdaction"     , "mame", 3, 0 } ,												
{ "Radar Scope"                                                                                           ,"radarscp"     , "mame", 1, 0 } ,												
{ "Radical Radial"                                                                                        ,"radrad"       , "mame", 3, 0 } ,												
{ "Raiden (Alternate Hardware)"                                                                           ,"raidena"      , "mame", 1, 0 } ,												
{ "Raiden (Korea)"                                                                                        ,"raidenk"      , "mame", 1, 0 } ,												
{ "Raiden"                                                                                                ,"raiden"       , "mame", 1, 0 } ,												
{ "Raimais (Japan)"                                                                                       ,"raimais"      , "mame", 5, 0 } ,												
{ "Rainbow Islands (Extra)"                                                                               ,"rainbowe"     , "mame", 1, 0 } ,												
{ "Rainbow Islands"                                                                                       ,"rainbow"      , "mame", 3, 0 } ,												
{ "Rally Bike / Dash Yarou"                                                                               ,"rallybik"     , "mame", 3, 0 } ,												
{ "Rally X (Midway)"                                                                                      ,"rallyxm"      , "mame", 1, 0 } ,												
{ "Rally X"                                                                                               ,"rallyx"       , "mame", 1, 0 } ,												
{ "Rambo III (set 1, Europe)"                                                                             ,"rambo3"       , "mame", 3, 0 } ,												
{ "Rambo III (set 2, US)"                                                                                 ,"rambo3a"      , "mame", 3, 0 } ,												
{ "Rampage (revision 2)"                                                                                  ,"rampage2"     , "mame", 1, 0 } ,												
{ "Rampage (revision 3)"                                                                                  ,"rampage"      , "mame", 1, 0 } ,												
{ "Rampage: World Tour (rev 1.1)"                                                                         ,"rmpgwt11"     , "mame", 3, 0 } ,												
{ "Rampage: World Tour (rev 1.3)"                                                                         ,"rmpgwt"       , "mame", 3, 0 } ,												
{ "Rampart (2-player Joystick)"                                                                           ,"ramprt2p"     , "mame", 3, 0 } ,												
{ "Rampart (3-player Trackball)"                                                                          ,"rampart"      , "mame", 3, 0 } ,												
{ "Rampart (Japan, 2-player Joystick)"                                                                    ,"rampartj"     , "mame", 3, 0 } ,												
{ "Rastan (US set 1)"                                                                                     ,"rastanu"      , "mame", 3, 0 } ,												
{ "Rastan (US set 2)"                                                                                     ,"rastanu2"     , "mame", 3, 0 } ,												
{ "Rastan (World)"                                                                                        ,"rastan"       , "mame", 3, 0 } ,												
{ "Rastan Saga (Japan)"                                                                                   ,"rastsaga"     , "mame", 3, 0 } ,												
{ "Rastan Saga 2 (Japan)"                                                                                 ,"rastsag2"     , "mame", 3, 0 } ,												
{ "Razzmatazz"                                                                                            ,"razmataz"     , "mame", 1, 0 } ,												
{ "Reactor"                                                                                               ,"reactor"      , "mame", 3, 0 } ,												
{ "Real Bout Fatal Fury / Real Bout Garou Densetsu"                                                       ,"rbff1"        , "neomame", 3, 0 } ,												
{ "Real Bout Fatal Fury 2 - The Newcomers / Real Bout Garou Densetsu 2 - the newcomers"                   ,"rbff2"        , "neomame", 3, 0 } ,												
{ "Real Bout Fatal Fury Special / Real Bout Garou Densetsu Special"                                       ,"rbffspec"     , "neomame", 3, 0 } ,												
{ "Real Ghostbusters, The (US 2 Players)"                                                                 ,"ghostb"       , "mame", 3, 0 } ,												
{ "Real Ghostbusters, The (US 3 Players)"                                                                 ,"ghostb3"      , "mame", 3, 0 } ,												
{ "Red Alert"                                                                                             ,"redalert"     , "mame", 3, 0 } ,												
{ "Red Baron"                                                                                             ,"redbaron"     , "mame", 3, 0 } ,												
{ "Redline Racer (2 players)"                                                                             ,"redlin2p"     , "mame", 3, 0 } ,												
{ "Regulus (not encrypted)"                                                                               ,"regulusu"     , "mame", 3, 0 } ,												
{ "Regulus"                                                                                               ,"regulus"      , "mame", 5, 0 } ,												
{ "Relief Pitcher (set 1)"                                                                                ,"relief"       , "mame", 3, 0 } ,												
{ "Relief Pitcher (set 2)"                                                                                ,"relief2"      , "mame", 3, 0 } ,												
{ "Renegade (US)"                                                                                         ,"renegade"     , "mame", 3, 0 } ,												
{ "Repulse"                                                                                               ,"repulse"      , "mame", 3, 0 } ,												
{ "Rescue Raider (Stand-Alone)"                                                                           ,"rescrdsa"     , "mame", 1, 0 } ,												
{ "Rescue Raider"                                                                                         ,"rescraid"     , "mame", 1, 0 } ,												
{ "Rescue"                                                                                                ,"rescue"       , "mame", 3, 0 } ,												
{ "Return of Ishtar, The"                                                                                 ,"roishtar"     , "mame", 3, 0 } ,												
{ "Return of the Invaders (bootleg set 1)"                                                                ,"retofin1"     , "mame", 3, 0 } ,												
{ "Return of the Invaders (bootleg set 2)"                                                                ,"retofin2"     , "mame", 3, 0 } ,												
{ "Return of the Invaders"                                                                                ,"retofinv"     , "mame", 3, 0 } ,												
{ "Return of the Jedi"                                                                                    ,"jedi"         , "mame", 3, 0 } ,												
{ "Riding Hero"                                                                                           ,"ridhero"      , "neomame", 3, 0 } ,												
{ "Ring King (set 1)"                                                                                     ,"ringking"     , "mame", 3, 0 } ,												
{ "Ring King (set 2)"                                                                                     ,"ringkin2"     , "mame", 3, 0 } ,												
{ "Ring King (set 3)"                                                                                     ,"ringkin3"     , "mame", 3, 0 } ,												
{ "Ring no Ohja (Japan)"                                                                                  ,"ringohja"     , "mame", 3, 0 } ,												
{ "Riot City"                                                                                             ,"riotcity"     , "mame", 1, 0 } ,												
{ "Rip Cord"                                                                                              ,"ripcord"      , "mame", 3, 0 } ,												
{ "Rip Off"                                                                                               ,"ripoff"       , "mame", 3, 0 } ,												
{ "River Patrol (bootleg)"                                                                                ,"rpatrolb"     , "mame", 3, 0 } ,												
{ "Road Blasters"                                                                                         ,"roadblst"     , "mame", 0, 0 } ,												
{ "Road Fighter (set 1)"                                                                                  ,"roadf"        , "mame", 3, 0 } ,												
{ "Road Fighter (set 2)"                                                                                  ,"roadf2"       , "mame", 3, 0 } ,												
{ "Road Runner"                                                                                           ,"roadrunn"     , "mame", 3, 0 } ,												
{ "Robby Roto"                                                                                            ,"robby"        , "mame", 1, 0 } ,												
{ "Robo Army"                                                                                             ,"roboarmy"     , "neomame", 3, 0 } ,												
{ "Robocop (US revision 0)"                                                                               ,"robocpu0"     , "mame", 3, 0 } ,												
{ "Robocop (US revision 1)"                                                                               ,"robocopu"     , "mame", 3, 0 } ,												
{ "Robocop (World bootleg)"                                                                               ,"robocopb"     , "mame", 3, 0 } ,												
{ "Robocop (World revision 3)"                                                                            ,"robocop"      , "mame", 3, 0 } ,												
{ "Robot Bowl"                                                                                            ,"robotbwl"     , "mame", 3, 0 } ,												
{ "Robotron (Solid Blue label)"                                                                           ,"robotron"     , "mame", 3, 0 } ,												
{ "Robotron (Yellow/Orange label)"                                                                        ,"robotryo"     , "mame", 3, 0 } ,												
{ "Roc'n Rope (Kosuka)"                                                                                   ,"rocnropk"     , "mame", 3, 0 } ,												
{ "Roc'n Rope"                                                                                            ,"rocnrope"     , "mame", 3, 0 } ,												
{ "Rock 'n Rage (World?)"                                                                                 ,"rockrage"     , "mame", 3, 0 } ,												
{ "Rockman - The Power Battle (Japan)"                                                                    ,"rockmanj"     , "mame", 3, 0 } ,												
{ "RodLand (Japan)"                                                                                       ,"rodlandj"     , "mame", 3, 0 } ,												
{ "RodLand (World)"                                                                                       ,"rodland"      , "mame", 3, 0 } ,												
{ "Rollergames (Japan)"                                                                                   ,"rollergj"     , "mame", 3, 0 } ,												
{ "Rollergames (US)"                                                                                      ,"rollerg"      , "mame", 3, 0 } ,												
{ "Rolling Crash / Moon Base"                                                                             ,"rollingc"     , "mame", 3, 0 } ,												
{ "Rolling Thunder (new version)"                                                                         ,"rthunder"     , "mame", 3, 0 } ,												
{ "Rolling Thunder (old version)"                                                                         ,"rthundro"     , "mame", 3, 0 } ,												
{ "Rolling Thunder 2 (Japan)"                                                                             ,"rthun2j"      , "mame", 3, 0 } ,												
{ "Rolling Thunder 2"                                                                                     ,"rthun2"       , "mame", 3, 0 } ,												
{ "Rompers (Japan old version)"                                                                           ,"romperso"     , "mame", 3, 0 } ,												
{ "Rompers (Japan)"                                                                                       ,"rompers"      , "mame", 3, 0 } ,												
{ "Rough Ranger (v2.0, Sharp Image license)"                                                              ,"rranger"      , "mame", 3, 0 } ,												
{ "Round-Up"                                                                                              ,"roundup"      , "mame", 3, 0 } ,												
{ "Route 16 (bootleg)"                                                                                    ,"route16b"     , "mame", 3, 0 } ,												
{ "Route 16"                                                                                              ,"route16"      , "mame", 3, 0 } ,												
{ "Royal Mahjong"                                                                                         ,"royalmah"     , "mame", 1, 0 } ,												
{ "Rug Rats"                                                                                              ,"rugrats"      , "mame", 3, 0 } ,												
{ "Runark (Japan)"                                                                                        ,"runark"       , "mame", 3, 0 } ,												
{ "Rush & Crash (Japan)"                                                                                  ,"rushcrsh"     , "mame", 3, 0 } ,												
{ "Rush'n Attack"                                                                                         ,"rushatck"     , "mame", 3, 0 } ,												
{ "Rygar (US set 1)"                                                                                      ,"rygar"        , "mame", 3, 0 } ,												
{ "Rygar (US set 2)"                                                                                      ,"rygar2"       , "mame", 3, 0 } ,												
{ "S.P.Y. - Special Project Y (US)"                                                                       ,"spy"          , "mame", 3, 0 } ,												
{ "S.R.D. Mission"                                                                                        ,"srdmissn"     , "mame", 3, 0 } ,												
{ "SAR - Search And Rescue (US)"                                                                          ,"sercharu"     , "mame", 3, 0 } ,												
{ "SAR - Search And Rescue (World)"                                                                       ,"searchar"     , "mame", 3, 0 } ,												
{ "SDI - Strategic Defense Initiative (Japan)"                                                            ,"sdioj"        , "mame", 3, 0 } ,												
{ "SDI - Strategic Defense Initiative"                                                                    ,"sdi"          , "mame", 3, 0 } ,												
{ "SOS"                                                                                                   ,"sos"          , "mame", 3, 0 } ,												
{ "SWAT"                                                                                                  ,"swat"         , "mame", 5, 0 } ,												
{ "Safari Rally"                                                                                          ,"safarir"      , "mame", 3, 0 } ,												
{ "Safari"                                                                                                ,"safari"       , "mame", 3, 0 } ,												
{ "Saigo no Nindou (Japan)"                                                                               ,"nspiritj"     , "mame", 1, 0 } ,												
{ "Saint Dragon"                                                                                          ,"stdragon"     , "mame", 3, 0 } ,												
{ "Salamander"                                                                                            ,"salamand"     , "mame", 3, 0 } ,												
{ "Same! Same! Same!"                                                                                     ,"samesame"     , "mame", 3, 0 } ,												
{ "Samurai (Sega)"                                                                                        ,"samurai"      , "mame", 3, 0 } ,												
{ "Samurai Nihon-ichi (set 1)"                                                                            ,"tsamurai"     , "mame", 3, 0 } ,												
{ "Samurai Nihon-ichi (set 2)"                                                                            ,"tsamura2"     , "mame", 3, 0 } ,												
{ "Samurai Shodown / Samurai Spirits"                                                                     ,"samsho"       , "neomame", 3, 0 } ,												
{ "Samurai Shodown II / Shin Samurai Spirits - Haohmaru jigokuhen"                                        ,"samsho2"      , "neomame", 3, 0 } ,												
{ "Samurai Shodown III / Samurai Spirits - Zankurou Musouken"                                             ,"samsho3"      , "neomame", 3, 0 } ,												
{ "Samurai Shodown IV - Amakusa's Revenge / Samurai Spirits - Amakusa Kourin"                             ,"samsho4"      , "neomame", 3, 0 } ,												
{ "Sangokushi II (Asia)"                                                                                  ,"wofa"         , "mame", 1, 0 } ,												
{ "Sarge"                                                                                                 ,"sarge"        , "mame", 1, 0 } ,												
{ "Sasuke vs. Commander"                                                                                  ,"sasuke"       , "mame", 3, 0 } ,												
{ "Satan of Saturn"                                                                                       ,"satansat"     , "mame", 3, 0 } ,												
{ "Satan's Hollow (set 1)"                                                                                ,"shollow"      , "mame", 5, 0 } ,												
{ "Satan's Hollow (set 2)"                                                                                ,"shollow2"     , "mame", 5, 0 } ,												
{ "Saturday Night Slam Masters (World)"                                                                   ,"slammast"     , "mame", 1, 0 } ,												
{ "Saturn"                                                                                                ,"saturn"       , "mame", 3, 0 } ,												
{ "Sauro"                                                                                                 ,"sauro"        , "mame", 3, 0 } ,												
{ "Savage Bees"                                                                                           ,"savgbees"     , "mame", 1, 0 } ,												
{ "Savage Reign / Fu'un Mokushiroku - kakutou sousei"                                                     ,"savagere"     , "neomame", 3, 0 } ,												
{ "Scion (Cinematronics)"                                                                                 ,"scionc"       , "mame", 3, 0 } ,												
{ "Scion"                                                                                                 ,"scion"        , "mame", 3, 0 } ,												
{ "Scramble (Stern)"                                                                                      ,"scrambls"     , "mame", 3, 0 } ,												
{ "Scramble (bootleg on Galaxian hardware)"                                                               ,"scramblb"     , "mame", 3, 0 } ,												
{ "Scramble"                                                                                              ,"scramble"     , "mame", 3, 0 } ,												
{ "Scrambled Egg"                                                                                         ,"scregg"       , "mame", 3, 0 } ,												
{ "Screw Loose (prototype)"                                                                               ,"screwloo"     , "mame", 3, 0 } ,												
{ "Sea Fighter Poseidon"                                                                                  ,"sfposeid"     , "mame", 3, 0 } ,												
{ "Sea Wolf II"                                                                                           ,"seawolf2"     , "mame", 3, 0 } ,												
{ "Sea Wolf"                                                                                              ,"seawolf"      , "mame", 3, 0 } ,												
{ "Secret Agent (World)"                                                                                  ,"secretag"     , "mame", 3, 0 } ,												
{ "Section Z (set 1)"                                                                                     ,"sectionz"     , "mame", 5, 0 } ,												
{ "Section Z (set 2)"                                                                                     ,"sctionza"     , "mame", 5, 0 } ,												
{ "Sector Zone"                                                                                           ,"sectrzon"     , "mame", 3, 0 } ,												
{ "Sega Ninja (not encrypted)"                                                                            ,"seganinu"     , "mame", 5, 0 } ,												
{ "Sega Ninja"                                                                                            ,"seganinj"     , "mame", 5, 0 } ,												
{ "Seicross"                                                                                              ,"seicross"     , "mame", 3, 0 } ,												
{ "Seishun Scandal (Japan)"                                                                               ,"myheroj"      , "mame", 5, 0 } ,												
{ "Sengoku / Sengoku Denshou (set 1)"                                                                     ,"sengoku"      , "neomame", 3, 0 } ,												
{ "Sengoku / Sengoku Denshou (set 2)"                                                                     ,"sengokh"      , "neomame", 3, 0 } ,												
{ "Sengoku 2 / Sengoku Denshou 2"                                                                         ,"sengoku2"     , "neomame", 3, 0 } ,												
{ "Sengoku Ace (Japan)"                                                                                   ,"sngkace"      , "mame", 3, 0 } ,												
{ "Senjo no Ookami II (Japan)"                                                                            ,"mercsj"       , "mame", 3, 0 } ,												
{ "Senjo no Ookami"                                                                                       ,"commandj"     , "mame", 5, 0 } ,												
{ "Senjyo"                                                                                                ,"senjyo"       , "mame", 1, 0 } ,												
{ "Sente Diagnostic Cartridge"                                                                            ,"sentetst"     , "mame", 3, 0 } ,												
{ "Shackled (US)"                                                                                         ,"shackled"     , "mame", 3, 0 } ,												
{ "Shadow Dancer (Japan)"                                                                                 ,"shdancrj"     , "mame", 1, 0 } ,												
{ "Shadow Dancer (US)"                                                                                    ,"shdancer"     , "mame", 1, 0 } ,												
{ "Shadow Dancer (bootleg)"                                                                               ,"shdancbl"     , "mame", 1, 0 } ,												
{ "Shadow Land"                                                                                           ,"shadowld"     , "mame", 3, 0 } ,												
{ "Shadow Warriors (US)"                                                                                  ,"shadoww"      , "mame", 3, 0 } ,												
{ "Shanghai III (Japan)"                                                                                  ,"shangha3"     , "mame", 3, 0 } ,												
{ "Shanghai"                                                                                              ,"shanghai"     , "mame", 3, 0 } ,												
{ "Shao-Lin's Road"                                                                                       ,"shaolins"     , "mame", 3, 0 } ,												
{ "Shark Attack"                                                                                          ,"sharkatt"     , "mame", 3, 0 } ,												
{ "Sheriff"                                                                                               ,"sheriff"      , "mame", 3, 0 } ,												
{ "Shinnyuushain Tooru-kun"                                                                               ,"mikiej"       , "mame", 3, 0 } ,												
{ "Shinobi (bootleg)"                                                                                     ,"shinobl"      , "mame", 1, 0 } ,												
{ "Shinobi (set 1)"                                                                                       ,"shinobi"      , "mame", 1, 0 } ,												
{ "Shinobi (set 2)"                                                                                       ,"shinobia"     , "mame", 1, 0 } ,												
{ "Shinobi (set 3)"                                                                                       ,"shinobib"     , "mame", 1, 0 } ,												
{ "Shippu Mahou Daisakusen (Japan)"                                                                       ,"shippumd"     , "mame", 3, 0 } ,												
{ "Shisensho - Joshiryo-Hen (Japan)"                                                                      ,"shisen"       , "mame", 1, 0 } ,												
{ "Shock Troopers - 2nd Squad"                                                                            ,"shocktr2"     , "neomame", 3, 0 } ,												
{ "Shock Troopers"                                                                                        ,"shocktro"     , "neomame", 3, 0 } ,												
{ "Shoot Out (Japan)"                                                                                     ,"shootouj"     , "mame", 3, 0 } ,												
{ "Shoot Out (Korean Bootleg)"                                                                            ,"shootoub"     , "mame", 3, 0 } ,												
{ "Shoot Out (US)"                                                                                        ,"shootout"     , "mame", 3, 0 } ,												
{ "Shooting Master"                                                                                       ,"shtngmst"     , "mame", 1, 0 } ,												
{ "Showdown (version 5.0)"                                                                                ,"showdown"     , "mame", 3, 0 } ,												
{ "Shuffleboard"                                                                                          ,"shuffle"      , "mame", 3, 0 } ,												
{ "Shuuz (version 7.1)"                                                                                   ,"shuuz2"       , "mame", 3, 0 } ,												
{ "Shuuz (version 8.0)"                                                                                   ,"shuuz"        , "mame", 3, 0 } ,												
{ "Sichuan II (hack ?) (set 2)"                                                                           ,"sichuana"     , "mame", 1, 0 } ,												
{ "Sichuan II (hack?) (set 1)"                                                                            ,"sichuan2"     , "mame", 1, 0 } ,												
{ "Side Arms - Hyper Dyne (Japan)"                                                                        ,"sidearjp"     , "mame", 3, 0 } ,												
{ "Side Arms - Hyper Dyne (US)"                                                                           ,"sidearmr"     , "mame", 3, 0 } ,												
{ "Side Arms - Hyper Dyne (World)"                                                                        ,"sidearms"     , "mame", 3, 0 } ,												
{ "Side Pocket (Japan)"                                                                                   ,"sidepctj"     , "mame", 3, 0 } ,												
{ "Side Pocket (World)"                                                                                   ,"sidepckt"     , "mame", 3, 0 } ,												
{ "Side Pocket (bootleg)"                                                                                 ,"sidepctb"     , "mame", 3, 0 } ,												
{ "Side Track"                                                                                            ,"sidetrac"     , "mame", 3, 0 } ,												
{ "Silent Dragon (World)"                                                                                 ,"silentd"      , "mame", 3, 0 } ,												
{ "Silkworm (set 1)"                                                                                      ,"silkworm"     , "mame", 3, 0 } ,												
{ "Silkworm (set 2)"                                                                                      ,"silkwrm2"     , "mame", 3, 0 } ,												
{ "Silver Land"                                                                                           ,"silvland"     , "mame", 3, 0 } ,												
{ "Simpsons, The (2 Players Japan)"                                                                       ,"simps2pj"     , "mame", 3, 0 } ,												
{ "Simpsons, The (2 Players)"                                                                             ,"simpsn2p"     , "mame", 3, 0 } ,												
{ "Simpsons, The (4 Players)"                                                                             ,"simpsons"     , "mame", 3, 0 } ,												
{ "Sindbad Mystery"                                                                                       ,"sindbadm"     , "mame", 5, 0 } ,												
{ "Sinistar (prototype version)"                                                                          ,"sinista1"     , "mame", 3, 0 } ,												
{ "Sinistar (revision 2)"                                                                                 ,"sinista2"     , "mame", 3, 0 } ,												
{ "Sinistar (revision 3)"                                                                                 ,"sinistar"     , "mame", 3, 0 } ,												
{ "Skull & Crossbones (set 1)"                                                                            ,"skullxbo"     , "mame", 3, 0 } ,												
{ "Skull & Crossbones (set 2)"                                                                            ,"skullxb2"     , "mame", 3, 0 } ,												
{ "Sky Adventure (US)"                                                                                    ,"skyadvnt"     , "mame", 3, 0 } ,												
{ "Sky Chuter"                                                                                            ,"skychut"      , "mame", 3, 0 } ,												
{ "Sky Diver"                                                                                             ,"skydiver"     , "mame", 3, 0 } ,												
{ "Sky Fox"                                                                                				  ,"skyfox"       , "mame", 3, 0 } ,												
{ "Sky Kid Deluxe (set 1)"                                                                                ,"skykiddx"     , "mame", 3, 0 } ,												
{ "Sky Kid Deluxe (set 2)"                                                                                ,"skykiddo"     , "mame", 3, 0 } ,												
{ "Sky Kid"                                                                                               ,"skykid"       , "mame", 3, 0 } ,												
{ "Sky Lancer"                                                                                            ,"skylancr"     , "mame", 3, 0 } ,												
{ "Sky Shark (US)"                                                                                        ,"skyshark"     , "mame", 3, 0 } ,												
{ "Sky Soldiers (US)"                                                                                     ,"skysoldr"     , "mame", 3, 0 } ,												
{ "Sky Wolf (set 1)"                                                                                      ,"skywolf"      , "mame", 3, 0 } ,												
{ "Sky Wolf (set 2)"                                                                                      ,"skywolf2"     , "mame", 3, 0 } ,												
{ "Slap Fight (English bootleg)"                                                                          ,"slapbtuk"     , "mame", 3, 0 } ,												
{ "Slap Fight (Japan bootleg)"                                                                            ,"slapbtjp"     , "mame", 3, 0 } ,												
{ "Slap Fight"                                                                                            ,"slapfigh"     , "mame", 3, 0 } ,												
{ "Sly Spy (US revision 2)"                                                                               ,"slyspy2"      , "mame", 3, 0 } ,												
{ "Sly Spy (US revision 3)"                                                                               ,"slyspy"       , "mame", 3, 0 } ,												
{ "Smash T.V. (rev 4.00)"                                                                                 ,"smashtv4"     , "mame", 3, 0 } ,												
{ "Smash T.V. (rev 5.00)"                                                                                 ,"smashtv5"     , "mame", 3, 0 } ,												
{ "Smash T.V. (rev 6.00)"                                                                                 ,"smashtv6"     , "mame", 3, 0 } ,												
{ "Smash T.V. (rev 8.00)"                                                                                 ,"smashtv"      , "mame", 3, 0 } ,												
{ "Snacks'n Jaxson"                                                                                       ,"snakjack"     , "mame", 1, 0 } ,												
{ "Snake Pit"                                                                                             ,"snakepit"     , "mame", 3, 0 } ,												
{ "Snap Jack"                                                                                             ,"snapjack"     , "mame", 3, 0 } ,												
{ "Snow Bros. - Nick & Tom (Japan)"                                                                       ,"snowbroj"     , "mame", 3, 0 } ,												
{ "Snow Bros. - Nick & Tom (set 1)"                                                                       ,"snowbros"     , "mame", 3, 0 } ,												
{ "Snow Bros. - Nick & Tom (set 2)"                                                                       ,"snowbroa"     , "mame", 3, 0 } ,												
{ "Snow Bros. - Nick & Tom (set 3)"                                                                       ,"snowbrob"     , "mame", 3, 0 } ,												
{ "Snow Bros. 2 - With New Elves"                                                                         ,"snowbro2"     , "mame", 3, 0 } ,												
{ "Soccer Brawl"                                                                                          ,"socbrawl"     , "neomame", 3, 0 } ,												
{ "Solar Fight"                                                                                           ,"solfight"     , "mame", 3, 0 } ,												
{ "Solar Fox"                                                                                             ,"solarfox"     , "mame", 5, 0 } ,												
{ "Solar Quest"                                                                                           ,"solarq"       , "mame", 3, 0 } ,												
{ "Solar Warrior"                                                                                         ,"solarwar"     , "mame", 3, 0 } ,												
{ "Soldam (Japan)"                                                                                        ,"soldamj"      , "mame", 3, 0 } ,												
{ "Solitary Fighter (World)"                                                                              ,"solfigtr"     , "mame", 3, 0 } ,												
{ "Solomon's Key (Japan)"                                                                                 ,"solomon"      , "mame", 3, 0 } ,												
{ "Son Son"                                                                                               ,"sonson"       , "mame", 3, 0 } ,												
{ "Son of Phoenix"                                                                                        ,"sonofphx"     , "mame", 3, 0 } ,												
{ "Sonic Wings (Japan)"                                                                                   ,"sonicwi"      , "mame", 1, 0 } ,												
{ "Souko Ban Deluxe (Japan)"                                                                              ,"soukobdx"     , "mame", 3, 0 } ,												
{ "Space Attack (cocktail)"                                                                               ,"sspacatc"     , "mame", 3, 0 } ,												
{ "Space Attack (upright)"                                                                                ,"sspaceat"     , "mame", 3, 0 } ,												
{ "Space Attack (upright, older)"                                                                         ,"sspacat2"     , "mame", 3, 0 } ,												
{ "Space Attack II"                                                                                       ,"spaceatt"     , "mame", 3, 0 } ,												
{ "Space Battle"                                                                                          ,"spacbatt"     , "mame", 3, 0 } ,												
{ "Space Bird (bootleg)"                                                                                  ,"spacebrd"     , "mame", 1, 0 } ,												
{ "Space Chaser (CV version)"                                                                             ,"schasrcv"     , "mame", 3, 0 } ,												
{ "Space Chaser"                                                                                          ,"schaser"      , "mame", 3, 0 } ,												
{ "Space Demon"                                                                                           ,"spacedem"     , "mame", 1, 0 } ,												
{ "Space Duel"                                                                                            ,"spacduel"     , "mame", 3, 0 } ,												
{ "Space Dungeon"                                                                                         ,"sdungeon"     , "mame", 3, 0 } ,												
{ "Space Encounters"                                                                                      ,"spcenctr"     , "mame", 3, 0 } ,												
{ "Space Fever (black and white)"                                                                         ,"sfeverbw"     , "mame", 3, 0 } ,												
{ "Space Fever (color)"                                                                                   ,"spacefev"     , "mame", 3, 0 } ,												
{ "Space Firebird (Gremlin)"                                                                              ,"spacefbg"     , "mame", 1, 0 } ,												
{ "Space Firebird (Nintendo)"                                                                             ,"spacefb"      , "mame", 1, 0 } ,												
{ "Space Firebird (bootleg)"                                                                              ,"spacefbb"     , "mame", 1, 0 } ,												
{ "Space Fury (revision A)"                                                                               ,"spacfura"     , "mame", 1, 0 } ,												
{ "Space Fury (revision C)"                                                                               ,"spacfury"     , "mame", 1, 0 } ,												
{ "Space Harrier"                                                                                         ,"sharrier"     , "mame", 3, 0 } ,												
{ "Space Intruder"                                                                                        ,"spaceint"     , "mame", 3, 0 } ,												
{ "Space Invaders (CV Version)"                                                                           ,"sicv"         , "mame", 3, 0 } ,												
{ "Space Invaders (Logitec)"                                                                              ,"invaderl"     , "mame", 3, 0 } ,												
{ "Space Invaders (SV Version 2)"                                                                         ,"sisv2"        , "mame", 3, 0 } ,												
{ "Space Invaders (SV Version)"                                                                           ,"sisv"         , "mame", 3, 0 } ,												
{ "Space Invaders (TV Version)"                                                                           ,"sitv"         , "mame", 3, 0 } ,												
{ "Space Invaders DX (Japan)"                                                                             ,"spacedx"      , "mame", 0, 0 } ,												
{ "Space Invaders Deluxe"                                                                                 ,"invaddlx"     , "mame", 3, 0 } ,												
{ "Space Invaders Galactica"                                                                              ,"galap1"       , "mame", 3, 0 } ,												
{ "Space Invaders II (Midway, cocktail)"                                                                  ,"invad2ct"     , "mame", 3, 0 } ,												
{ "Space Invaders Part II (Taito)"                                                                        ,"invadpt2"     , "mame", 3, 0 } ,												
{ "Space Invaders"                                                                                        ,"invaders"     , "mame", 3, 0 } ,												
{ "Space Invasion"                                                                                        ,"spaceinv"     , "mame", 5, 0 } ,												
{ "Space King"                                                                                            ,"spceking"     , "mame", 3, 0 } ,												
{ "Space Laser"                                                                                           ,"spclaser"     , "mame", 3, 0 } ,												
{ "Space Odyssey"                                                                                         ,"spaceod"      , "mame", 1, 0 } ,												
{ "Space Panic (German)"                                                                                  ,"panicger"     , "mame", 1, 0 } ,												
{ "Space Panic (set 1)"                                                                                   ,"panic"        , "mame", 1, 0 } ,												
{ "Space Panic (set 2)"                                                                                   ,"panica"       , "mame", 1, 0 } ,												
{ "Space Phantoms"                                                                                        ,"spaceph"      , "mame", 3, 0 } ,												
{ "Space Pilot"                                                                                           ,"spaceplt"     , "mame", 3, 0 } ,												
{ "Space Seeker"                                                                                          ,"spaceskr"     , "mame", 3, 0 } ,												
{ "Space Tactics"                                                                                         ,"stactics"     , "mame", 3, 0 } ,												
{ "Space Trek (cocktail)"                                                                                 ,"sptrekct"     , "mame", 3, 0 } ,												
{ "Space Trek (upright)"                                                                                  ,"spacetrk"     , "mame", 3, 0 } ,												
{ "Space War (Leijac)"                                                                                    ,"spcewarl"     , "mame", 3, 0 } ,												
{ "Space War (Sanritsu)"                                                                                  ,"spcewars"     , "mame", 3, 0 } ,												
{ "Space War Part 3"                                                                                      ,"spacewr3"     , "mame", 3, 0 } ,												
{ "Space Wars"                                                                                            ,"spacewar"     , "mame", 3, 0 } ,												
{ "Space Zap"                                                                                             ,"spacezap"     , "mame", 3, 0 } ,												
{ "Sparkz (prototype)"                                                                                    ,"sparkz"       , "mame", 3, 0 } ,												
{ "Spartan X (Japan)"                                                                                     ,"spartanx"     , "mame", 3, 0 } ,												
{ "Speak & Rescue"                                                                                        ,"speakres"     , "mame", 3, 0 } ,												
{ "Spectar (revision 1?)"                                                                                 ,"spectar1"     , "mame", 3, 0 } ,												
{ "Spectar (revision 3)"                                                                                  ,"spectar"      , "mame", 3, 0 } ,												
{ "Speed Ball"                                                                                            ,"speedbal"     , "mame", 3, 0 } ,												
{ "Speed Coin (prototype)"                                                                                ,"spdcoin"      , "mame", 3, 0 } ,												
{ "Speed Freak"                                                                                           ,"speedfrk"     , "mame", 3, 0 } ,												
{ "Speed Rumbler, The (set 1)"                                                                            ,"srumbler"     , "mame", 3, 0 } ,												
{ "Speed Rumbler, The (set 2)"                                                                            ,"srumblr2"     , "mame", 3, 0 } ,												
{ "Spelunker II"                                                                                          ,"spelunk2"     , "mame", 3, 0 } ,												
{ "Spelunker"                                                                                             ,"spelunkr"     , "mame", 3, 0 } ,												
{ "Spiders (set 1)"                                                                                       ,"spiders"      , "mame", 3, 0 } ,												
{ "Spiders (set 2)"                                                                                       ,"spiders2"     , "mame", 3, 0 } ,												
{ "Spiker"                                                                                                ,"spiker"       , "mame", 1, 0 } ,												
{ "Spinal Breakers (Japan)"                                                                               ,"spinlbrj"     , "mame", 3, 0 } ,												
{ "Spinal Breakers (US)"                                                                                  ,"spinlbru"     , "mame", 3, 0 } ,												
{ "Spinal Breakers (World)"                                                                               ,"spinlbrk"     , "mame", 3, 0 } ,												
{ "Spinmaster / Miracle Adventure"                                                                        ,"spinmast"     , "neomame", 3, 0 } ,												
{ "Splash!"                                                                                               ,"splash"       , "mame", 3, 0 } ,												
{ "Splat!"                                                                                                ,"splat"        , "mame", 3, 0 } ,												
{ "Splatter House (Japan)"                                                                                ,"splatter"     , "mame", 3, 0 } ,												
{ "Springer"                                                                                              ,"springer"     , "mame", 3, 0 } ,												
{ "Sprint 1"                                                                                              ,"sprint1"      , "mame", 3, 0 } ,												
{ "Sprint 2"                                                                                              ,"sprint2"      , "mame", 3, 0 } ,												
{ "Spy Hunter 2 (rev 1)"                                                                                  ,"spyhnt2a"     , "mame", 3, 0 } ,												
{ "Spy Hunter 2 (rev 2)"                                                                                  ,"spyhunt2"     , "mame", 3, 0 } ,												
{ "Spy Hunter"                                                                                            ,"spyhunt"      , "mame", 1, 0 } ,												
{ "Stadium Hero (Japan)"                                                                                  ,"stadhero"     , "mame", 3, 0 } ,												
{ "Stakes Winner / Stakes Winner - GI kinzen seihae no michi"                                             ,"stakwin"      , "neomame", 3, 0 } ,												
{ "Stakes Winner 2"                                                                                       ,"stakwin2"     , "neomame", 3, 0 } ,												
{ "Star Castle (older)"                                                                                   ,"starcas1"     , "mame", 3, 0 } ,												
{ "Star Castle (version 3)"                                                                               ,"starcas"      , "mame", 3, 0 } ,												
{ "Star Cruiser"                                                                                          ,"starcrus"     , "mame", 3, 0 } ,												
{ "Star Fire"                                                                                             ,"starfire"     , "mame", 3, 0 } ,												
{ "Star Force (encrypted)"                                                                                ,"starfore"     , "mame", 1, 0 } ,												
{ "Star Force"                                                                                            ,"starforc"     , "mame", 1, 0 } ,												
{ "Star Hawk"                                                                                             ,"starhawk"     , "mame", 3, 0 } ,												
{ "Star Jacker (Sega)"                                                                                    ,"starjack"     , "mame", 3, 0 } ,												
{ "Star Jacker (Stern)"                                                                                   ,"starjacs"     , "mame", 3, 0 } ,												
{ "Star Trek"                                                                                             ,"startrek"     , "mame", 1, 0 } ,												
{ "Star Wars (rev 1)"                                                                                     ,"starwar1"     , "mame", 3, 0 } ,												
{ "Star Wars (rev 2)"                                                                                     ,"starwars"     , "mame", 3, 0 } ,												
{ "Star Wars"                                                                                             ,"starw"        , "mame", 3, 0 } ,												
{ "Stargate"                                                                                              ,"stargate"     , "mame", 3, 0 } ,												
{ "Stinger"                                                                                               ,"stinger"      , "mame", 1, 0 } ,												
{ "Stocker"                                                                                               ,"stocker"      , "mame", 3, 0 } ,												
{ "Stoneage"                                                                                              ,"stoneage"     , "mame", 3, 0 } ,												
{ "Storming Party / Riku Kai Kuu Saizensen"                                                               ,"storming"     , "mame", 3, 0 } ,												
{ "Strategy X (Stern)"                                                                                    ,"stratgys"     , "mame", 3, 0 } ,												
{ "Strategy X"                                                                                            ,"stratgyx"     , "mame", 3, 0 } ,												
{ "Stratovox (bootleg)"                                                                                   ,"stratvxb"     , "mame", 3, 0 } ,												
{ "Stratovox"                                                                                             ,"stratvox"     , "mame", 3, 0 } ,												
{ "Streaking"                                                                                             ,"streakng"     , "mame", 3, 0 } ,												
{ "Street Fight (Germany)"                                                                                ,"stfight"      , "mame", 5, 0 } ,												
{ "Street Fighter (Japan)"                                                                                ,"sf1jp"        , "mame", 3, 0 } ,												
{ "Street Fighter (US)"                                                                                   ,"sf1us"        , "mame", 3, 0 } ,												
{ "Street Fighter (World)"                                                                                ,"sf1"          , "mame", 3, 0 } ,												
{ "Street Fighter II - The World Warrior (Japan 910214)"                                                  ,"sf2jb"        , "mame", 3, 0 } ,												
{ "Street Fighter II - The World Warrior (Japan 911210)"                                                  ,"sf2j"         , "mame", 3, 0 } ,												
{ "Street Fighter II - The World Warrior (US 910206)"                                                     ,"sf2a"         , "mame", 3, 0 } ,												
{ "Street Fighter II - The World Warrior (US 910214)"                                                     ,"sf2b"         , "mame", 3, 0 } ,												
{ "Street Fighter II - The World Warrior (US 910228)"                                                     ,"sf2e"         , "mame", 3, 0 } ,												
{ "Street Fighter II - The World Warrior (World 910214)"                                                  ,"sf2"          , "mame", 3, 0 } ,												
{ "Street Fighter II' - Champion Edition (Accelerator Pt.II)"                                             ,"sf2accp2"     , "mame", 3, 0 } ,												
{ "Street Fighter II' - Champion Edition (Japan)"                                                         ,"sf2cej"       , "mame", 3, 0 } ,												
{ "Street Fighter II' - Champion Edition (Rainbow)"                                                       ,"sf2rb"        , "mame", 3, 0 } ,												
{ "Street Fighter II' - Champion Edition (Red Wave)"                                                      ,"sf2red"       , "mame", 3, 0 } ,												
{ "Street Fighter II' - Champion Edition (US rev A)"                                                      ,"sf2cea"       , "mame", 3, 0 } ,												
{ "Street Fighter II' - Champion Edition (US rev B)"                                                      ,"sf2ceb"       , "mame", 3, 0 } ,												
{ "Street Fighter II' - Champion Edition (World)"                                                         ,"sf2ce"        , "mame", 3, 0 } ,												
{ "Street Fighter II' - Hyper Fighting (US)"                                                              ,"sf2t"         , "mame", 3, 0 } ,												
{ "Street Fighter II' Turbo - Hyper Fighting (Japan)"                                                     ,"sf2tj"        , "mame", 3, 0 } ,												
{ "Street Football"                                                                                       ,"sfootbal"     , "mame", 3, 0 } ,												
{ "Street Hoop / Street Slam / Dunk Dream"                                                                ,"strhoop"      , "neomame", 3, 0 } ,												
{ "Street Smart (Japan version 1)"                                                                        ,"streetsj"     , "mame", 3, 0 } ,												
{ "Street Smart (US version 1)"                                                                           ,"streets1"     , "mame", 3, 0 } ,												
{ "Street Smart (US version 2)"                                                                           ,"streetsm"     , "mame", 3, 0 } ,												
{ "Strider (US)"                                                                                          ,"strider"      , "mame", 3, 0 } ,												
{ "Strider Hiryu (Japan set 1)"                                                                           ,"striderj"     , "mame", 3, 0 } ,												
{ "Strider Hiryu (Japan set 2)"                                                                           ,"stridrja"     , "mame", 3, 0 } ,												
{ "Strike Force (rev 1 02/25/91)"                                                                         ,"strkforc"     , "mame", 3, 0 } ,												
{ "Strike Zone"                                                                                           ,"strkzone"     , "mame", 1, 0 } ,												
{ "Subs"                                                                                                  ,"subs"         , "mame", 3, 0 } ,												
{ "Sundance"                                                                                              ,"sundance"     , "mame", 3, 0 } ,												
{ "Sunset Riders (Asia 2 Players ver. ABD)"                                                               ,"ssrdrabd"     , "mame", 3, 0 } ,												
{ "Sunset Riders (Japan 2 Players ver. JBD)"                                                              ,"ssrdrjbd"     , "mame", 3, 0 } ,												
{ "Sunset Riders (US 2 Players ver. UBC)"                                                                 ,"ssrdrubc"     , "mame", 3, 0 } ,												
{ "Sunset Riders (US 4 Players ver. UAC)"                                                                 ,"ssrdruac"     , "mame", 3, 0 } ,												
{ "Sunset Riders (US 4 Players ver. UDA)"                                                                 ,"ssrdruda"     , "mame", 3, 0 } ,												
{ "Sunset Riders (World 2 Players ver. EBC)"                                                              ,"ssrdrebc"     , "mame", 3, 0 } ,												
{ "Sunset Riders (World 2 Players ver. EBD)"                                                              ,"ssrdrebd"     , "mame", 3, 0 } ,												
{ "Sunset Riders (World 4 Players ver. EAC)"                                                              ,"ssriders"     , "mame", 3, 0 } ,												
{ "Super Bagman (Stern)"                                                                                  ,"sbagmans"     , "mame", 3, 0 } ,												
{ "Super Bagman"                                                                                          ,"sbagman"      , "mame", 3, 0 } ,												
{ "Super Baseball Double Play Home Run Derby"                                                             ,"dblplay"      , "mame", 1, 0 } ,												
{ "Super Basketball"                                                                                      ,"sbasketb"     , "mame", 3, 0 } ,												
{ "Super Bobble Bobble"                                                                                   ,"sboblbob"     , "mame", 3, 0 } ,												
{ "Super Bond"                                                                                            ,"superbon"     , "mame", 1, 0 } ,												
{ "Super Breakout"                                                                                        ,"sbrkout"      , "mame", 3, 0 } ,												
{ "Super Burger Time (Japan)"                                                                             ,"supbtimj"     , "mame", 3, 0 } ,												
{ "Super Burger Time (World)"                                                                             ,"supbtime"     , "mame", 3, 0 } ,												
{ "Super Buster Bros (US)"                                                                                ,"sbbros"       , "mame", 1, 0 } ,												
{ "Super Casino"                                                                                          ,"sucasino"     , "mame", 3, 0 } ,												
{ "Super Champion Baseball"                                                                               ,"sbasebal"     , "mame", 3, 0 } ,												
{ "Super Cobra (Stern)"                                                                                   ,"scobras"      , "mame", 3, 0 } ,												
{ "Super Cobra (bootleg)"                                                                                 ,"scobrab"      , "mame", 3, 0 } ,												
{ "Super Cobra"                                                                                           ,"scobra"       , "mame", 3, 0 } ,												
{ "Super Contra (Japan)"                                                                                  ,"scontraj"     , "mame", 3, 0 } ,												
{ "Super Contra"                                                                                          ,"scontra"      , "mame", 3, 0 } ,												
{ "Super Dodge Ball / Kunio no Nekketsu Toukyuu Densetsu"                                                 ,"sdodgeb"      , "neomame", 3, 0 } ,												
{ "Super Earth Invasion"                                                                                  ,"earthinv"     , "mame", 3, 0 } ,												
{ "Super Formula (Japan)"                                                                                 ,"sformula"     , "mame", 1, 0 } ,												
{ "Super Galaxians"                                                                                       ,"superg"       , "mame", 3, 0 } ,												
{ "Super Hang-On (bootleg)"                                                                               ,"shangonb"     , "mame", 1, 0 } ,												
{ "Super Hang-On"                                                                                         ,"shangon"      , "mame", 1, 0 } ,												
{ "Super High Impact (rev LA1 09/30/91)"                                                                  ,"shimpact"     , "mame", 3, 0 } ,												
{ "Super Invaders (EMAG)"                                                                                 ,"sinvemag"     , "mame", 3, 0 } ,												
{ "Super Invaders (Zenitone-Microsec)"                                                                    ,"sinvzen"      , "mame", 3, 0 } ,												
{ "Super Invaders"                                                                                        ,"superinv"     , "mame", 3, 0 } ,												
{ "Super Locomotive"                                                                                      ,"suprloco"     , "mame", 5, 0 } ,												
{ "Super Marukin-Ban"                                                                                     ,"marukin"      , "mame", 1, 0 } ,												
{ "Super Missile Attack"                                                                                  ,"suprmatk"     , "mame", 3, 0 } ,												
{ "Super Moon Cresta"                                                                                     ,"smooncrs"     , "mame", 3, 0 } ,												
{ "Super Mouse"                                                                                           ,"suprmous"     , "mame", 3, 0 } ,												
{ "Super Pac-Man (Midway)"                                                                                ,"superpcm"     , "mame", 3, 0 } ,												
{ "Super Pac-Man"                                                                                         ,"superpac"     , "mame", 3, 0 } ,												
{ "Super Pang (World)"                                                                                    ,"spang"        , "mame", 1, 0 } ,												
{ "Super Pierrot (Japan)"                                                                                 ,"spiero"       , "mame", 1, 0 } ,												
{ "Super Pool III (I-Vics)"                                                                               ,"spool3i"      , "mame", 3, 0 } ,												
{ "Super Pool III (World?)"                                                                               ,"spool3"       , "mame", 3, 0 } ,												
{ "Super Punch-Out!! (Japan)"                                                                             ,"spnchotj"     , "mame", 1, 0 } ,												
{ "Super Punch-Out!!"                                                                                     ,"spnchout"     , "mame", 1, 0 } ,												
{ "Super Qix (bootleg)"                                                                                   ,"sqixbl"       , "mame", 1, 0 } ,												
{ "Super Qix"                                                                                             ,"superqix"     , "mame", 1, 0 } ,												
{ "Super Real Darwin (Japan)"                                                                             ,"srdarwin"     , "mame", 3, 0 } ,												
{ "Super Sidekicks / Tokuten Ou"                                                                          ,"ssideki"      , "neomame", 3, 0 } ,												
{ "Super Sidekicks 2 - The World Championship / Tokuten Ou 2 - real fight football"                       ,"ssideki2"     , "neomame", 3, 0 } ,												
{ "Super Sidekicks 3 - The Next Glory / Tokuten Ou 3 - eikoue no michi"                                   ,"ssideki3"     , "neomame", 3, 0 } ,												
{ "Super Space Invaders '91 (World)"                                                                      ,"ssi"          , "mame", 3, 0 } ,												
{ "Super Sprint"                                                                                          ,"ssprint"      , "mame", 3, 0 } ,												
{ "Super Spy, The"                                                                                        ,"superspy"     , "neomame", 3, 0 } ,												
{ "Super Stingray"                                                                                        ,"sstingry"     , "mame", 1, 0 } ,												
{ "Super Volley '91 (Japan)"                                                                              ,"svolly91"     , "mame", 1, 0 } ,												
{ "Super Volleyball (Japan)"                                                                              ,"svolley"      , "mame", 1, 0 } ,												
{ "Super Volleyball (Korea)"                                                                              ,"svolleyk"     , "mame", 1, 0 } ,												
{ "Super World Stadium '92 (Japan)"                                                                       ,"sws92"        , "mame", 3, 0 } ,												
{ "Super World Stadium '93 (Japan)"                                                                       ,"sws93"        , "mame", 3, 0 } ,												
{ "Super Xevious"                                                                                         ,"sxevious"     , "mame", 3, 0 } ,												
{ "Super Zaxxon"                                                                                          ,"szaxxon"      , "mame", 1, 0 } ,												
{ "Superman"                                                                                              ,"superman"     , "mame", 3, 0 } ,												
{ "Surprise Attack (Japan)"                                                                               ,"surpratk"     , "mame", 3, 0 } ,												
{ "Swarm"                                                                                                 ,"swarm"        , "mame", 3, 0 } ,												
{ "Swimmer (set 1)"                                                                                       ,"swimmer"      , "mame", 3, 0 } ,												
{ "Swimmer (set 2)"                                                                                       ,"swimmera"     , "mame", 3, 0 } ,												
{ "Syougi No Tatsujin - Master of Syougi"                                                                 ,"mosyougi"     , "neomame", 3, 0 } ,												
{ "Syusse Oozumou (Japan)"                                                                                ,"ssozumo"      , "mame", 3, 0 } ,												
{ "T.T. Mahjong"                                                                                          ,"ttmahjng"     , "mame", 3, 0 } ,												
{ "TNK III (US?)"                                                                                         ,"tnk3"         , "mame", 3, 0 } ,												
{ "Tac/Scan"                                                                                              ,"tacscan"      , "mame", 1, 0 } ,												
{ "Tag Team Wrestling"                                                                                    ,"tagteam"      , "mame", 3, 0 } ,												
{ "Tail to Nose - Great Championship"                                                                     ,"tail2nos"     , "mame", 1, 0 } ,												
{ "Tailgunner"                                                                                            ,"tailg"        , "mame", 3, 0 } ,												
{ "Taisen Karate Dou (Japan VS version)"                                                                  ,"karatevs"     , "mame", 5, 0 } ,												
{ "Takeda Shingen (Japan)"                                                                                ,"tshingen"     , "mame", 3, 0 } ,												
{ "Tank (Japan)"                                                                                          ,"tnk3j"        , "mame", 3, 0 } ,												
{ "Tank Battalion"                                                                                        ,"tankbatt"     , "mame", 3, 0 } ,												
{ "Tank Force (Japan)"                                                                                    ,"tankfrcj"     , "mame", 3, 0 } ,												
{ "Tank Force (US)"                                                                                       ,"tankfrce"     , "mame", 3, 0 } ,												
{ "Tapper (Budweiser)"                                                                                    ,"tapper"       , "mame", 5, 0 } ,												
{ "Tapper (Root Beer)"                                                                                    ,"rbtapper"     , "mame", 5, 0 } ,												
{ "Tapper (Suntory)"                                                                                      ,"sutapper"     , "mame", 5, 0 } ,												
{ "Tapper (alternate)"                                                                                    ,"tappera"      , "mame", 5, 0 } ,												
{ "Targ"                                                                                                  ,"targ"         , "mame", 3, 0 } ,												
{ "Tatakai no Banka (Japan)"                                                                              ,"trojanj"      , "mame", 5, 0 } ,												
{ "Tazz-Mania (Scramble hardware)"                                                                        ,"tazmania"     , "mame", 1, 0 } ,												
{ "Tazz-Mania (Strategy X hardware)"                                                                      ,"tazmani2"     , "mame", 1, 0 } ,												
{ "Tecmo Knight"                                                                                          ,"tknight"      , "mame", 3, 0 } ,												
{ "Tecmo World Soccer '96"                                                                                ,"tws96"        , "neomame", 3, 0 } ,												
{ "TeddyBoy Blues"                                                                                        ,"teddybb"      , "mame", 5, 0 } ,												
{ "Tee'd Off"                                                                                             ,"teedoff"      , "mame", 3, 0 } ,												
{ "Teenage Mutant Hero Turtles (2 Players UK)"                                                            ,"tmht2p"       , "mame", 3, 0 } ,												
{ "Teenage Mutant Hero Turtles (4 Players UK)"                                                            ,"tmht"         , "mame", 3, 0 } ,												
{ "Teenage Mutant Ninja Turtles (2 Players Japan)"                                                        ,"tmnt2pj"      , "mame", 3, 0 } ,												
{ "Teenage Mutant Ninja Turtles (2 Players Oceania)"                                                      ,"tmnt2po"      , "mame", 3, 0 } ,												
{ "Teenage Mutant Ninja Turtles (4 Players Japan)"                                                        ,"tmntj"        , "mame", 3, 0 } ,												
{ "Teenage Mutant Ninja Turtles (4 Players US)"                                                           ,"tmnt"         , "mame", 3, 0 } ,												
{ "Teenage Mutant Ninja Turtles - Turtles in Time (2 Players US)"                                         ,"tmnt22p"      , "mame", 3, 0 } ,												
{ "Teenage Mutant Ninja Turtles - Turtles in Time (4 Players Asia)"                                       ,"tmnt2a"       , "mame", 3, 0 } ,												
{ "Teenage Mutant Ninja Turtles - Turtles in Time (4 Players US)"                                         ,"tmnt2"        , "mame", 3, 0 } ,												
{ "Tehkan World Cup"                                                                                      ,"tehkanwc"     , "mame", 3, 0 } ,												
{ "Teki Paki"                                                                                             ,"tekipaki"     , "mame", 3, 0 } ,												
{ "Tempest (rev 1)"                                                                                       ,"tempest1"     , "mame", 3, 0 } ,												
{ "Tempest (rev 2)"                                                                                       ,"tempest2"     , "mame", 3, 0 } ,												
{ "Tempest (rev 3)"                                                                                       ,"tempest"      , "mame", 3, 0 } ,												
{ "Tempest Tubes"                                                                                         ,"temptube"     , "mame", 3, 0 } ,												
{ "Tenchi wo Kurau (Japan)"                                                                               ,"dwj"          , "mame", 3, 0 } ,												
{ "Tenchi wo Kurau II - Sekiheki no Tatakai (Japan)"                                                      ,"wofj"         , "mame", 1, 0 } ,												
{ "Terminator 2 - Judgment Day (rev LA3 03/27/92)"                                                        ,"term2"        , "mame", 3, 0 } ,												
{ "Terra Cresta (YM2203)"                                                                                 ,"terracra"     , "mame", 3, 0 } ,												
{ "Terra Cresta (YM3526 set 1)"                                                                           ,"terracre"     , "mame", 3, 0 } ,												
{ "Terra Cresta (YM3526 set 2)"                                                                           ,"terracrb"     , "mame", 3, 0 } ,												
{ "Terra Force (US)"                                                                                      ,"terrafu"      , "mame", 3, 0 } ,												
{ "Terra Force"                                                                                           ,"terraf"       , "mame", 3, 0 } ,												
{ "Tetris (Cocktail set 1)"                                                                               ,"atetcktl"     , "mame", 3, 0 } ,												
{ "Tetris (Cocktail set 2)"                                                                               ,"atetckt2"     , "mame", 3, 0 } ,												
{ "Tetris (Japan, B-System)"                                                                              ,"tetrist"      , "mame", 3, 0 } ,												
{ "Tetris (Sega Set 1)"                                                                                   ,"tetris"       , "mame", 3, 0 } ,												
{ "Tetris (Sega Set 2)"                                                                                   ,"tetrisa"      , "mame", 3, 0 } ,												
{ "Tetris (Sega bootleg)"                                                                                 ,"tetrisbl"     , "mame", 3, 0 } ,												
{ "Tetris (bootleg)"                                                                                      ,"atetrisb"     , "mame", 3, 0 } ,												
{ "Tetris (set 1)"                                                                                        ,"atetris"      , "mame", 3, 0 } ,												
{ "Tetris (set 2)"                                                                                        ,"atetrisa"     , "mame", 3, 0 } ,												
{ "Thrash Rally"                                                                                          ,"trally"       , "neomame", 3, 0 } ,												
{ "Three Stooges"                                                                                         ,"3stooges"     , "mame", 3, 0 } ,												
{ "Three Wonders (US)"                                                                                    ,"3wonders"     , "mame", 3, 0 } ,												
{ "Thunder Blaster (Japan)"                                                                               ,"thndblst"     , "mame", 3, 0 } ,												
{ "Thunder Cross (Japan)"                                                                                 ,"thnderxj"     , "mame", 3, 0 } ,												
{ "Thunder Cross II (Japan)"                                                                              ,"thndrx2"      , "mame", 3, 0 } ,												
{ "Thunder Cross"                                                                                         ,"thunderx"     , "mame", 3, 0 } ,												
{ "Thunder Fox (Japan)"                                                                                   ,"thundfox"     , "mame", 3, 0 } ,												
{ "ThunderJaws"                                                                                           ,"thunderj"     , "mame", 0, 0 } ,												
{ "Thundercade / Twin Formation"                                                                          ,"tndrcade"     , "mame", 3, 0 } ,												
{ "Tiger Heli (Japan)"                                                                                    ,"tigerhj"      , "mame", 3, 0 } ,												
{ "Tiger Heli (bootleg 1)"                                                                                ,"tigerhb1"     , "mame", 3, 0 } ,												
{ "Tiger Heli (bootleg 2)"                                                                                ,"tigerhb2"     , "mame", 3, 0 } ,												
{ "Tiger Heli (set 1)"                                                                                    ,"tigerh"       , "mame", 3, 0 } ,												
{ "Tiger Heli (set 2)"                                                                                    ,"tigerh2"      , "mame", 3, 0 } ,												
{ "Tiger Road (US)"                                                                                       ,"tigeroad"     , "mame", 3, 0 } ,												
{ "Timber"                                                                                                ,"timber"       , "mame", 5, 0 } ,												
{ "Time Pilot '84 (set 1)"                                                                                ,"tp84"         , "mame", 3, 0 } ,												
{ "Time Pilot '84 (set 2)"                                                                                ,"tp84a"        , "mame", 3, 0 } ,												
{ "Time Pilot (Centuri)"                                                                                  ,"timepltc"     , "mame", 3, 0 } ,												
{ "Time Pilot"                                                                                            ,"timeplt"      , "mame", 3, 0 } ,												
{ "Time Scanner"                                                                                          ,"timscanr"     , "mame", 3, 0 } ,												
{ "Time Soldiers (US Rev 1)"                                                                              ,"timesol1"     , "mame", 3, 0 } ,												
{ "Time Soldiers (US Rev 3)"                                                                              ,"timesold"     , "mame", 3, 0 } ,												
{ "Time Tunnel"                                                                                           ,"timetunl"     , "mame", 3, 0 } ,												
{ "Tin Star, The"                                                                                         ,"tinstar"      , "mame", 3, 0 } ,												
{ "Tip Top"                                                                                               ,"tiptop"       , "mame", 3, 0 } ,												
{ "Toggle"                                                                                                ,"toggle"       , "mame", 3, 0 } ,												
{ "Toki (US)"                                                                                             ,"tokiu"        , "mame", 3, 0 } ,												
{ "Toki (bootleg)"                                                                                        ,"tokib"        , "mame", 3, 0 } ,												
{ "Toki (set 1)"                                                                                          ,"toki"         , "mame", 3, 0 } ,												
{ "Toki (set 2)"                                                                                          ,"toki2"        , "mame", 3, 0 } ,												
{ "Toki (set 3)"                                                                                          ,"toki3"        , "mame", 3, 0 } ,												
{ "Toki no Senshi - Chrono Soldier"                                                                       ,"tokisens"     , "mame", 3, 0 } ,												
{ "Tokio / Scramble Formation (bootleg)"                                                                  ,"tokiob"       , "mame", 3, 0 } ,												
{ "Tokio / Scramble Formation"                                                                            ,"tokio"        , "mame", 3, 0 } ,												
{ "Tokushu Butai Jackal (Japan)"                                                                          ,"jackalj"      , "mame", 3, 0 } ,												
{ "Tokusyu Butai UAG (Japan)"                                                                             ,"tndrcadj"     , "mame", 3, 0 } ,												
{ "Tomahawk 777 (Revision 1)"                                                                             ,"tomahawk"     , "mame", 3, 0 } ,												
{ "Tomahawk 777 (Revision 5)"                                                                             ,"tomahaw5"     , "mame", 3, 0 } ,												
{ "Toobin' (Prototype)"                                                                                   ,"toobinp"      , "mame", 3, 0 } ,												
{ "Toobin' (version 2)"                                                                                   ,"toobin2"      , "mame", 3, 0 } ,												
{ "Toobin' (version 3)"                                                                                   ,"toobin"       , "mame", 3, 0 } ,												
{ "Top Gunner (US)"                                                                                       ,"topgunr"      , "mame", 3, 0 } ,												
{ "Top Gunner (bootleg)"                                                                                  ,"topgunbl"     , "mame", 3, 0 } ,												
{ "Top Hunter - Roddy & Cathy"                                                                            ,"tophuntr"     , "neomame", 3, 0 } ,												
{ "Top Player's Golf"                                                                                     ,"tpgolf"       , "neomame", 3, 0 } ,												
{ "Top Racer"                                                                                             ,"topracer"     , "mame", 3, 0 } ,												
{ "Top Secret (Exidy) (version 1.0)"                                                                      ,"topsecex"     , "mame", 3, 0 } ,												
{ "Top Secret (Japan)"                                                                                    ,"topsecrt"     , "mame", 3, 0 } ,												
{ "Tora eno Michi (Japan)"                                                                                ,"toramich"     , "mame", 1, 0 } ,												
{ "Tornado Baseball"                                                                                      ,"tornbase"     , "mame", 3, 0 } ,												
{ "Toryumon"                                                                                              ,"toryumon"     , "mame", 1, 0 } ,												
{ "Total Carnage (prototype, rev 1.0 01/25/92)"                                                           ,"totcarnp"     , "mame", 3, 0 } ,												
{ "Total Carnage (rev LA1 03/10/92)"                                                                      ,"totcarn"      , "mame", 3, 0 } ,												
{ "TouchDown Fever (Japan)"                                                                               ,"tdfeverj"     , "mame", 3, 0 } ,												
{ "TouchDown Fever"                                                                                       ,"tdfever"      , "mame", 3, 0 } ,												
{ "Tough Turf (Japan)"                                                                                    ,"tturf"        , "mame", 3, 0 } ,												
{ "Tough Turf (US)"                                                                                       ,"tturfu"       , "mame", 3, 0 } ,												
{ "Tough Turf (bootleg)"                                                                                  ,"tturfbl"      , "mame", 3, 0 } ,												
{ "Tougyuu, The (Japan)"                                                                                  ,"bullfgtj"     , "mame", 5, 0 } ,												
{ "Tournament Arkanoid (US)"                                                                              ,"arkatour"     , "mame", 3, 0 } ,												
{ "Tournament Cyberball 2072"                                                                             ,"cyberbt"      , "mame", 3, 0 } ,												
{ "Tower of Druaga (set 1)"                                                                               ,"todruaga"     , "mame", 3, 0 } ,												
{ "Tower of Druaga (set 2)"                                                                               ,"todruagb"     , "mame", 3, 0 } ,												
{ "Toypop"                                                                                                ,"toypop"       , "mame", 3, 0 } ,												
{ "Track & Field (Centuri)"                                                                               ,"trackflc"     , "mame", 3, 0 } ,												
{ "Track & Field"                                                                                         ,"trackfld"     , "mame", 3, 0 } ,												
{ "Tranquilizer Gun"                                                                                      ,"tranqgun"     , "mame", 3, 0 } ,												
{ "Traverse USA / Zippy Race"                                                                             ,"travrusa"     , "mame", 3, 0 } ,												
{ "Treasure Hunt (Japan?)"                                                                                ,"treahunt"     , "mame", 1, 0 } ,												
{ "Tri-Sports"                                                                                            ,"trisport"     , "mame", 3, 0 } ,												
{ "Trigon (Japan)"                                                                                        ,"trigon"       , "mame", 3, 0 } ,												
{ "Trio The Punch - Never Forget Me... (Japan)"                                                           ,"triothep"     , "mame", 3, 0 } ,												
{ "Triple Punch"                                                                                          ,"triplep"      , "mame", 3, 0 } ,												
{ "Trivial Pursuit (All Star Sports Edition)"                                                             ,"triviasp"     , "mame", 3, 0 } ,												
{ "Trivial Pursuit (Baby Boomer Edition)"                                                                 ,"triviabb"     , "mame", 3, 0 } ,												
{ "Trivial Pursuit (Genus I)"                                                                             ,"triviag1"     , "mame", 3, 0 } ,												
{ "Trivial Pursuit (Genus II)"                                                                            ,"triviag2"     , "mame", 3, 0 } ,												
{ "Trivial Pursuit (Young Players Edition)"                                                               ,"triviayp"     , "mame", 3, 0 } ,												
{ "Trog (prototype, rev 4.00 07/27/90)"                                                                   ,"trogp"        , "mame", 3, 0 } ,												
{ "Trog (rev LA3 02/14/91)"                                                                               ,"trog3"        , "mame", 3, 0 } ,												
{ "Trog (rev LA4 03/11/91)"                                                                               ,"trog"         , "mame", 3, 0 } ,												
{ "Trojan (Romstar)"                                                                                      ,"trojanr"      , "mame", 5, 0 } ,												
{ "Trojan (US)"                                                                                           ,"trojan"       , "mame", 5, 0 } ,												
{ "Tron (set 1)"                                                                                          ,"tron"         , "mame", 5, 0 } ,												
{ "Tron (set 2)"                                                                                          ,"tron2"        , "mame", 5, 0 } ,												
{ "Tropical Angel"                                                                                        ,"troangel"     , "mame", 3, 0 } ,												
{ "Truxton / Tatsujin"                                                                                    ,"truxton"      , "mame", 3, 0 } ,												
{ "Truxton II / Tatsujin II / Tatsujin Oh (Japan)"                                                        ,"tatsujn2"     , "mame", 3, 0 } ,												
{ "Tube-It"                                                                                               ,"tubeit"       , "mame", 3, 0 } ,												
{ "Tumble Pop (Japan)"                                                                                    ,"tumblepj"     , "mame", 3, 0 } ,												
{ "Tumble Pop (World)"                                                                                    ,"tumblep"      , "mame", 3, 0 } ,												
{ "Tumble Pop (bootleg set 1)"                                                                            ,"tumblepb"     , "mame", 3, 0 } ,												
{ "Tumble Pop (bootleg set 2)"                                                                            ,"tumblep2"     , "mame", 3, 0 } ,												
{ "Turbo (encrypted set 1)"                                                                               ,"turboa"       , "mame", 3, 0 } ,												
{ "Turbo (encrypted set 2)"                                                                               ,"turbob"       , "mame", 3, 0 } ,												
{ "Turbo Force"                                                                                           ,"turbofrc"     , "mame", 1, 0 } ,												
{ "Turbo Tag (Prototype)"                                                                                 ,"turbotag"     , "mame", 1, 0 } ,												
{ "Turbo"                                                                                                 ,"turbo"        , "mame", 3, 0 } ,												
{ "Turkey Shoot"                                                                                          ,"tshoot"       , "mame", 3, 0 } ,												
{ "Turpin"                                                                                                ,"turpin"       , "mame", 3, 0 } ,												
{ "Turtle Ship"                                                                                           ,"turtship"     , "mame", 3, 0 } ,												
{ "Turtles"                                                                                               ,"turtles"      , "mame", 3, 0 } ,												
{ "Tutankham (Stern)"                                                                                     ,"tutankst"     , "mame", 3, 0 } ,												
{ "Tutankham"                                                                                             ,"tutankhm"     , "mame", 3, 0 } ,												
{ "Twin Cobra (US)"                                                                                       ,"twincobu"     , "mame", 3, 0 } ,												
{ "Twin Cobra (World)"                                                                                    ,"twincobr"     , "mame", 3, 0 } ,												
{ "Twin Eagle (Japan)"                                                                                    ,"twineagl"     , "mame", 3, 0 } ,												
{ "TwinBee"                                                                                               ,"twinbee"      , "mame", 3, 0 } ,												
{ "Twinkle Star Sprites"                                                                                  ,"twinspri"     , "neomame", 3, 0 } ,												
{ "Two Crude (US)"                                                                                        ,"twocrude"     , "mame", 3, 0 } ,												
{ "Two Tigers"                                                                                            ,"twotiger"     , "mame", 5, 0 } ,												
{ "U.N. Squadron (US)"                                                                                    ,"unsquad"      , "mame", 3, 0 } ,												
{ "U.S. Classic"                                                                                          ,"usclssic"     , "mame", 0, 0 } ,												
{ "U.S. Navy (Japan)"                                                                                     ,"cawingj"      , "mame", 3, 0 } ,												
{ "Ufo Senshi Yohko Chan"                                                                                 ,"ufosensi"     , "mame", 1, 0 } ,												
{ "Ultimate 11 / Tokuten Ou - Honoo no Libero, The"                                                       ,"ssideki4"     , "neomame", 3, 0 } ,												
{ "Ultimate Mortal Kombat 3 (rev 1.1)"                                                                    ,"umk3r11"      , "mame", 3, 0 } ,												
{ "Ultimate Mortal Kombat 3 (rev 1.2)"                                                                    ,"umk3"         , "mame", 3, 0 } ,												
{ "Ultraman (Japan)"                                                                                      ,"ultraman"     , "mame", 3, 0 } ,												
{ "Undercover Cops (Japan)"                                                                               ,"uccopsj"      , "mame", 3, 0 } ,												
{ "Undercover Cops (World)"                                                                               ,"uccops"       , "mame", 3, 0 } ,												
{ "UniWar S"                                                                                              ,"uniwars"      , "mame", 3, 0 } ,												
{ "Uo Poko (Japan)"                                                                                       ,"uopoko"       , "mame", 3, 0 } ,												
{ "Up'n Down"                                                                                             ,"upndown"      , "mame", 3, 0 } ,												
{ "Us vs. Them"                                                                                           ,"usvsthem"     , "mame", 3, 0 } ,												
{ "V-Five (Japan)"                                                                                        ,"vfive"        , "mame", 3, 0 } ,												
{ "Valtric"                                                                                               ,"valtric"      , "mame", 1, 0 } ,												
{ "Van Van Car (Sanritsu)"                                                                                ,"vanvans"      , "mame", 3, 0 } ,												
{ "Van Van Car"                                                                                           ,"vanvan"       , "mame", 3, 0 } ,												
{ "Vanguard (Centuri)"                                                                                    ,"vangrdce"     , "mame", 3, 0 } ,												
{ "Vanguard (SNK)"                                                                                        ,"vanguard"     , "mame", 3, 0 } ,												
{ "Vanguard II"                                                                                           ,"vangrd2"      , "mame", 3, 0 } ,												
{ "Vapor Trail - Hyper Offence Formation (US)"                                                            ,"vaportru"     , "mame", 3, 0 } ,												
{ "Vapor Trail - Hyper Offence Formation (World revision 1)"                                              ,"vaportra"     , "mame", 3, 0 } ,												
{ "Varth - Operation Thunderstorm (Japan)"                                                                ,"varthj"       , "mame", 3, 0 } ,												
{ "Varth - Operation Thunderstorm (US)"                                                                   ,"varthu"       , "mame", 3, 0 } ,												
{ "Varth - Operation Thunderstorm (World)"                                                                ,"varth"        , "mame", 3, 0 } ,												
{ "Vastar (set 1)"                                                                                        ,"vastar"       , "mame", 3, 0 } ,												
{ "Vastar (set 2)"                                                                                        ,"vastar2"      , "mame", 3, 0 } ,												
{ "Vendetta (Asia set 1)"                                                                                 ,"vendetta"     , "mame", 3, 0 } ,												
{ "Vendetta (Asia set 2)"                                                                                 ,"vendett2"     , "mame", 3, 0 } ,												
{ "Venture (version 4)"                                                                                   ,"venture4"     , "mame", 3, 0 } ,												
{ "Venture (version 5 set 1)"                                                                             ,"venture"      , "mame", 3, 0 } ,												
{ "Venture (version 5 set 2)"                                                                             ,"venture2"     , "mame", 3, 0 } ,												
{ "Venus"                                                                                                 ,"venus"        , "mame", 3, 0 } ,												
{ "Victor Banana"                                                                                         ,"victorba"     , "mame", 1, 0 } ,												
{ "Victory Road"                                                                                          ,"victroad"     , "mame", 3, 0 } ,												
{ "Victory"                                                                                               ,"victory"      , "mame", 1, 0 } ,												
{ "Video Hustler (bootleg)"                                                                               ,"hustlerb"     , "mame", 3, 0 } ,												
{ "Video Hustler"                                                                                         ,"hustler"      , "mame", 3, 0 } ,												
{ "Viewpoint"                                                                                             ,"viewpoin"     , "neomame", 3, 0 } ,												
{ "Vigilante (Japan)"                                                                                     ,"vigilntj"     , "mame", 1, 0 } ,												
{ "Vigilante (US)"                                                                                        ,"vigilntu"     , "mame", 1, 0 } ,												
{ "Vigilante (World)"                                                                                     ,"vigilant"     , "mame", 1, 0 } ,												
{ "Vimana (Nova Apparate GMBH & Co)"                                                                      ,"vimanan"      , "mame", 3, 0 } ,												
{ "Vimana (set 1)"                                                                                        ,"vimana"       , "mame", 3, 0 } ,												
{ "Vimana (set 2)"                                                                                        ,"vimana2"      , "mame", 3, 0 } ,												
{ "Vindicators Part II"                                                                                   ,"vindctr2"     , "mame", 3, 0 } ,												
{ "Vindicators"                                                                                           ,"vindictr"     , "mame", 3, 0 } ,												
{ "Violence Fight (World)"                                                                                ,"viofight"     , "mame", 3, 0 } ,												
{ "Viper"                                                                                                 ,"viper"        , "mame", 3, 0 } ,												
{ "Voltage Fighter - Gowcaizer / Choujin Gakuen Gowcaizer"                                                ,"gowcaizr"     , "neomame", 3, 0 } ,												
{ "Vulcan Venture"                                                                                        ,"vulcan"       , "mame", 3, 0 } ,												
{ "Vulgus (Japan?)"                                                                                       ,"vulgusj"      , "mame", 5, 0 } ,												
{ "Vulgus (set 1)"                                                                                        ,"vulgus"       , "mame", 5, 0 } ,												
{ "Vulgus (set 2)"                                                                                        ,"vulgus2"      , "mame", 5, 0 } ,												
{ "WEC Le Mans 24"                                                                                        ,"wecleman"     , "mame", 3, 0 } ,												
{ "WWF: Wrestlemania (rev 1.30)"                                                                          ,"wwfmania"     , "mame", 3, 0 } ,												
{ "Wacko"                                                                                                 ,"wacko"        , "mame", 5, 0 } ,												
{ "Waku Waku 7"                                                                                           ,"wakuwak7"     , "neomame", 3, 0 } ,												
{ "Wanted"                                                                                                ,"wanted"       , "mame", 3, 0 } ,												
{ "War of Aero - Project MEIOU"                                                                           ,"wrofaero"     , "mame", 3, 0 } ,												
{ "War of the Bugs"                                                                                       ,"warofbug"     , "mame", 3, 0 } ,												
{ "War of the Worlds"                                                                                     ,"wotw"         , "mame", 3, 0 } ,												
{ "Wardna no Mori (Japan)"                                                                                ,"wardnerj"     , "mame", 3, 0 } ,												
{ "Wardner (World)"                                                                                       ,"wardner"      , "mame", 3, 0 } ,												
{ "Warlords"                                                                                              ,"warlord"      , "mame", 3, 0 } ,												
{ "Warp & Warp"                                                                                           ,"warpwarp"     , "mame", 3, 0 } ,												
{ "Warp Warp (Rock-ola set 1)"                                                                            ,"warpwarr"     , "mame", 3, 0 } ,												
{ "Warp Warp (Rock-ola set 2)"                                                                            ,"warpwar2"     , "mame", 3, 0 } ,												
{ "Warrior"                                                                                               ,"warrior"      , "mame", 3, 0 } ,												
{ "Warriors of Fate (World)"                                                                              ,"wof"          , "mame", 1, 0 } ,												
{ "Water Ski"                                                                                             ,"waterski"     , "mame", 1, 0 } ,												
{ "West Story"                                                                                            ,"weststry"     , "mame", 0, 0 } ,												
{ "Western Express (World?)"                                                                              ,"wexpress"     , "mame", 3, 0 } ,												
{ "Western Express (bootleg)"                                                                             ,"wexpresb"     , "mame", 3, 0 } ,												
{ "Who Dunit (version 8.0)"                                                                               ,"whodunit"     , "mame", 3, 0 } ,												
{ "Whoopee (Japan) / Pipi & Bibis (World)"                                                                ,"whoopee"      , "mame", 3, 0 } ,												
{ "Wild Fang"                                                                                             ,"wildfang"     , "mame", 3, 0 } ,												
{ "Wild Western (set 1)"                                                                                  ,"wwestern"     , "mame", 3, 0 } ,												
{ "Wild Western (set 2)"                                                                                  ,"wwester1"     , "mame", 3, 0 } ,												
{ "Willow (Japan, English)"                                                                               ,"willow"       , "mame", 3, 0 } ,												
{ "Willow (Japan, Japanese)"                                                                              ,"willowj"      , "mame", 3, 0 } ,												
{ "Windjammers / Flying Power Disc"                                                                       ,"wjammers"     , "neomame", 3, 0 } ,												
{ "Wiping"                                                                                                ,"wiping"       , "mame", 3, 0 } ,												
{ "Wise Guy"                                                                                              ,"wiseguy"      , "mame", 1, 0 } ,												
{ "Wiz (Taito)"                                                                                           ,"wizt"         , "mame", 3, 0 } ,												
{ "Wiz"                                                                                                   ,"wiz"          , "mame", 3, 0 } ,												
{ "Wizard of Wor"                                                                                         ,"wow"          , "mame", 3, 0 } ,												
{ "Wonder 3 (Japan)"                                                                                      ,"wonder3"      , "mame", 3, 0 } ,												
{ "Wonder Boy (not encrypted)"                                                                            ,"wboyu"        , "mame", 3, 0 } ,												
{ "Wonder Boy (set 1)"                                                                                    ,"wboy"         , "mame", 5, 0 } ,												
{ "Wonder Boy (set 2)"                                                                                    ,"wboy2"        , "mame", 5, 0 } ,												
{ "Wonder Boy (set 3)"                                                                                    ,"wboy3"        , "mame", 5, 0 } ,												
{ "Wonder Boy (set 4 not encrypted)"                                                                      ,"wboy4u"       , "mame", 3, 0 } ,												
{ "Wonder Boy (set 4)"                                                                                    ,"wboy4"        , "mame", 5, 0 } ,												
{ "Wonder Boy Deluxe"                                                                                     ,"wbdeluxe"     , "mame", 3, 0 } ,												
{ "Wonder Boy III - Monster Lair (bootleg)"                                                               ,"wb3bl"        , "mame", 3, 0 } ,												
{ "Wonder Boy III - Monster Lair (set 1)"                                                                 ,"wb3"          , "mame", 3, 0 } ,												
{ "Wonder Boy III - Monster Lair (set 2)"                                                                 ,"wb3a"         , "mame", 3, 0 } ,												
{ "Wonder Boy in Monster Land (Japan not encrypted)"                                                      ,"wbmlju"       , "mame", 5, 0 } ,												
{ "Wonder Boy in Monster Land (Japan set 1)"                                                              ,"wbmlj"        , "mame", 5, 0 } ,												
{ "Wonder Boy in Monster Land (Japan set 2)"                                                              ,"wbmlj2"       , "mame", 5, 0 } ,												
{ "Wonder Boy in Monster Land"                                                                            ,"wbml"         , "mame", 5, 0 } ,												
{ "Wonder Momo"                                                                                           ,"wndrmomo"     , "mame", 3, 0 } ,												
{ "World Court (Japan)"                                                                                   ,"wldcourt"     , "mame", 3, 0 } ,												
{ "World Cup 90"                                                                                          ,"wc90"         , "mame", 3, 0 } ,												
{ "World Heroes 2 Jet"                                                                                    ,"wh2j"         , "neomame", 3, 0 } ,												
{ "World Heroes 2"                                                                                        ,"wh2"          , "neomame", 3, 0 } ,												
{ "World Heroes Perfect"                                                                                  ,"whp"          , "neomame", 3, 0 } ,												
{ "World Heroes"                                                                                          ,"wh1"          , "neomame", 3, 0 } ,												
{ "World Series: The Season"                                                                              ,"wseries"      , "mame", 1, 0 } ,												
{ "World Soccer Finals"                                                                                   ,"wsf"          , "mame", 3, 0 } ,												
{ "World Stadium '89 (Japan)"                                                                             ,"ws89"         , "mame", 3, 0 } ,												
{ "World Stadium '90 (Japan)"                                                                             ,"ws90"         , "mame", 3, 0 } ,												
{ "World Stadium (Japan)"                                                                                 ,"ws"           , "mame", 3, 0 } ,												
{ "World Tennis"                                                                                          ,"wtennis"      , "mame", 3, 0 } ,												
{ "World Wars (Japan)"                                                                                    ,"worldwar"     , "mame", 3, 0 } ,												
{ "Wrestle War"                                                                                           ,"wrestwar"     , "mame", 1, 0 } ,												
{ "X Multiply (Japan)"                                                                                    ,"xmultipl"     , "mame", 1, 0 } ,												
{ "X-Men (2 Players Japan)"                                                                               ,"xmen2pj"      , "mame", 3, 0 } ,												
{ "X-Men (4 Players)"                                                                                     ,"xmen"         , "mame", 3, 0 } ,												
{ "X-Men (6 Players)"                                                                                     ,"xmen6p"       , "mame", 3, 0 } ,												
{ "Xain'd Sleena (bootleg)"                                                                               ,"xsleenab"     , "mame", 3, 0 } ,												
{ "Xain'd Sleena"                                                                                         ,"xsleena"      , "mame", 3, 0 } ,												
{ "Xenophobe"                                                                                             ,"xenophob"     , "mame", 3, 0 } ,												
{ "Xevios"                                                                                                ,"xevios"       , "mame", 3, 0 } ,												
{ "Xevious (Atari)"                                                                                       ,"xeviousa"     , "mame", 3, 0 } ,												
{ "Xevious (Namco)"                                                                                       ,"xevious"      , "mame", 3, 0 } ,												
{ "Xybots"                                                                                                ,"xybots"       , "mame", 3, 0 } ,												
{ "Yam! Yam!?"                                                                                            ,"yamyam"       , "mame", 1, 0 } ,												
{ "Yamato (set 1)"                                                                                        ,"yamato"       , "mame", 5, 0 } ,												
{ "Yamato (set 2)"                                                                                        ,"yamato2"      , "mame", 5, 0 } ,												
{ "Yankee DO!"                                                                                            ,"yankeedo"     , "mame", 3, 0 } ,												
{ "Yes/No Sinri Tokimeki Chart"                                                                           ,"yesnoj"       , "mame", 3, 0 } ,												
{ "Yie Ar Kung-Fu (set 1)"                                                                                ,"yiear"        , "mame", 3, 0 } ,												
{ "Yie Ar Kung-Fu (set 2)"                                                                                ,"yiear2"       , "mame", 3, 0 } ,												
{ "Yokai Douchuuki (Japan new version)"                                                                   ,"youkaidk"     , "mame", 3, 0 } ,												
{ "Yokai Douchuuki (Japan old version)"                                                                   ,"yokaidko"     , "mame", 3, 0 } ,												
{ "Yosaku To Donbee (bootleg)"                                                                            ,"yosakdon"     , "mame", 3, 0 } ,												
{ "Youma Ninpou Chou (Japan)"                                                                             ,"youma"        , "mame", 3, 0 } ,												
{ "Yuuyu no Quiz de GO!GO! (Japan)"                                                                       ,"yuyugogo"     , "mame", 1, 0 } ,												
{ "Zarzon"                                                                                                ,"zarzon"       , "mame", 3, 0 } ,												
{ "Zaxxon (set 1)"                                                                                        ,"zaxxon"       , "mame", 3, 0 } ,												
{ "Zaxxon (set 2)"                                                                                        ,"zaxxon2"      , "mame", 3, 0 } ,												
{ "Zed Blade / Operation Ragnarok"                                                                        ,"zedblade"     , "neomame", 3, 0 } ,												
{ "Zektor"                                                                                                ,"zektor"       , "mame", 1, 0 } ,												
{ "Zero Time"                                                                                             ,"zerotime"     , "mame", 3, 0 } ,												
{ "Zero Wing"                                                                                             ,"zerowing"     , "mame", 3, 0 } ,												
{ "Zero Zone"                                                                                             ,"zerozone"     , "mame", 3, 0 } ,												
{ "Zig Zag (Dig Dug hardware)"                                                                            ,"dzigzag"      , "mame", 3, 0 } ,												
{ "Zig Zag (Galaxian hardware, set 1)"                                                                    ,"zigzag"       , "mame", 3, 0 } ,												
{ "Zig Zag (Galaxian hardware, set 2)"                                                                    ,"zigzag2"      , "mame", 3, 0 } ,												
{ "Zing Zing Zip"                                                                                         ,"zingzip"      , "mame", 3, 0 } ,												
{ "Zoar"                                                                                                  ,"zoar"         , "mame", 3, 0 } ,												
{ "Zodiack"                                                                                               ,"zodiack"      , "mame", 1, 0 } ,												
{ "Zoo Keeper (set 1)"                                                                                    ,"zookeep"      , "mame", 3, 0 } ,												
{ "Zoo Keeper (set 2)"                                                                                    ,"zookeep2"     , "mame", 3, 0 } ,												
{ "Zoo Keeper (set 3)"                                                                                    ,"zookeep3"     , "mame", 3, 0 } ,												
{ "Zwackery"                                                                                              ,"zwackery"     , "mame", 3, 0 } ,												
{ "Zzyzzyxx (set 1)"                                                                                      ,"zzyzzyxx"     , "mame", 3, 0 } ,												
{ "Zzyzzyxx (set 2)"                                                                                      ,"zzyzzyx2"     , "mame", 3, 0 }  												

};

#endif